Class: WalmartApIs::AcknowledgeOrderResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/acknowledge_order_response.rb

Overview

AcknowledgeOrderResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(purchase_order_id: SKIP, acknowledged_at: SKIP, additional_properties: nil) ⇒ AcknowledgeOrderResponse

Returns a new instance of AcknowledgeOrderResponse.



42
43
44
45
46
47
48
49
50
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 42

def initialize(purchase_order_id: SKIP, acknowledged_at: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @purchase_order_id = purchase_order_id unless purchase_order_id == SKIP
  @acknowledged_at = acknowledged_at unless acknowledged_at == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#acknowledged_atDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


19
20
21
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 19

def acknowledged_at
  @acknowledged_at
end

#purchase_order_idString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 15

def purchase_order_id
  @purchase_order_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  purchase_order_id =
    hash.key?('purchaseOrderId') ? hash['purchaseOrderId'] : SKIP
  acknowledged_at = if hash.key?('acknowledgedAt')
                      (DateTimeHelper.from_rfc3339(hash['acknowledgedAt']) if hash['acknowledgedAt'])
                    else
                      SKIP
                    end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AcknowledgeOrderResponse.new(purchase_order_id: purchase_order_id,
                               acknowledged_at: acknowledged_at,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['purchase_order_id'] = 'purchaseOrderId'
  @_hash['acknowledged_at'] = 'acknowledgedAt'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 30

def self.optionals
  %w[
    purchase_order_id
    acknowledged_at
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} purchase_order_id: #{@purchase_order_id.inspect}, acknowledged_at:"\
  " #{@acknowledged_at.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_acknowledged_atObject



78
79
80
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 78

def to_custom_acknowledged_at
  DateTimeHelper.to_rfc3339(acknowledged_at)
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/walmart_ap_is/models/acknowledge_order_response.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} purchase_order_id: #{@purchase_order_id}, acknowledged_at:"\
  " #{@acknowledged_at}, additional_properties: #{@additional_properties}>"
end