Class: WalmartApIs::AnnualStatementOptsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/annual_statement_opts_response.rb

Overview

AnnualStatementOptsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_opted_in: SKIP, statement_year: SKIP, additional_properties: nil) ⇒ AnnualStatementOptsResponse

Returns a new instance of AnnualStatementOptsResponse.



41
42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 41

def initialize(is_opted_in: SKIP, statement_year: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_opted_in = is_opted_in unless is_opted_in == SKIP
  @statement_year = statement_year unless statement_year == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_opted_inTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 14

def is_opted_in
  @is_opted_in
end

#statement_yearInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 18

def statement_year
  @statement_year
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_opted_in = hash.key?('isOptedIn') ? hash['isOptedIn'] : SKIP
  statement_year = hash.key?('statementYear') ? hash['statementYear'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AnnualStatementOptsResponse.new(is_opted_in: is_opted_in,
                                  statement_year: statement_year,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_opted_in'] = 'isOptedIn'
  @_hash['statement_year'] = 'statementYear'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 29

def self.optionals
  %w[
    is_opted_in
    statement_year
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_opted_in: #{@is_opted_in.inspect}, statement_year:"\
  " #{@statement_year.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/walmart_ap_is/models/annual_statement_opts_response.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_opted_in: #{@is_opted_in}, statement_year: #{@statement_year},"\
  " additional_properties: #{@additional_properties}>"
end