Class: WalmartApIs::AppointmentSlotTime

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/appointment_slot_time.rb

Overview

An appointment slot time with start and end., Contains details for a transportation carrier appointment., An appointment slot time with start and end., Contains details for a transportation carrier appointment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(end_time:, start_time:, additional_properties: nil) ⇒ AppointmentSlotTime

Returns a new instance of AppointmentSlotTime.



41
42
43
44
45
46
47
48
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 41

def initialize(end_time:, start_time:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @end_time = end_time
  @start_time = start_time
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_timeDateTime

The end timestamp of the appointment in UTC.

Returns:

  • (DateTime)


17
18
19
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 17

def end_time
  @end_time
end

#start_timeDateTime

The start timestamp of the appointment in UTC.

Returns:

  • (DateTime)


21
22
23
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 21

def start_time
  @start_time
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  end_time = if hash.key?('endTime')
               (DateTimeHelper.from_rfc3339(hash['endTime']) if hash['endTime'])
             end
  start_time = if hash.key?('startTime')
                 (DateTimeHelper.from_rfc3339(hash['startTime']) if hash['startTime'])
               end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AppointmentSlotTime.new(end_time: end_time,
                          start_time: start_time,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['end_time'] = 'endTime'
  @_hash['start_time'] = 'startTime'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} end_time: #{@end_time.inspect}, start_time: #{@start_time.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_end_timeObject



75
76
77
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 75

def to_custom_end_time
  DateTimeHelper.to_rfc3339(end_time)
end

#to_custom_start_timeObject



79
80
81
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 79

def to_custom_start_time
  DateTimeHelper.to_rfc3339(start_time)
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/walmart_ap_is/models/appointment_slot_time.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} end_time: #{@end_time}, start_time: #{@start_time}, additional_properties:"\
  " #{@additional_properties}>"
end