Class: WalmartApIs::BatchOffersResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/batch_offers_response.rb

Overview

Common schema present in ItemOffersResponse and ListingOffersResponse.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(body:, headers: SKIP, status: SKIP, additional_properties: nil) ⇒ BatchOffersResponse

Returns a new instance of BatchOffersResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 47

def initialize(body:, headers: SKIP, status: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @headers = headers unless headers == SKIP
  @status = status unless status == SKIP
  @body = body
  @additional_properties = additional_properties
end

Instance Attribute Details

#bodyGetOffersResponse

The response schema for the getListingOffers and getItemOffers operations.

Returns:



23
24
25
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 23

def body
  @body
end

#headersHttpResponseHeaders

A mapping of additional HTTP headers to receive for the individual batch request.

Returns:



15
16
17
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 15

def headers
  @headers
end

#statusGetOffersHttpStatusLine

The HTTP status line associated with the response.



19
20
21
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 19

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  body = GetOffersResponse.from_hash(hash['body']) if hash['body']
  headers = HttpResponseHeaders.from_hash(hash['headers']) if hash['headers']
  status = GetOffersHttpStatusLine.from_hash(hash['status']) if hash['status']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BatchOffersResponse.new(body: body,
                          headers: headers,
                          status: status,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['headers'] = 'headers'
  @_hash['status'] = 'status'
  @_hash['body'] = 'body'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 35

def self.optionals
  %w[
    headers
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} headers: #{@headers.inspect}, status: #{@status.inspect}, body:"\
  " #{@body.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/walmart_ap_is/models/batch_offers_response.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} headers: #{@headers}, status: #{@status}, body: #{@body},"\
  " additional_properties: #{@additional_properties}>"
end