Class: WalmartApIs::BulkInventoryItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/bulk_inventory_item.rb

Overview

BulkInventoryItem Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(seller_sku:, quantity:, ship_node: SKIP, fulfillment_lag: SKIP, additional_properties: nil) ⇒ BulkInventoryItem

Returns a new instance of BulkInventoryItem.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 51

def initialize(seller_sku:, quantity:, ship_node: SKIP,
               fulfillment_lag: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @seller_sku = seller_sku
  @quantity = quantity
  @ship_node = ship_node unless ship_node == SKIP
  @fulfillment_lag = fulfillment_lag unless fulfillment_lag == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fulfillment_lagInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 26

def fulfillment_lag
  @fulfillment_lag
end

#quantityQuantity

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 18

def quantity
  @quantity
end

#seller_skuString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 14

def seller_sku
  @seller_sku
end

#ship_nodeString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 22

def ship_node
  @ship_node
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  seller_sku = hash.key?('sellerSku') ? hash['sellerSku'] : nil
  quantity = Quantity.from_hash(hash['quantity']) if hash['quantity']
  ship_node = hash.key?('shipNode') ? hash['shipNode'] : SKIP
  fulfillment_lag =
    hash.key?('fulfillmentLag') ? hash['fulfillmentLag'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BulkInventoryItem.new(seller_sku: seller_sku,
                        quantity: quantity,
                        ship_node: ship_node,
                        fulfillment_lag: fulfillment_lag,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['seller_sku'] = 'sellerSku'
  @_hash['quantity'] = 'quantity'
  @_hash['ship_node'] = 'shipNode'
  @_hash['fulfillment_lag'] = 'fulfillmentLag'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 39

def self.optionals
  %w[
    ship_node
    fulfillment_lag
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} seller_sku: #{@seller_sku.inspect}, quantity: #{@quantity.inspect},"\
  " ship_node: #{@ship_node.inspect}, fulfillment_lag: #{@fulfillment_lag.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
95
# File 'lib/walmart_ap_is/models/bulk_inventory_item.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} seller_sku: #{@seller_sku}, quantity: #{@quantity}, ship_node:"\
  " #{@ship_node}, fulfillment_lag: #{@fulfillment_lag}, additional_properties:"\
  " #{@additional_properties}>"
end