Class: WalmartApIs::BulkItemError
- Defined in:
- lib/walmart_ap_is/models/bulk_item_error.rb
Overview
BulkItemError Model.
Instance Attribute Summary collapse
-
#code ⇒ String
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#seller_sku ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(seller_sku: SKIP, code: SKIP, message: SKIP, additional_properties: nil) ⇒ BulkItemError
constructor
A new instance of BulkItemError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(seller_sku: SKIP, code: SKIP, message: SKIP, additional_properties: nil) ⇒ BulkItemError
Returns a new instance of BulkItemError.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 47 def initialize(seller_sku: SKIP, code: SKIP, message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @seller_sku = seller_sku unless seller_sku == SKIP @code = code unless code == SKIP @message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 18 def code @code end |
#message ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 22 def @message end |
#seller_sku ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 14 def seller_sku @seller_sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. seller_sku = hash.key?('sellerSku') ? hash['sellerSku'] : SKIP code = hash.key?('code') ? hash['code'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BulkItemError.new(seller_sku: seller_sku, code: code, message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['seller_sku'] = 'sellerSku' @_hash['code'] = 'code' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 34 def self.optionals %w[ seller_sku code message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} seller_sku: #{@seller_sku.inspect}, code: #{@code.inspect}, message:"\ " #{@message.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/bulk_item_error.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} seller_sku: #{@seller_sku}, code: #{@code}, message: #{@message},"\ " additional_properties: #{@additional_properties}>" end |