Class: WalmartApIs::CancelInboundPlanResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/cancel_inbound_plan_response.rb

Overview

The cancelInboundPlan response., The generateDeliveryWindowOptions response., The confirmDeliveryWindowOptions response., The cancelSelfShipAppointment response., The generateSelfShipAppointmentSlots response., The setPackingInformation response., The generatePackingOptions response., The confirmPackingOption response., The generatePlacementOptions response., The confirmPlacementOption response., The generateTransportationOptions response., The confirmTransportationOptions response., The updateItemComplianceDetails response., The setPrepDetails response., The updateShipmentSourceAddress response., The updateShipmentTrackingDetails response., The generateShipmentContentUpdatePreviews response., The confirmShipmentContentUpdatePreview response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(operation_id:, additional_properties: nil) ⇒ CancelInboundPlanResponse

Returns a new instance of CancelInboundPlanResponse.



44
45
46
47
48
49
50
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 44

def initialize(operation_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @operation_id = operation_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#operation_idString

UUID for the given operation.

Returns:

  • (String)


25
26
27
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 25

def operation_id
  @operation_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  operation_id = hash.key?('operationId') ? hash['operationId'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CancelInboundPlanResponse.new(operation_id: operation_id,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['operation_id'] = 'operationId'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} operation_id: #{@operation_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/walmart_ap_is/models/cancel_inbound_plan_response.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} operation_id: #{@operation_id}, additional_properties:"\
  " #{@additional_properties}>"
end