Class: WalmartApIs::CancelOrderLine
- Defined in:
- lib/walmart_ap_is/models/cancel_order_line.rb
Overview
CancelOrderLine Model.
Instance Attribute Summary collapse
-
#cancel_quantity ⇒ QuantityWithUnit
TODO: Write general description for this method.
-
#cancellation_reason ⇒ CancellationReason
TODO: Write general description for this method.
-
#line_number ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(line_number:, cancellation_reason:, cancel_quantity: SKIP, additional_properties: nil) ⇒ CancelOrderLine
constructor
A new instance of CancelOrderLine.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(line_number:, cancellation_reason:, cancel_quantity: SKIP, additional_properties: nil) ⇒ CancelOrderLine
Returns a new instance of CancelOrderLine.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 45 def initialize(line_number:, cancellation_reason:, cancel_quantity: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @line_number = line_number @cancel_quantity = cancel_quantity unless cancel_quantity == SKIP @cancellation_reason = cancellation_reason @additional_properties = additional_properties end |
Instance Attribute Details
#cancel_quantity ⇒ QuantityWithUnit
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 18 def cancel_quantity @cancel_quantity end |
#cancellation_reason ⇒ CancellationReason
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 22 def cancellation_reason @cancellation_reason end |
#line_number ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 14 def line_number @line_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. line_number = hash.key?('lineNumber') ? hash['lineNumber'] : nil cancellation_reason = hash.key?('cancellationReason') ? hash['cancellationReason'] : nil cancel_quantity = QuantityWithUnit.from_hash(hash['cancelQuantity']) if hash['cancelQuantity'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CancelOrderLine.new(line_number: line_number, cancellation_reason: cancellation_reason, cancel_quantity: cancel_quantity, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['line_number'] = 'lineNumber' @_hash['cancel_quantity'] = 'cancelQuantity' @_hash['cancellation_reason'] = 'cancellationReason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 34 def self.optionals %w[ cancel_quantity ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} line_number: #{@line_number.inspect}, cancel_quantity:"\ " #{@cancel_quantity.inspect}, cancellation_reason: #{@cancellation_reason.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 87 |
# File 'lib/walmart_ap_is/models/cancel_order_line.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} line_number: #{@line_number}, cancel_quantity: #{@cancel_quantity},"\ " cancellation_reason: #{@cancellation_reason}, additional_properties:"\ " #{@additional_properties}>" end |