Class: WalmartApIs::Carrier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/carrier.rb

Overview

Carrier Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, additional_properties: nil) ⇒ Carrier

Returns a new instance of Carrier.



41
42
43
44
45
46
47
48
# File 'lib/walmart_ap_is/models/carrier.rb', line 41

def initialize(id:, name:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/carrier.rb', line 14

def id
  @id
end

#nameString

Carrier display name. Walmart-specific enum-widening for internally-fulfilled carriers (e.g. WALMART_GROUND) is captured by leaving this as a free string rather than a closed enum.

Returns:

  • (String)


21
22
23
# File 'lib/walmart_ap_is/models/carrier.rb', line 21

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/walmart_ap_is/models/carrier.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Carrier.new(id: id,
              name: name,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/walmart_ap_is/models/carrier.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/carrier.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/walmart_ap_is/models/carrier.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/walmart_ap_is/models/carrier.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/walmart_ap_is/models/carrier.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, additional_properties:"\
  " #{@additional_properties}>"
end