Class: WalmartApIs::CompetitiveSummaryRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::CompetitiveSummaryRequest
- Defined in:
- lib/walmart_ap_is/models/competitive_summary_request.rb
Overview
An individual competitive summary request.
Instance Attribute Summary collapse
-
#included_data ⇒ Array[IncludedDatum2]
The list of requested competitive pricing data for the product.
-
#marketplace_id ⇒ String
A marketplace identifier.
-
#walmart_item_id ⇒ String
The Walmart Item ID of the item (see ADR-029).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(walmart_item_id:, marketplace_id:, included_data:, additional_properties: nil) ⇒ CompetitiveSummaryRequest
constructor
A new instance of CompetitiveSummaryRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(walmart_item_id:, marketplace_id:, included_data:, additional_properties: nil) ⇒ CompetitiveSummaryRequest
Returns a new instance of CompetitiveSummaryRequest.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 43 def initialize(walmart_item_id:, marketplace_id:, included_data:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @walmart_item_id = walmart_item_id @marketplace_id = marketplace_id @included_data = included_data @additional_properties = additional_properties end |
Instance Attribute Details
#included_data ⇒ Array[IncludedDatum2]
The list of requested competitive pricing data for the product.
22 23 24 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 22 def included_data @included_data end |
#marketplace_id ⇒ String
A marketplace identifier.
18 19 20 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 18 def marketplace_id @marketplace_id end |
#walmart_item_id ⇒ String
The Walmart Item ID of the item (see ADR-029).
14 15 16 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 14 def walmart_item_id @walmart_item_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. walmart_item_id = hash.key?('walmartItemId') ? hash['walmartItemId'] : nil marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : nil included_data = hash.key?('includedData') ? hash['includedData'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CompetitiveSummaryRequest.new(walmart_item_id: walmart_item_id, marketplace_id: marketplace_id, included_data: included_data, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['walmart_item_id'] = 'walmartItemId' @_hash['marketplace_id'] = 'marketplaceId' @_hash['included_data'] = 'includedData' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} walmart_item_id: #{@walmart_item_id.inspect}, marketplace_id:"\ " #{@marketplace_id.inspect}, included_data: #{@included_data.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/competitive_summary_request.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} walmart_item_id: #{@walmart_item_id}, marketplace_id: #{@marketplace_id},"\ " included_data: #{@included_data}, additional_properties: #{@additional_properties}>" end |