Class: WalmartApIs::ComplianceDetail

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/compliance_detail.rb

Overview

Contains item identifiers and related tax information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(msku: SKIP, tax_details: SKIP, additional_properties: nil) ⇒ ComplianceDetail

Returns a new instance of ComplianceDetail.



41
42
43
44
45
46
47
48
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 41

def initialize(msku: SKIP, tax_details: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @msku = msku unless msku == SKIP
  @tax_details = tax_details unless tax_details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#mskuString

The merchant SKU, a merchant-supplied identifier for a specific SKU.

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 14

def msku
  @msku
end

#tax_detailsTaxDetails

Information used to determine the tax compliance.

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 18

def tax_details
  @tax_details
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  msku = hash.key?('msku') ? hash['msku'] : SKIP
  tax_details = TaxDetails.from_hash(hash['taxDetails']) if hash['taxDetails']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ComplianceDetail.new(msku: msku,
                       tax_details: tax_details,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['msku'] = 'msku'
  @_hash['tax_details'] = 'taxDetails'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 29

def self.optionals
  %w[
    msku
    tax_details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} msku: #{@msku.inspect}, tax_details: #{@tax_details.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/walmart_ap_is/models/compliance_detail.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} msku: #{@msku}, tax_details: #{@tax_details}, additional_properties:"\
  " #{@additional_properties}>"
end