Class: WalmartApIs::CreateFeedResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/create_feed_response.rb

Overview

CreateFeedResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(feed_id:, feed_type: SKIP, marketplace_id: SKIP, additional_properties: nil) ⇒ CreateFeedResponse

Returns a new instance of CreateFeedResponse.



46
47
48
49
50
51
52
53
54
55
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 46

def initialize(feed_id:, feed_type: SKIP, marketplace_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @feed_id = feed_id
  @feed_type = feed_type unless feed_type == SKIP
  @marketplace_id = marketplace_id unless marketplace_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#feed_idString

Unique identifier for the submitted feed. Use this to poll feed status.

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 14

def feed_id
  @feed_id
end

#feed_typeString

The feed type that was submitted

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 18

def feed_type
  @feed_type
end

#marketplace_idString

The marketplace the feed was submitted to

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 22

def marketplace_id
  @marketplace_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  feed_id = hash.key?('feedId') ? hash['feedId'] : nil
  feed_type = hash.key?('feedType') ? hash['feedType'] : SKIP
  marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateFeedResponse.new(feed_id: feed_id,
                         feed_type: feed_type,
                         marketplace_id: marketplace_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['feed_id'] = 'feedId'
  @_hash['feed_type'] = 'feedType'
  @_hash['marketplace_id'] = 'marketplaceId'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 34

def self.optionals
  %w[
    feed_type
    marketplace_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} feed_id: #{@feed_id.inspect}, feed_type: #{@feed_type.inspect},"\
  " marketplace_id: #{@marketplace_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/walmart_ap_is/models/create_feed_response.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} feed_id: #{@feed_id}, feed_type: #{@feed_type}, marketplace_id:"\
  " #{@marketplace_id}, additional_properties: #{@additional_properties}>"
end