Class: WalmartApIs::CreateFulfillmentOrderResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::CreateFulfillmentOrderResponse
- Defined in:
- lib/walmart_ap_is/models/create_fulfillment_order_response.rb
Overview
CreateFulfillmentOrderResponse Model.
Instance Attribute Summary collapse
-
#errors ⇒ ErrorList
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(errors: SKIP, additional_properties: nil) ⇒ CreateFulfillmentOrderResponse
constructor
A new instance of CreateFulfillmentOrderResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(errors: SKIP, additional_properties: nil) ⇒ CreateFulfillmentOrderResponse
Returns a new instance of CreateFulfillmentOrderResponse.
35 36 37 38 39 40 41 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 35 def initialize(errors: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @errors = errors unless errors == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#errors ⇒ ErrorList
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 14 def errors @errors end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. errors = ErrorList.from_hash(hash['errors']) if hash['errors'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateFulfillmentOrderResponse.new(errors: errors, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['errors'] = 'errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 24 def self.optionals %w[ errors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} errors: #{@errors.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/walmart_ap_is/models/create_fulfillment_order_response.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} errors: #{@errors}, additional_properties: #{@additional_properties}>" end |