Class: WalmartApIs::CreateShipmentRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/create_shipment_request.rb

Overview

CreateShipmentRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(shipment_request_details:, shipping_service_id:, shipping_service_offer_id: SKIP, label_format: SKIP, additional_properties: nil) ⇒ CreateShipmentRequest

Returns a new instance of CreateShipmentRequest.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 51

def initialize(shipment_request_details:, shipping_service_id:,
               shipping_service_offer_id: SKIP, label_format: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @shipment_request_details = shipment_request_details
  @shipping_service_id = shipping_service_id
  unless shipping_service_offer_id == SKIP
    @shipping_service_offer_id =
      shipping_service_offer_id
  end
  @label_format = label_format unless label_format == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#label_formatLabelFormat

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 26

def label_format
  @label_format
end

#shipment_request_detailsShipmentRequestDetails

TODO: Write general description for this method



14
15
16
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 14

def shipment_request_details
  @shipment_request_details
end

#shipping_service_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 18

def shipping_service_id
  @shipping_service_id
end

#shipping_service_offer_idString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 22

def shipping_service_offer_id
  @shipping_service_offer_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 68

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  shipment_request_details = ShipmentRequestDetails.from_hash(hash['shipmentRequestDetails']) if
    hash['shipmentRequestDetails']
  shipping_service_id =
    hash.key?('shippingServiceId') ? hash['shippingServiceId'] : nil
  shipping_service_offer_id =
    hash.key?('shippingServiceOfferId') ? hash['shippingServiceOfferId'] : SKIP
  label_format = hash.key?('labelFormat') ? hash['labelFormat'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateShipmentRequest.new(shipment_request_details: shipment_request_details,
                            shipping_service_id: shipping_service_id,
                            shipping_service_offer_id: shipping_service_offer_id,
                            label_format: label_format,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['shipment_request_details'] = 'shipmentRequestDetails'
  @_hash['shipping_service_id'] = 'shippingServiceId'
  @_hash['shipping_service_offer_id'] = 'shippingServiceOfferId'
  @_hash['label_format'] = 'labelFormat'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 39

def self.optionals
  %w[
    shipping_service_offer_id
    label_format
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
110
111
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} shipment_request_details: #{@shipment_request_details.inspect},"\
  " shipping_service_id: #{@shipping_service_id.inspect}, shipping_service_offer_id:"\
  " #{@shipping_service_offer_id.inspect}, label_format: #{@label_format.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
101
102
# File 'lib/walmart_ap_is/models/create_shipment_request.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} shipment_request_details: #{@shipment_request_details},"\
  " shipping_service_id: #{@shipping_service_id}, shipping_service_offer_id:"\
  " #{@shipping_service_offer_id}, label_format: #{@label_format}, additional_properties:"\
  " #{@additional_properties}>"
end