Class: WalmartApIs::CreateUploadDestinationResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/create_upload_destination_response.rb

Overview

CreateUploadDestinationResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(upload_destination_id: SKIP, url: SKIP, headers: SKIP, additional_properties: nil) ⇒ CreateUploadDestinationResponse

Returns a new instance of CreateUploadDestinationResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 47

def initialize(upload_destination_id: SKIP, url: SKIP, headers: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @upload_destination_id = upload_destination_id unless upload_destination_id == SKIP
  @url = url unless url == SKIP
  @headers = headers unless headers == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#headersHash[String, String]

HTTP headers to include with the upload PUT request

Returns:

  • (Hash[String, String])


22
23
24
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 22

def headers
  @headers
end

#upload_destination_idString

The upload destination ID to pass when creating a feed or report

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 14

def upload_destination_id
  @upload_destination_id
end

#urlString

Pre-signed URL for a PUT upload (valid 15 minutes) — do not log

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 18

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  upload_destination_id =
    hash.key?('uploadDestinationId') ? hash['uploadDestinationId'] : SKIP
  url = hash.key?('url') ? hash['url'] : SKIP
  headers = hash.key?('headers') ? hash['headers'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateUploadDestinationResponse.new(upload_destination_id: upload_destination_id,
                                      url: url,
                                      headers: headers,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['upload_destination_id'] = 'uploadDestinationId'
  @_hash['url'] = 'url'
  @_hash['headers'] = 'headers'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 34

def self.optionals
  %w[
    upload_destination_id
    url
    headers
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} upload_destination_id: #{@upload_destination_id.inspect}, url:"\
  " #{@url.inspect}, headers: #{@headers.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/walmart_ap_is/models/create_upload_destination_response.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} upload_destination_id: #{@upload_destination_id}, url: #{@url}, headers:"\
  " #{@headers}, additional_properties: #{@additional_properties}>"
end