Class: WalmartApIs::DetailApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/walmart_ap_is/apis/detail_api.rb

Overview

DetailApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from WalmartApIs::BaseApi

Instance Method Details

#token_detail(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ ApiResponse

Returns OAuth token metadata and scopes granted by the seller to your application. Use this to verify whether a token is valid, when it expires, and which API categories are allowed (full_access, view_only, no_access). Send the access token in the ‘WM_SEC.ACCESS_TOKEN` header. You can also use this API for troubleshooting access failures and rendering “connected account” permissions in your UI. For more information and usage examples, refer to <a href=“developer.walmart.com/us-marketplace/docs/retrieve-access-to ken-details”>Retrieve access token details.</a> obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called.

Parameters:

  • wm_sec_access_token (String)

    Required parameter: Access token

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: A unique ID that

  • wm_svc_name (String)

    Required parameter: Specifies the name of the

  • accept (String)

    Required parameter: TODO: type description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/apis/detail_api.rb', line 31

def token_detail(wm_sec_access_token,
                 wm_consumer_channel_type,
                 wm_qos_correlation_id,
                 wm_svc_name,
                 accept)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/token/detail',
                                 Server::SERVER_1)
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')
                              .is_required(true))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')
                              .is_required(true))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')
                              .is_required(true))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')
                              .is_required(true))
               .header_param(new_parameter(accept, key: 'Accept')
                              .is_required(true))
               .auth(Single.new('basic')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation2.method(:from_hash))
                .is_api_response(true))
    .execute
end