Class: WalmartApIs::Dimensions
- Defined in:
- lib/walmart_ap_is/models/dimensions.rb
Overview
Measurement of a package's dimensions.
Instance Attribute Summary collapse
-
#height ⇒ Float
The height of a package.
-
#length ⇒ Float
The length of a package.
-
#unit_of_measurement ⇒ UnitOfMeasurement
Unit of linear measure.
-
#width ⇒ Float
The width of a package.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(height:, length:, width:, unit_of_measurement:, additional_properties: nil) ⇒ Dimensions
constructor
A new instance of Dimensions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(height:, length:, width:, unit_of_measurement:, additional_properties: nil) ⇒ Dimensions
Returns a new instance of Dimensions.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 48 def initialize(height:, length:, width:, unit_of_measurement:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @height = height @length = length @width = width @unit_of_measurement = unit_of_measurement @additional_properties = additional_properties end |
Instance Attribute Details
#height ⇒ Float
The height of a package.
14 15 16 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 14 def height @height end |
#length ⇒ Float
The length of a package.
18 19 20 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 18 def length @length end |
#unit_of_measurement ⇒ UnitOfMeasurement
Unit of linear measure.
26 27 28 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 26 def unit_of_measurement @unit_of_measurement end |
#width ⇒ Float
The width of a package.
22 23 24 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 22 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. height = hash.key?('height') ? hash['height'] : nil length = hash.key?('length') ? hash['length'] : nil width = hash.key?('width') ? hash['width'] : nil unit_of_measurement = hash.key?('unitOfMeasurement') ? hash['unitOfMeasurement'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Dimensions.new(height: height, length: length, width: width, unit_of_measurement: unit_of_measurement, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['height'] = 'height' @_hash['length'] = 'length' @_hash['width'] = 'width' @_hash['unit_of_measurement'] = 'unitOfMeasurement' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} height: #{@height.inspect}, length: #{@length.inspect}, width:"\ " #{@width.inspect}, unit_of_measurement: #{@unit_of_measurement.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 92 |
# File 'lib/walmart_ap_is/models/dimensions.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} height: #{@height}, length: #{@length}, width: #{@width},"\ " unit_of_measurement: #{@unit_of_measurement}, additional_properties:"\ " #{@additional_properties}>" end |