Class: WalmartApIs::DisbursementsV4FinalPayoutCaseUpdateStatusRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::DisbursementsV4FinalPayoutCaseUpdateStatusRequest
- Defined in:
- lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb
Overview
DisbursementsV4FinalPayoutCaseUpdateStatusRequest Model.
Instance Attribute Summary collapse
-
#notes ⇒ String
TODO: Write general description for this method.
-
#status ⇒ Status3
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status:, notes: SKIP, additional_properties: nil) ⇒ DisbursementsV4FinalPayoutCaseUpdateStatusRequest
constructor
A new instance of DisbursementsV4FinalPayoutCaseUpdateStatusRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status:, notes: SKIP, additional_properties: nil) ⇒ DisbursementsV4FinalPayoutCaseUpdateStatusRequest
Returns a new instance of DisbursementsV4FinalPayoutCaseUpdateStatusRequest.
40 41 42 43 44 45 46 47 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 40 def initialize(status:, notes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status @notes = notes unless notes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#notes ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 18 def notes @notes end |
#status ⇒ Status3
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 14 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil notes = hash.key?('notes') ? hash['notes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DisbursementsV4FinalPayoutCaseUpdateStatusRequest.new(status: status, notes: notes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['notes'] = 'notes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 29 def self.optionals %w[ notes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, notes: #{@notes.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/disbursements_v4_final_payout_case_update_status_request.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, notes: #{@notes}, additional_properties:"\ " #{@additional_properties}>" end |