Class: WalmartApIs::Document
- Defined in:
- lib/walmart_ap_is/models/document.rb
Overview
Document Model.
Instance Attribute Summary collapse
-
#compression_algorithm ⇒ CompressionAlgorithm
Pre-signed URL to download query result data — do not log.
-
#document_id ⇒ String
TODO: Write general description for this method.
-
#url ⇒ String
Pre-signed URL to download query result data — do not log.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(document_id:, url:, compression_algorithm: SKIP, additional_properties: nil) ⇒ Document
constructor
A new instance of Document.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(document_id:, url:, compression_algorithm: SKIP, additional_properties: nil) ⇒ Document
Returns a new instance of Document.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/walmart_ap_is/models/document.rb', line 45 def initialize(document_id:, url:, compression_algorithm: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @document_id = document_id @url = url @compression_algorithm = compression_algorithm unless compression_algorithm == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#compression_algorithm ⇒ CompressionAlgorithm
Pre-signed URL to download query result data — do not log
22 23 24 |
# File 'lib/walmart_ap_is/models/document.rb', line 22 def compression_algorithm @compression_algorithm end |
#document_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/document.rb', line 14 def document_id @document_id end |
#url ⇒ String
Pre-signed URL to download query result data — do not log
18 19 20 |
# File 'lib/walmart_ap_is/models/document.rb', line 18 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/walmart_ap_is/models/document.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. document_id = hash.key?('documentId') ? hash['documentId'] : nil url = hash.key?('url') ? hash['url'] : nil compression_algorithm = hash.key?('compressionAlgorithm') ? hash['compressionAlgorithm'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Document.new(document_id: document_id, url: url, compression_algorithm: compression_algorithm, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/document.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['document_id'] = 'documentId' @_hash['url'] = 'url' @_hash['compression_algorithm'] = 'compressionAlgorithm' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/walmart_ap_is/models/document.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/walmart_ap_is/models/document.rb', line 34 def self.optionals %w[ compression_algorithm ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/document.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} document_id: #{@document_id.inspect}, url: #{@url.inspect},"\ " compression_algorithm: #{@compression_algorithm.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/walmart_ap_is/models/document.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} document_id: #{@document_id}, url: #{@url}, compression_algorithm:"\ " #{@compression_algorithm}, additional_properties: #{@additional_properties}>" end |