Class: WalmartApIs::FasterPayoutEligibilityResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::FasterPayoutEligibilityResponse
- Defined in:
- lib/walmart_ap_is/models/faster_payout_eligibility_response.rb
Overview
FasterPayoutEligibilityResponse Model.
Instance Attribute Summary collapse
-
#available_amount ⇒ Money
TODO: Write general description for this method.
-
#ineligible_reason ⇒ String
TODO: Write general description for this method.
-
#is_eligible ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(is_eligible: SKIP, ineligible_reason: SKIP, available_amount: SKIP, additional_properties: nil) ⇒ FasterPayoutEligibilityResponse
constructor
A new instance of FasterPayoutEligibilityResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_eligible: SKIP, ineligible_reason: SKIP, available_amount: SKIP, additional_properties: nil) ⇒ FasterPayoutEligibilityResponse
Returns a new instance of FasterPayoutEligibilityResponse.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 47 def initialize(is_eligible: SKIP, ineligible_reason: SKIP, available_amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @is_eligible = is_eligible unless is_eligible == SKIP @ineligible_reason = ineligible_reason unless ineligible_reason == SKIP @available_amount = available_amount unless available_amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#available_amount ⇒ Money
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 22 def available_amount @available_amount end |
#ineligible_reason ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 18 def ineligible_reason @ineligible_reason end |
#is_eligible ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 14 def is_eligible @is_eligible end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_eligible = hash.key?('isEligible') ? hash['isEligible'] : SKIP ineligible_reason = hash.key?('ineligibleReason') ? hash['ineligibleReason'] : SKIP available_amount = Money.from_hash(hash['availableAmount']) if hash['availableAmount'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FasterPayoutEligibilityResponse.new(is_eligible: is_eligible, ineligible_reason: ineligible_reason, available_amount: available_amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['is_eligible'] = 'isEligible' @_hash['ineligible_reason'] = 'ineligibleReason' @_hash['available_amount'] = 'availableAmount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 34 def self.optionals %w[ is_eligible ineligible_reason available_amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_eligible: #{@is_eligible.inspect}, ineligible_reason:"\ " #{@ineligible_reason.inspect}, available_amount: #{@available_amount.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/walmart_ap_is/models/faster_payout_eligibility_response.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_eligible: #{@is_eligible}, ineligible_reason: #{@ineligible_reason},"\ " available_amount: #{@available_amount}, additional_properties: #{@additional_properties}>" end |