Class: WalmartApIs::FeaturedOffer

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/featured_offer.rb

Overview

A featured offer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(offer_identifier: SKIP, condition: SKIP, price: SKIP, additional_properties: nil) ⇒ FeaturedOffer

Returns a new instance of FeaturedOffer.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 47

def initialize(offer_identifier: SKIP, condition: SKIP, price: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @offer_identifier = offer_identifier unless offer_identifier == SKIP
  @condition = condition unless condition == SKIP
  @price = price unless price == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#conditionString

The item condition.

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 18

def condition
  @condition
end

#offer_identifierOfferIdentifier

Identifies an offer.

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 14

def offer_identifier
  @offer_identifier
end

#priceMoneyType

Currency type and monetary value.

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 22

def price
  @price
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  offer_identifier = OfferIdentifier.from_hash(hash['offerIdentifier']) if
    hash['offerIdentifier']
  condition = hash.key?('condition') ? hash['condition'] : SKIP
  price = MoneyType.from_hash(hash['price']) if hash['price']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FeaturedOffer.new(offer_identifier: offer_identifier,
                    condition: condition,
                    price: price,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['offer_identifier'] = 'offerIdentifier'
  @_hash['condition'] = 'condition'
  @_hash['price'] = 'price'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 34

def self.optionals
  %w[
    offer_identifier
    condition
    price
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} offer_identifier: #{@offer_identifier.inspect}, condition:"\
  " #{@condition.inspect}, price: #{@price.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/walmart_ap_is/models/featured_offer.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} offer_identifier: #{@offer_identifier}, condition: #{@condition}, price:"\
  " #{@price}, additional_properties: #{@additional_properties}>"
end