Class: WalmartApIs::FeaturedOfferExpectedPrice
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::FeaturedOfferExpectedPrice
- Defined in:
- lib/walmart_ap_is/models/featured_offer_expected_price.rb
Overview
The featured offer expected price for a given SKU.
Instance Attribute Summary collapse
-
#listing_price ⇒ MoneyType
Currency type and monetary value.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(listing_price: SKIP, additional_properties: nil) ⇒ FeaturedOfferExpectedPrice
constructor
A new instance of FeaturedOfferExpectedPrice.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(listing_price: SKIP, additional_properties: nil) ⇒ FeaturedOfferExpectedPrice
Returns a new instance of FeaturedOfferExpectedPrice.
35 36 37 38 39 40 41 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 35 def initialize(listing_price: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @listing_price = listing_price unless listing_price == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#listing_price ⇒ MoneyType
Currency type and monetary value.
14 15 16 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 14 def listing_price @listing_price end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. listing_price = MoneyType.from_hash(hash['listingPrice']) if hash['listingPrice'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FeaturedOfferExpectedPrice.new(listing_price: listing_price, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['listing_price'] = 'listingPrice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 24 def self.optionals %w[ listing_price ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 74 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} listing_price: #{@listing_price.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 67 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} listing_price: #{@listing_price}, additional_properties:"\ " #{@additional_properties}>" end |