Class: WalmartApIs::FeaturedOfferExpectedPriceRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::FeaturedOfferExpectedPriceRequest
- Defined in:
- lib/walmart_ap_is/models/featured_offer_expected_price_request.rb
Overview
An individual FOEP request for a particular SKU.
Instance Attribute Summary collapse
-
#marketplace_id ⇒ String
A marketplace identifier.
-
#sku ⇒ String
The seller stock keeping unit (SKU) of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id:, sku:, additional_properties: nil) ⇒ FeaturedOfferExpectedPriceRequest
constructor
A new instance of FeaturedOfferExpectedPriceRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id:, sku:, additional_properties: nil) ⇒ FeaturedOfferExpectedPriceRequest
Returns a new instance of FeaturedOfferExpectedPriceRequest.
38 39 40 41 42 43 44 45 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 38 def initialize(marketplace_id:, sku:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id @sku = sku @additional_properties = additional_properties end |
Instance Attribute Details
#marketplace_id ⇒ String
A marketplace identifier.
14 15 16 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 14 def marketplace_id @marketplace_id end |
#sku ⇒ String
The seller stock keeping unit (SKU) of the item.
18 19 20 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 18 def sku @sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : nil sku = hash.key?('sku') ? hash['sku'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FeaturedOfferExpectedPriceRequest.new(marketplace_id: marketplace_id, sku: sku, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'marketplaceId' @_hash['sku'] = 'sku' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, sku: #{@sku.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/walmart_ap_is/models/featured_offer_expected_price_request.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, sku: #{@sku}, additional_properties:"\ " #{@additional_properties}>" end |