Class: WalmartApIs::FeedDocument

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/feed_document.rb

Overview

FeedDocument Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(feed_document_id:, url:, compression_algorithm: SKIP, additional_properties: nil) ⇒ FeedDocument

Returns a new instance of FeedDocument.



45
46
47
48
49
50
51
52
53
54
# File 'lib/walmart_ap_is/models/feed_document.rb', line 45

def initialize(feed_document_id:, url:, compression_algorithm: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @feed_document_id = feed_document_id
  @url = url
  @compression_algorithm = compression_algorithm unless compression_algorithm == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#compression_algorithmCompressionAlgorithm

Compression applied to the document; decompress before parsing if present



22
23
24
# File 'lib/walmart_ap_is/models/feed_document.rb', line 22

def compression_algorithm
  @compression_algorithm
end

#feed_document_idString

Unique identifier for this feed result document

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/feed_document.rb', line 14

def feed_document_id
  @feed_document_id
end

#urlString

Pre-signed URL to download the document (valid 15 minutes) — do not log

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/feed_document.rb', line 18

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/feed_document.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  feed_document_id =
    hash.key?('feedDocumentId') ? hash['feedDocumentId'] : nil
  url = hash.key?('url') ? hash['url'] : nil
  compression_algorithm =
    hash.key?('compressionAlgorithm') ? hash['compressionAlgorithm'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FeedDocument.new(feed_document_id: feed_document_id,
                   url: url,
                   compression_algorithm: compression_algorithm,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/feed_document.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['feed_document_id'] = 'feedDocumentId'
  @_hash['url'] = 'url'
  @_hash['compression_algorithm'] = 'compressionAlgorithm'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/walmart_ap_is/models/feed_document.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/walmart_ap_is/models/feed_document.rb', line 34

def self.optionals
  %w[
    compression_algorithm
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/walmart_ap_is/models/feed_document.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} feed_document_id: #{@feed_document_id.inspect}, url: #{@url.inspect},"\
  " compression_algorithm: #{@compression_algorithm.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
87
# File 'lib/walmart_ap_is/models/feed_document.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} feed_document_id: #{@feed_document_id}, url: #{@url},"\
  " compression_algorithm: #{@compression_algorithm}, additional_properties:"\
  " #{@additional_properties}>"
end