Class: WalmartApIs::FeedsFeedTypeWalmartFundedIncentivesEnrollmentApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/walmart_ap_is/apis/feeds_feed_type_walmart_funded_incentives_enrollment_api.rb

Overview

FeedsFeedTypeWalmartFundedIncentivesEnrollmentApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from WalmartApIs::BaseApi

Instance Method Details

#update_walmart_funded_incentives_enrollment_for_specific_items(feed_type, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ ApiResponse

Updates the enrollment status of specific items in the Walmart-funded incentives program. By default, all items are auto-enrolled in Walmart-funded incentives, meaning that eligible items are automatically included in this program to benefit from price reductions funded by Walmart. You have the flexibility to modify the enrollment status for specific items using this API: <ul><li>Opt-Out - Use this option to opt-out of Walmart-funded incentives for specific items for which you do not want to lower the price.</li> <li>Opt-in - Use this option to opt-in items that were previously opted-out from Walmart-funded incentives. For instance, you can re-enroll items in Walmart-funded incentives programs at any time depending on your business needs.</li></ul> For more information and usage examples, refer to the <a href=“developer.walmart.com/us-marketplace/docs/manage-enrollment- specific-items-in-walmart-funded-incentives”>Pricing API Guide</a>. here obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called. body Required parameter: TODO: type description here

Parameters:

  • feed_type (String)

    Required parameter: TODO: type description

  • wm_sec_access_token (String)

    Required parameter: Access token

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: A unique ID that

  • wm_svc_name (String)

    Required parameter: Specifies the name of the

  • accept (String)

    Required parameter: TODO: type description here

  • (UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest)

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/walmart_ap_is/apis/feeds_feed_type_walmart_funded_incentives_enrollment_api.rb', line 41

def update_walmart_funded_incentives_enrollment_for_specific_items(feed_type,
                                                                   wm_sec_access_token,
                                                                   wm_consumer_channel_type,
                                                                   wm_qos_correlation_id,
                                                                   wm_svc_name,
                                                                   accept,
                                                                   body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/feeds',
                                 Server::SERVER_1)
               .query_param(new_parameter(feed_type, key: 'feedType')
                             .is_required(true))
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')
                              .is_required(true))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')
                              .is_required(true))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')
                              .is_required(true))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(accept, key: 'Accept')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation8.method(:from_hash))
                .is_api_response(true))
    .execute
end