Class: WalmartApIs::FinalPayoutCaseStatusResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::FinalPayoutCaseStatusResponse
- Defined in:
- lib/walmart_ap_is/models/final_payout_case_status_response.rb
Overview
FinalPayoutCaseStatusResponse Model.
Instance Attribute Summary collapse
-
#amount ⇒ Money
TODO: Write general description for this method.
-
#case_id ⇒ String
TODO: Write general description for this method.
-
#status ⇒ Status21
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(case_id: SKIP, status: SKIP, amount: SKIP, additional_properties: nil) ⇒ FinalPayoutCaseStatusResponse
constructor
A new instance of FinalPayoutCaseStatusResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(case_id: SKIP, status: SKIP, amount: SKIP, additional_properties: nil) ⇒ FinalPayoutCaseStatusResponse
Returns a new instance of FinalPayoutCaseStatusResponse.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 47 def initialize(case_id: SKIP, status: SKIP, amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @case_id = case_id unless case_id == SKIP @status = status unless status == SKIP @amount = amount unless amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Money
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 22 def amount @amount end |
#case_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 14 def case_id @case_id end |
#status ⇒ Status21
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. case_id = hash.key?('caseId') ? hash['caseId'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP amount = Money.from_hash(hash['amount']) if hash['amount'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FinalPayoutCaseStatusResponse.new(case_id: case_id, status: status, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['case_id'] = 'caseId' @_hash['status'] = 'status' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 34 def self.optionals %w[ case_id status amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} case_id: #{@case_id.inspect}, status: #{@status.inspect}, amount:"\ " #{@amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/final_payout_case_status_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} case_id: #{@case_id}, status: #{@status}, amount: #{@amount},"\ " additional_properties: #{@additional_properties}>" end |