Class: WalmartApIs::FulfillmentAvailability

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/fulfillment_availability.rb

Overview

FulfillmentAvailability Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(fulfillment_channel_code: SKIP, quantity: SKIP, lead_time_to_deploy: SKIP, additional_properties: nil) ⇒ FulfillmentAvailability

Returns a new instance of FulfillmentAvailability.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 47

def initialize(fulfillment_channel_code: SKIP, quantity: SKIP,
               lead_time_to_deploy: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @fulfillment_channel_code = fulfillment_channel_code unless fulfillment_channel_code == SKIP
  @quantity = quantity unless quantity == SKIP
  @lead_time_to_deploy = lead_time_to_deploy unless lead_time_to_deploy == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fulfillment_channel_codeFulfillmentChannelCode

TODO: Write general description for this method



14
15
16
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 14

def fulfillment_channel_code
  @fulfillment_channel_code
end

#lead_time_to_deployString

ISO 8601 duration (e.g. PT2D for 2-day lead time)

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 22

def lead_time_to_deploy
  @lead_time_to_deploy
end

#quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 18

def quantity
  @quantity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  fulfillment_channel_code =
    hash.key?('fulfillmentChannelCode') ? hash['fulfillmentChannelCode'] : SKIP
  quantity = hash.key?('quantity') ? hash['quantity'] : SKIP
  lead_time_to_deploy =
    hash.key?('leadTimeToDeploy') ? hash['leadTimeToDeploy'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FulfillmentAvailability.new(fulfillment_channel_code: fulfillment_channel_code,
                              quantity: quantity,
                              lead_time_to_deploy: lead_time_to_deploy,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['fulfillment_channel_code'] = 'fulfillmentChannelCode'
  @_hash['quantity'] = 'quantity'
  @_hash['lead_time_to_deploy'] = 'leadTimeToDeploy'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 34

def self.optionals
  %w[
    fulfillment_channel_code
    quantity
    lead_time_to_deploy
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} fulfillment_channel_code: #{@fulfillment_channel_code.inspect}, quantity:"\
  " #{@quantity.inspect}, lead_time_to_deploy: #{@lead_time_to_deploy.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/walmart_ap_is/models/fulfillment_availability.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} fulfillment_channel_code: #{@fulfillment_channel_code}, quantity:"\
  " #{@quantity}, lead_time_to_deploy: #{@lead_time_to_deploy}, additional_properties:"\
  " #{@additional_properties}>"
end