Class: WalmartApIs::GenerateSelfShipAppointmentSlotsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::GenerateSelfShipAppointmentSlotsRequest
- Defined in:
- lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb
Overview
The generateSelfShipAppointmentSlots request.
Instance Attribute Summary collapse
-
#desired_end_date ⇒ DateTime
The desired end date.
-
#desired_start_date ⇒ DateTime
The desired start date.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(desired_end_date: SKIP, desired_start_date: SKIP, additional_properties: nil) ⇒ GenerateSelfShipAppointmentSlotsRequest
constructor
A new instance of GenerateSelfShipAppointmentSlotsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_desired_end_date ⇒ Object
- #to_custom_desired_start_date ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(desired_end_date: SKIP, desired_start_date: SKIP, additional_properties: nil) ⇒ GenerateSelfShipAppointmentSlotsRequest
Returns a new instance of GenerateSelfShipAppointmentSlotsRequest.
42 43 44 45 46 47 48 49 50 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 42 def initialize(desired_end_date: SKIP, desired_start_date: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @desired_end_date = desired_end_date unless desired_end_date == SKIP @desired_start_date = desired_start_date unless desired_start_date == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#desired_end_date ⇒ DateTime
The desired end date. In ISO 8601 datetime format.
15 16 17 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 15 def desired_end_date @desired_end_date end |
#desired_start_date ⇒ DateTime
The desired start date. In ISO 8601 datetime format.
19 20 21 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 19 def desired_start_date @desired_start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. desired_end_date = if hash.key?('desiredEndDate') (DateTimeHelper.from_rfc3339(hash['desiredEndDate']) if hash['desiredEndDate']) else SKIP end desired_start_date = if hash.key?('desiredStartDate') (DateTimeHelper.from_rfc3339(hash['desiredStartDate']) if hash['desiredStartDate']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GenerateSelfShipAppointmentSlotsRequest.new(desired_end_date: desired_end_date, desired_start_date: desired_start_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['desired_end_date'] = 'desiredEndDate' @_hash['desired_start_date'] = 'desiredStartDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 30 def self.optionals %w[ desired_end_date desired_start_date ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} desired_end_date: #{@desired_end_date.inspect}, desired_start_date:"\ " #{@desired_start_date.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_desired_end_date ⇒ Object
81 82 83 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 81 def to_custom_desired_end_date DateTimeHelper.to_rfc3339(desired_end_date) end |
#to_custom_desired_start_date ⇒ Object
85 86 87 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 85 def to_custom_desired_start_date DateTimeHelper.to_rfc3339(desired_start_date) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/walmart_ap_is/models/generate_self_ship_appointment_slots_request.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} desired_end_date: #{@desired_end_date}, desired_start_date:"\ " #{@desired_start_date}, additional_properties: #{@additional_properties}>" end |