Class: WalmartApIs::GetEligibleShippingServicesRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::GetEligibleShippingServicesRequest
- Defined in:
- lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb
Overview
GetEligibleShippingServicesRequest Model.
Instance Attribute Summary collapse
-
#shipment_request_details ⇒ ShipmentRequestDetails
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shipment_request_details:, additional_properties: nil) ⇒ GetEligibleShippingServicesRequest
constructor
A new instance of GetEligibleShippingServicesRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shipment_request_details:, additional_properties: nil) ⇒ GetEligibleShippingServicesRequest
Returns a new instance of GetEligibleShippingServicesRequest.
33 34 35 36 37 38 39 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 33 def initialize(shipment_request_details:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @shipment_request_details = shipment_request_details @additional_properties = additional_properties end |
Instance Attribute Details
#shipment_request_details ⇒ ShipmentRequestDetails
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 14 def shipment_request_details @shipment_request_details end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. shipment_request_details = ShipmentRequestDetails.from_hash(hash['shipmentRequestDetails']) if hash['shipmentRequestDetails'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetEligibleShippingServicesRequest.new(shipment_request_details: shipment_request_details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['shipment_request_details'] = 'shipmentRequestDetails' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} shipment_request_details: #{@shipment_request_details.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_request.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} shipment_request_details: #{@shipment_request_details},"\ " additional_properties: #{@additional_properties}>" end |