Class: WalmartApIs::GetFeedsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/get_feeds_response.rb

Overview

GetFeedsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(feeds: SKIP, next_token: SKIP, additional_properties: nil) ⇒ GetFeedsResponse

Returns a new instance of GetFeedsResponse.



42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 42

def initialize(feeds: SKIP, next_token: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @feeds = feeds unless feeds == SKIP
  @next_token = next_token unless next_token == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#feedsArray[Feed]

List of feeds matching the request filters

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 14

def feeds
  @feeds
end

#next_tokenString

Token to retrieve the next page of results; absent when no more pages exist

Returns:

  • (String)


19
20
21
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 19

def next_token
  @next_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  feeds = nil
  unless hash['feeds'].nil?
    feeds = []
    hash['feeds'].each do |structure|
      feeds << (Feed.from_hash(structure) if structure)
    end
  end

  feeds = SKIP unless hash.key?('feeds')
  next_token = hash.key?('nextToken') ? hash['nextToken'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetFeedsResponse.new(feeds: feeds,
                       next_token: next_token,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['feeds'] = 'feeds'
  @_hash['next_token'] = 'nextToken'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 30

def self.optionals
  %w[
    feeds
    next_token
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} feeds: #{@feeds.inspect}, next_token: #{@next_token.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/walmart_ap_is/models/get_feeds_response.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} feeds: #{@feeds}, next_token: #{@next_token}, additional_properties:"\
  " #{@additional_properties}>"
end