Class: WalmartApIs::GetMyFeesEstimateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::GetMyFeesEstimateResponse
- Defined in:
- lib/walmart_ap_is/models/get_my_fees_estimate_response.rb
Overview
Response for single-item fee estimate endpoints. Mirrors SP-API GetMyFeesEstimateResponse.
Instance Attribute Summary collapse
-
#errors ⇒ ErrorList
Wraps the fee estimate result for a single-item endpoint.
-
#payload ⇒ GetMyFeesEstimateResult
Wraps the fee estimate result for a single-item endpoint.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payload: SKIP, errors: SKIP, additional_properties: nil) ⇒ GetMyFeesEstimateResponse
constructor
A new instance of GetMyFeesEstimateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payload: SKIP, errors: SKIP, additional_properties: nil) ⇒ GetMyFeesEstimateResponse
Returns a new instance of GetMyFeesEstimateResponse.
42 43 44 45 46 47 48 49 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 42 def initialize(payload: SKIP, errors: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payload = payload unless payload == SKIP @errors = errors unless errors == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#errors ⇒ ErrorList
Wraps the fee estimate result for a single-item endpoint.
19 20 21 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 19 def errors @errors end |
#payload ⇒ GetMyFeesEstimateResult
Wraps the fee estimate result for a single-item endpoint.
15 16 17 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 15 def payload @payload end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payload = GetMyFeesEstimateResult.from_hash(hash['payload']) if hash['payload'] errors = ErrorList.from_hash(hash['errors']) if hash['errors'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetMyFeesEstimateResponse.new(payload: payload, errors: errors, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['payload'] = 'payload' @_hash['errors'] = 'errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 30 def self.optionals %w[ payload errors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} payload: #{@payload.inspect}, errors: #{@errors.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/walmart_ap_is/models/get_my_fees_estimate_response.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} payload: #{@payload}, errors: #{@errors}, additional_properties:"\ " #{@additional_properties}>" end |