Class: WalmartApIs::GetOffersHttpStatusLine

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/get_offers_http_status_line.rb

Overview

The HTTP status line associated with the response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status_code: SKIP, reason_phrase: SKIP, additional_properties: nil) ⇒ GetOffersHttpStatusLine

Returns a new instance of GetOffersHttpStatusLine.



41
42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 41

def initialize(status_code: SKIP, reason_phrase: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status_code = status_code unless status_code == SKIP
  @reason_phrase = reason_phrase unless reason_phrase == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reason_phraseString

The HTTP response Reason-Phrase.

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 18

def reason_phrase
  @reason_phrase
end

#status_codeInteger

The HTTP response Status Code.

Returns:

  • (Integer)


14
15
16
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 14

def status_code
  @status_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status_code = hash.key?('statusCode') ? hash['statusCode'] : SKIP
  reason_phrase = hash.key?('reasonPhrase') ? hash['reasonPhrase'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetOffersHttpStatusLine.new(status_code: status_code,
                              reason_phrase: reason_phrase,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status_code'] = 'statusCode'
  @_hash['reason_phrase'] = 'reasonPhrase'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 29

def self.optionals
  %w[
    status_code
    reason_phrase
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status_code: #{@status_code.inspect}, reason_phrase:"\
  " #{@reason_phrase.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/walmart_ap_is/models/get_offers_http_status_line.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status_code: #{@status_code}, reason_phrase: #{@reason_phrase},"\
  " additional_properties: #{@additional_properties}>"
end