Class: WalmartApIs::GetOrderRegulatedInfoResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/get_order_regulated_info_response.rb

Overview

GetOrderRegulatedInfoResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payload: SKIP, additional_properties: nil) ⇒ GetOrderRegulatedInfoResponse

Returns a new instance of GetOrderRegulatedInfoResponse.



38
39
40
41
42
43
44
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 38

def initialize(payload: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payload = payload unless payload == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#payloadRegulatedInfo

Verification requirements for an order containing regulated items. Mirrors Amazon SP-API Orders v0 RegulatedInformation plus a regulatedCategory discriminator so a caller can short- circuit when the order is not regulated at all.

Returns:



17
18
19
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 17

def payload
  @payload
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payload = RegulatedInfo.from_hash(hash['payload']) if hash['payload']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetOrderRegulatedInfoResponse.new(payload: payload,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payload'] = 'payload'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
30
31
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 27

def self.optionals
  %w[
    payload
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payload: #{@payload.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
# File 'lib/walmart_ap_is/models/get_order_regulated_info_response.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payload: #{@payload}, additional_properties: #{@additional_properties}>"
end