Class: WalmartApIs::GetPricingInsightsRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/get_pricing_insights_request.rb

Overview

GetPricingInsightsRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(filter:, search_criteria:, sort:, page_number:, additional_properties: nil) ⇒ GetPricingInsightsRequest

Returns a new instance of GetPricingInsightsRequest.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 48

def initialize(filter:, search_criteria:, sort:, page_number:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @filter = filter
  @search_criteria = search_criteria
  @sort = sort
  @page_number = page_number
  @additional_properties = additional_properties
end

Instance Attribute Details

#filterArray[Filter]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 14

def filter
  @filter
end

#page_numberInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 26

def page_number
  @page_number
end

#search_criteriaSearchCriteria

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 18

def search_criteria
  @search_criteria
end

#sortSort

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 22

def sort
  @sort
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  filter = nil
  unless hash['filter'].nil?
    filter = []
    hash['filter'].each do |structure|
      filter << (Filter.from_hash(structure) if structure)
    end
  end

  filter = nil unless hash.key?('filter')
  search_criteria = SearchCriteria.from_hash(hash['searchCriteria']) if hash['searchCriteria']
  sort = Sort.from_hash(hash['sort']) if hash['sort']
  page_number = hash.key?('pageNumber') ? hash['pageNumber'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetPricingInsightsRequest.new(filter: filter,
                                search_criteria: search_criteria,
                                sort: sort,
                                page_number: page_number,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['filter'] = 'filter'
  @_hash['search_criteria'] = 'searchCriteria'
  @_hash['sort'] = 'sort'
  @_hash['page_number'] = 'pageNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} filter: #{@filter.inspect}, search_criteria: #{@search_criteria.inspect},"\
  " sort: #{@sort.inspect}, page_number: #{@page_number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/walmart_ap_is/models/get_pricing_insights_request.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} filter: #{@filter}, search_criteria: #{@search_criteria}, sort: #{@sort},"\
  " page_number: #{@page_number}, additional_properties: #{@additional_properties}>"
end