Class: WalmartApIs::GetSelfShipAppointmentSlotsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb

Overview

The getSelfShipAppointmentSlots response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(self_ship_appointment_slots_availability:, pagination: SKIP, additional_properties: nil) ⇒ GetSelfShipAppointmentSlotsResponse

Returns a new instance of GetSelfShipAppointmentSlotsResponse.



42
43
44
45
46
47
48
49
50
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 42

def initialize(self_ship_appointment_slots_availability:, pagination: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @pagination = pagination unless pagination == SKIP
  @self_ship_appointment_slots_availability = self_ship_appointment_slots_availability
  @additional_properties = additional_properties
end

Instance Attribute Details

#paginationPagination4

Contains tokens to fetch from a certain page.

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 14

def pagination
  @pagination
end

#self_ship_appointment_slots_availabilitySelfShipAppointmentSlotsAvailability

The self ship appointment time slots availability and an expiration date for which the slots can be scheduled.



19
20
21
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 19

def self_ship_appointment_slots_availability
  @self_ship_appointment_slots_availability
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  if hash['selfShipAppointmentSlotsAvailability']
    self_ship_appointment_slots_availability = SelfShipAppointmentSlotsAvailability.from_hash(hash['selfShipAppointmentSlotsAvailability'])
  end
  pagination = Pagination4.from_hash(hash['pagination']) if hash['pagination']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetSelfShipAppointmentSlotsResponse.new(self_ship_appointment_slots_availability: self_ship_appointment_slots_availability,
                                          pagination: pagination,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
28
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['pagination'] = 'pagination'
  @_hash['self_ship_appointment_slots_availability'] =
    'selfShipAppointmentSlotsAvailability'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 31

def self.optionals
  %w[
    pagination
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
89
90
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} pagination: #{@pagination.inspect},"\
  ' self_ship_appointment_slots_availability:'\
  " #{@self_ship_appointment_slots_availability.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
81
# File 'lib/walmart_ap_is/models/get_self_ship_appointment_slots_response.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} pagination: #{@pagination}, self_ship_appointment_slots_availability:"\
  " #{@self_ship_appointment_slots_availability}, additional_properties:"\
  " #{@additional_properties}>"
end