Class: WalmartApIs::HttpResponseHeaders

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/http_response_headers.rb

Overview

A mapping of additional HTTP headers to receive for the individual batch request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(date: SKIP, x_request_id: SKIP, additional_properties: nil) ⇒ HttpResponseHeaders

Returns a new instance of HttpResponseHeaders.



42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 42

def initialize(date: SKIP, x_request_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @date = date unless date == SKIP
  @x_request_id = x_request_id unless x_request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dateString

The timestamp that the API request was received.

Returns:

  • (String)


15
16
17
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 15

def date
  @date
end

#x_request_idString

Unique request reference identifier.

Returns:

  • (String)


19
20
21
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 19

def x_request_id
  @x_request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  date = hash.key?('Date') ? hash['Date'] : SKIP
  x_request_id = hash.key?('X-Request-Id') ? hash['X-Request-Id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  HttpResponseHeaders.new(date: date,
                          x_request_id: x_request_id,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['date'] = 'Date'
  @_hash['x_request_id'] = 'X-Request-Id'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 30

def self.optionals
  %w[
    date
    x_request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date.inspect}, x_request_id: #{@x_request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/walmart_ap_is/models/http_response_headers.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date}, x_request_id: #{@x_request_id}, additional_properties:"\
  " #{@additional_properties}>"
end