Class: WalmartApIs::IneligibleRate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/ineligible_rate.rb

Overview

IneligibleRate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(carrier_name: SKIP, service_name: SKIP, ineligibility_reasons: SKIP, additional_properties: nil) ⇒ IneligibleRate

Returns a new instance of IneligibleRate.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 47

def initialize(carrier_name: SKIP, service_name: SKIP,
               ineligibility_reasons: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @carrier_name = carrier_name unless carrier_name == SKIP
  @service_name = service_name unless service_name == SKIP
  @ineligibility_reasons = ineligibility_reasons unless ineligibility_reasons == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#carrier_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 14

def carrier_name
  @carrier_name
end

#ineligibility_reasonsArray[IneligibilityReason]

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 22

def ineligibility_reasons
  @ineligibility_reasons
end

#service_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 18

def service_name
  @service_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  carrier_name = hash.key?('carrierName') ? hash['carrierName'] : SKIP
  service_name = hash.key?('serviceName') ? hash['serviceName'] : SKIP
  # Parameter is an array, so we need to iterate through it
  ineligibility_reasons = nil
  unless hash['ineligibilityReasons'].nil?
    ineligibility_reasons = []
    hash['ineligibilityReasons'].each do |structure|
      ineligibility_reasons << (IneligibilityReason.from_hash(structure) if structure)
    end
  end

  ineligibility_reasons = SKIP unless hash.key?('ineligibilityReasons')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IneligibleRate.new(carrier_name: carrier_name,
                     service_name: service_name,
                     ineligibility_reasons: ineligibility_reasons,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['carrier_name'] = 'carrierName'
  @_hash['service_name'] = 'serviceName'
  @_hash['ineligibility_reasons'] = 'ineligibilityReasons'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 34

def self.optionals
  %w[
    carrier_name
    service_name
    ineligibility_reasons
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_name: #{@carrier_name.inspect}, service_name:"\
  " #{@service_name.inspect}, ineligibility_reasons: #{@ineligibility_reasons.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
96
# File 'lib/walmart_ap_is/models/ineligible_rate.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_name: #{@carrier_name}, service_name: #{@service_name},"\
  " ineligibility_reasons: #{@ineligibility_reasons}, additional_properties:"\
  " #{@additional_properties}>"
end