Class: WalmartApIs::ItemIdentifier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/item_identifier.rb

Overview

ItemIdentifier Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(identifier_type: SKIP, identifier: SKIP, marketplace_id: SKIP, additional_properties: nil) ⇒ ItemIdentifier

Returns a new instance of ItemIdentifier.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 47

def initialize(identifier_type: SKIP, identifier: SKIP,
               marketplace_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @identifier_type = identifier_type unless identifier_type == SKIP
  @identifier = identifier unless identifier == SKIP
  @marketplace_id = marketplace_id unless marketplace_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#identifierString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 18

def identifier
  @identifier
end

#identifier_typeIdentifierType

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 14

def identifier_type
  @identifier_type
end

#marketplace_idString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 22

def marketplace_id
  @marketplace_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  identifier_type =
    hash.key?('identifierType') ? hash['identifierType'] : SKIP
  identifier = hash.key?('identifier') ? hash['identifier'] : SKIP
  marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemIdentifier.new(identifier_type: identifier_type,
                     identifier: identifier,
                     marketplace_id: marketplace_id,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['identifier_type'] = 'identifierType'
  @_hash['identifier'] = 'identifier'
  @_hash['marketplace_id'] = 'marketplaceId'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 34

def self.optionals
  %w[
    identifier_type
    identifier
    marketplace_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} identifier_type: #{@identifier_type.inspect}, identifier:"\
  " #{@identifier.inspect}, marketplace_id: #{@marketplace_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/walmart_ap_is/models/item_identifier.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} identifier_type: #{@identifier_type}, identifier: #{@identifier},"\
  " marketplace_id: #{@marketplace_id}, additional_properties: #{@additional_properties}>"
end