Class: WalmartApIs::ItemImage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/item_image.rb

Overview

ItemImage Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(variant: SKIP, link: SKIP, height: SKIP, width: SKIP, additional_properties: nil) ⇒ ItemImage

Returns a new instance of ItemImage.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/walmart_ap_is/models/item_image.rb', line 53

def initialize(variant: SKIP, link: SKIP, height: SKIP, width: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @variant = variant unless variant == SKIP
  @link = link unless link == SKIP
  @height = height unless height == SKIP
  @width = width unless width == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#heightInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/walmart_ap_is/models/item_image.rb', line 22

def height
  @height
end

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/item_image.rb', line 18

def link
  @link
end

#variantVariant

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/item_image.rb', line 14

def variant
  @variant
end

#widthInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/walmart_ap_is/models/item_image.rb', line 26

def width
  @width
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/walmart_ap_is/models/item_image.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  variant = hash.key?('variant') ? hash['variant'] : SKIP
  link = hash.key?('link') ? hash['link'] : SKIP
  height = hash.key?('height') ? hash['height'] : SKIP
  width = hash.key?('width') ? hash['width'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemImage.new(variant: variant,
                link: link,
                height: height,
                width: width,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/item_image.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['variant'] = 'variant'
  @_hash['link'] = 'link'
  @_hash['height'] = 'height'
  @_hash['width'] = 'width'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/walmart_ap_is/models/item_image.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/walmart_ap_is/models/item_image.rb', line 39

def self.optionals
  %w[
    variant
    link
    height
    width
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/walmart_ap_is/models/item_image.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} variant: #{@variant.inspect}, link: #{@link.inspect}, height:"\
  " #{@height.inspect}, width: #{@width.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/walmart_ap_is/models/item_image.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} variant: #{@variant}, link: #{@link}, height: #{@height}, width: #{@width},"\
  " additional_properties: #{@additional_properties}>"
end