Class: WalmartApIs::ItemImage1
- Defined in:
- lib/walmart_ap_is/models/item_image1.rb
Overview
ItemImage1 Model.
Instance Attribute Summary collapse
-
#height ⇒ Integer
TODO: Write general description for this method.
-
#link ⇒ String
TODO: Write general description for this method.
-
#width ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(link: SKIP, height: SKIP, width: SKIP, additional_properties: nil) ⇒ ItemImage1
constructor
A new instance of ItemImage1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(link: SKIP, height: SKIP, width: SKIP, additional_properties: nil) ⇒ ItemImage1
Returns a new instance of ItemImage1.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 47 def initialize(link: SKIP, height: SKIP, width: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @link = link unless link == SKIP @height = height unless height == SKIP @width = width unless width == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#height ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 18 def height @height end |
#link ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 14 def link @link end |
#width ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 22 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. link = hash.key?('link') ? hash['link'] : SKIP height = hash.key?('height') ? hash['height'] : SKIP width = hash.key?('width') ? hash['width'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemImage1.new(link: link, height: height, width: width, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['link'] = 'link' @_hash['height'] = 'height' @_hash['width'] = 'width' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 34 def self.optionals %w[ link height width ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} link: #{@link.inspect}, height: #{@height.inspect}, width:"\ " #{@width.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/item_image1.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} link: #{@link}, height: #{@height}, width: #{@width},"\ " additional_properties: #{@additional_properties}>" end |