Class: WalmartApIs::Link

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/link.rb

Overview

Link Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(resource:, title: SKIP, type: SKIP, additional_properties: nil) ⇒ Link

Returns a new instance of Link.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/walmart_ap_is/models/link.rb', line 51

def initialize(resource:, title: SKIP, type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @resource = resource
  @verb = 'GET'
  @title = title unless title == SKIP
  @type = type unless type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#resourceString

URI to resolve the restriction (e.g. approval request URL)

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/link.rb', line 14

def resource
  @resource
end

#titleString

URI to resolve the restriction (e.g. approval request URL)

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/link.rb', line 22

def title
  @title
end

#typeString

URI to resolve the restriction (e.g. approval request URL)

Returns:

  • (String)


26
27
28
# File 'lib/walmart_ap_is/models/link.rb', line 26

def type
  @type
end

#verbString (readonly)

URI to resolve the restriction (e.g. approval request URL)

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/link.rb', line 18

def verb
  @verb
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/walmart_ap_is/models/link.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  resource = hash.key?('resource') ? hash['resource'] : nil
  title = hash.key?('title') ? hash['title'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Link.new(resource: resource,
           title: title,
           type: type,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/link.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['resource'] = 'resource'
  @_hash['verb'] = 'verb'
  @_hash['title'] = 'title'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/walmart_ap_is/models/link.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
# File 'lib/walmart_ap_is/models/link.rb', line 39

def self.optionals
  %w[
    title
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/walmart_ap_is/models/link.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} resource: #{@resource.inspect}, verb: #{@verb.inspect}, title:"\
  " #{@title.inspect}, type: #{@type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/walmart_ap_is/models/link.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} resource: #{@resource}, verb: #{@verb}, title: #{@title}, type: #{@type},"\
  " additional_properties: #{@additional_properties}>"
end