Class: WalmartApIs::ListAllFulfillmentOrdersResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ListAllFulfillmentOrdersResponse
- Defined in:
- lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb
Overview
ListAllFulfillmentOrdersResponse Model.
Instance Attribute Summary collapse
-
#fulfillment_orders ⇒ Array[FulfillmentOrder]
TODO: Write general description for this method.
-
#next_token ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(next_token: SKIP, fulfillment_orders: SKIP, additional_properties: nil) ⇒ ListAllFulfillmentOrdersResponse
constructor
A new instance of ListAllFulfillmentOrdersResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(next_token: SKIP, fulfillment_orders: SKIP, additional_properties: nil) ⇒ ListAllFulfillmentOrdersResponse
Returns a new instance of ListAllFulfillmentOrdersResponse.
41 42 43 44 45 46 47 48 49 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 41 def initialize(next_token: SKIP, fulfillment_orders: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @next_token = next_token unless next_token == SKIP @fulfillment_orders = fulfillment_orders unless fulfillment_orders == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fulfillment_orders ⇒ Array[FulfillmentOrder]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 18 def fulfillment_orders @fulfillment_orders end |
#next_token ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 14 def next_token @next_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. next_token = hash.key?('nextToken') ? hash['nextToken'] : SKIP # Parameter is an array, so we need to iterate through it fulfillment_orders = nil unless hash['fulfillmentOrders'].nil? fulfillment_orders = [] hash['fulfillmentOrders'].each do |structure| fulfillment_orders << (FulfillmentOrder.from_hash(structure) if structure) end end fulfillment_orders = SKIP unless hash.key?('fulfillmentOrders') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ListAllFulfillmentOrdersResponse.new(next_token: next_token, fulfillment_orders: fulfillment_orders, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['next_token'] = 'nextToken' @_hash['fulfillment_orders'] = 'fulfillmentOrders' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 29 def self.optionals %w[ next_token fulfillment_orders ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} next_token: #{@next_token.inspect}, fulfillment_orders:"\ " #{@fulfillment_orders.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/list_all_fulfillment_orders_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} next_token: #{@next_token}, fulfillment_orders: #{@fulfillment_orders},"\ " additional_properties: #{@additional_properties}>" end |