Class: WalmartApIs::ListInboundPlanPalletsResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ListInboundPlanPalletsResponse
- Defined in:
- lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb
Overview
The listInboundPlanPallets response.
Instance Attribute Summary collapse
-
#pagination ⇒ Pagination4
Contains tokens to fetch from a certain page.
-
#pallets ⇒ Array[Pallet]
The pallets in an inbound plan.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(pallets:, pagination: SKIP, additional_properties: nil) ⇒ ListInboundPlanPalletsResponse
constructor
A new instance of ListInboundPlanPalletsResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(pallets:, pagination: SKIP, additional_properties: nil) ⇒ ListInboundPlanPalletsResponse
Returns a new instance of ListInboundPlanPalletsResponse.
40 41 42 43 44 45 46 47 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 40 def initialize(pallets:, pagination: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @pallets = pallets @pagination = pagination unless pagination == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#pagination ⇒ Pagination4
Contains tokens to fetch from a certain page.
18 19 20 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 18 def pagination @pagination end |
#pallets ⇒ Array[Pallet]
The pallets in an inbound plan.
14 15 16 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 14 def pallets @pallets end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it pallets = nil unless hash['pallets'].nil? pallets = [] hash['pallets'].each do |structure| pallets << (Pallet.from_hash(structure) if structure) end end pallets = nil unless hash.key?('pallets') pagination = Pagination4.from_hash(hash['pagination']) if hash['pagination'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ListInboundPlanPalletsResponse.new(pallets: pallets, pagination: pagination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['pallets'] = 'pallets' @_hash['pagination'] = 'pagination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 29 def self.optionals %w[ pagination ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} pallets: #{@pallets.inspect}, pagination: #{@pagination.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/list_inbound_plan_pallets_response.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} pallets: #{@pallets}, pagination: #{@pagination}, additional_properties:"\ " #{@additional_properties}>" end |