Class: WalmartApIs::ListInboundPlansResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ListInboundPlansResponse
- Defined in:
- lib/walmart_ap_is/models/list_inbound_plans_response.rb
Overview
The listInboundPlans response.
Instance Attribute Summary collapse
-
#inbound_plans ⇒ Array[InboundPlanSummary]
A list of inbound plans with minimal information.
-
#pagination ⇒ Pagination4
Contains tokens to fetch from a certain page.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(inbound_plans: SKIP, pagination: SKIP, additional_properties: nil) ⇒ ListInboundPlansResponse
constructor
A new instance of ListInboundPlansResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(inbound_plans: SKIP, pagination: SKIP, additional_properties: nil) ⇒ ListInboundPlansResponse
Returns a new instance of ListInboundPlansResponse.
41 42 43 44 45 46 47 48 49 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 41 def initialize(inbound_plans: SKIP, pagination: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @inbound_plans = inbound_plans unless inbound_plans == SKIP @pagination = pagination unless pagination == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#inbound_plans ⇒ Array[InboundPlanSummary]
A list of inbound plans with minimal information.
14 15 16 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 14 def inbound_plans @inbound_plans end |
#pagination ⇒ Pagination4
Contains tokens to fetch from a certain page.
18 19 20 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 18 def pagination @pagination end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it inbound_plans = nil unless hash['inboundPlans'].nil? inbound_plans = [] hash['inboundPlans'].each do |structure| inbound_plans << (InboundPlanSummary.from_hash(structure) if structure) end end inbound_plans = SKIP unless hash.key?('inboundPlans') pagination = Pagination4.from_hash(hash['pagination']) if hash['pagination'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ListInboundPlansResponse.new(inbound_plans: inbound_plans, pagination: pagination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['inbound_plans'] = 'inboundPlans' @_hash['pagination'] = 'pagination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 29 def self.optionals %w[ inbound_plans pagination ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} inbound_plans: #{@inbound_plans.inspect}, pagination:"\ " #{@pagination.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/list_inbound_plans_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} inbound_plans: #{@inbound_plans}, pagination: #{@pagination},"\ " additional_properties: #{@additional_properties}>" end |