Class: WalmartApIs::LtlTrackingDetailInput
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::LtlTrackingDetailInput
- Defined in:
- lib/walmart_ap_is/models/ltl_tracking_detail_input.rb
Overview
Contains input information to update LTL tracking information.
Instance Attribute Summary collapse
-
#bill_of_lading_number ⇒ String
The number of the carrier shipment acknowledgement document.
-
#freight_bill_number ⇒ Array[String]
Number associated with the freight bill.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(freight_bill_number:, bill_of_lading_number: SKIP, additional_properties: nil) ⇒ LtlTrackingDetailInput
constructor
A new instance of LtlTrackingDetailInput.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(freight_bill_number:, bill_of_lading_number: SKIP, additional_properties: nil) ⇒ LtlTrackingDetailInput
Returns a new instance of LtlTrackingDetailInput.
40 41 42 43 44 45 46 47 48 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 40 def initialize(freight_bill_number:, bill_of_lading_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bill_of_lading_number = bill_of_lading_number unless bill_of_lading_number == SKIP @freight_bill_number = freight_bill_number @additional_properties = additional_properties end |
Instance Attribute Details
#bill_of_lading_number ⇒ String
The number of the carrier shipment acknowledgement document.
14 15 16 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 14 def bill_of_lading_number @bill_of_lading_number end |
#freight_bill_number ⇒ Array[String]
Number associated with the freight bill.
18 19 20 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 18 def freight_bill_number @freight_bill_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. freight_bill_number = hash.key?('freightBillNumber') ? hash['freightBillNumber'] : nil bill_of_lading_number = hash.key?('billOfLadingNumber') ? hash['billOfLadingNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LtlTrackingDetailInput.new(freight_bill_number: freight_bill_number, bill_of_lading_number: bill_of_lading_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['bill_of_lading_number'] = 'billOfLadingNumber' @_hash['freight_bill_number'] = 'freightBillNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 29 def self.optionals %w[ bill_of_lading_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} bill_of_lading_number: #{@bill_of_lading_number.inspect},"\ " freight_bill_number: #{@freight_bill_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/walmart_ap_is/models/ltl_tracking_detail_input.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} bill_of_lading_number: #{@bill_of_lading_number}, freight_bill_number:"\ " #{@freight_bill_number}, additional_properties: #{@additional_properties}>" end |