Class: WalmartApIs::MStrategyCollectionIdApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/walmart_ap_is/apis/m_strategy_collection_id_api.rb

Overview

MStrategyCollectionIdApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from WalmartApIs::BaseApi

Instance Method Details

#delete_repricer_strategy(strategy_collection_id, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ ApiResponse

Deletes a repricer strategy. Use this API to delete an existing repricer strategy and its corresponding details from the system. For more information and usage examples, refer to the <a href=“developer.walmart.com/us-marketplace/docs/delete-repricer-st rategy”>Pricing API Guide</a>. of the repricer strategy. This strategy collection ID is used to identify the specific repricer strategy that should be deleted. obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called.

Parameters:

  • strategy_collection_id (String)

    Required parameter: The unique ID

  • wm_sec_access_token (String)

    Required parameter: Access token

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: A unique ID that

  • wm_svc_name (String)

    Required parameter: Specifies the name of the

  • accept (String)

    Required parameter: TODO: type description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/walmart_ap_is/apis/m_strategy_collection_id_api.rb', line 88

def delete_repricer_strategy(strategy_collection_id,
                             wm_sec_access_token,
                             wm_consumer_channel_type,
                             wm_qos_correlation_id,
                             wm_svc_name,
                             accept)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/repricer/strategy/{strategyCollectionId}',
                                 Server::SERVER_1)
               .template_param(new_parameter(strategy_collection_id, key: 'strategyCollectionId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')
                              .is_required(true))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')
                              .is_required(true))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')
                              .is_required(true))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')
                              .is_required(true))
               .header_param(new_parameter(accept, key: 'Accept')
                              .is_required(true)))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation1.method(:from_hash))
                .is_api_response(true))
    .execute
end

#update_repricer_strategy(strategy_collection_id, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ ApiResponse

Updates an existing repricer strategy. Use this API to modify and update a repricer strategy rule, name, amount, and unit for a given strategy.

For more information and usage examples, refer to the <a

href=“developer.walmart.com/us-marketplace/docs/update-repricer-st rategy”>Pricing API Guide</a>. of the repricer strategy. This strategy collection ID is used to identify the specific repricer strategy that should be updated. obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called. description here

Parameters:

  • strategy_collection_id (String)

    Required parameter: The unique ID

  • wm_sec_access_token (String)

    Required parameter: Access token

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: A unique ID that

  • wm_svc_name (String)

    Required parameter: Specifies the name of the

  • accept (String)

    Required parameter: TODO: type description here

  • body (UpdateRepricerStrategyRequest)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/walmart_ap_is/apis/m_strategy_collection_id_api.rb', line 32

def update_repricer_strategy(strategy_collection_id,
                             wm_sec_access_token,
                             wm_consumer_channel_type,
                             wm_qos_correlation_id,
                             wm_svc_name,
                             accept,
                             body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/repricer/strategy/{strategyCollectionId}',
                                 Server::SERVER_1)
               .template_param(new_parameter(strategy_collection_id, key: 'strategyCollectionId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')
                              .is_required(true))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')
                              .is_required(true))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')
                              .is_required(true))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(accept, key: 'Accept')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation.method(:from_hash))
                .is_api_response(true))
    .execute
end