Class: WalmartApIs::Marketplace

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/marketplace.rb

Overview

Marketplace Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, name: SKIP, country_code: SKIP, currency_code: SKIP, default_language_code: SKIP, additional_properties: nil) ⇒ Marketplace

Returns a new instance of Marketplace.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/walmart_ap_is/models/marketplace.rb', line 59

def initialize(id: SKIP, name: SKIP, country_code: SKIP,
               currency_code: SKIP, default_language_code: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @name = name unless name == SKIP
  @country_code = country_code unless country_code == SKIP
  @currency_code = currency_code unless currency_code == SKIP
  @default_language_code = default_language_code unless default_language_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#country_codeString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/marketplace.rb', line 22

def country_code
  @country_code
end

#currency_codeString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/walmart_ap_is/models/marketplace.rb', line 26

def currency_code
  @currency_code
end

#default_language_codeString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/walmart_ap_is/models/marketplace.rb', line 30

def default_language_code
  @default_language_code
end

#idMarketplaceId

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/marketplace.rb', line 14

def id
  @id
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/marketplace.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/walmart_ap_is/models/marketplace.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  country_code = hash.key?('countryCode') ? hash['countryCode'] : SKIP
  currency_code = hash.key?('currencyCode') ? hash['currencyCode'] : SKIP
  default_language_code =
    hash.key?('defaultLanguageCode') ? hash['defaultLanguageCode'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Marketplace.new(id: id,
                  name: name,
                  country_code: country_code,
                  currency_code: currency_code,
                  default_language_code: default_language_code,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/walmart_ap_is/models/marketplace.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['country_code'] = 'countryCode'
  @_hash['currency_code'] = 'currencyCode'
  @_hash['default_language_code'] = 'defaultLanguageCode'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/walmart_ap_is/models/marketplace.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/walmart_ap_is/models/marketplace.rb', line 44

def self.optionals
  %w[
    id
    name
    country_code
    currency_code
    default_language_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



110
111
112
113
114
115
# File 'lib/walmart_ap_is/models/marketplace.rb', line 110

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, country_code:"\
  " #{@country_code.inspect}, currency_code: #{@currency_code.inspect}, default_language_code:"\
  " #{@default_language_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



102
103
104
105
106
107
# File 'lib/walmart_ap_is/models/marketplace.rb', line 102

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, country_code: #{@country_code}, currency_code:"\
  " #{@currency_code}, default_language_code: #{@default_language_code},"\
  " additional_properties: #{@additional_properties}>"
end