Class: WalmartApIs::MarketplaceShipmentDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/marketplace_shipment_details.rb

Overview

Marketplace-side shipment context. Renamed from the industry SP-API "vendor-shipment-details" block to be vendor-neutral.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(seller_order_id: SKIP, purchase_order_id: SKIP, seller_tracking_id: SKIP, additional_properties: nil) ⇒ MarketplaceShipmentDetails

Returns a new instance of MarketplaceShipmentDetails.



48
49
50
51
52
53
54
55
56
57
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 48

def initialize(seller_order_id: SKIP, purchase_order_id: SKIP,
               seller_tracking_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @seller_order_id = seller_order_id unless seller_order_id == SKIP
  @purchase_order_id = purchase_order_id unless purchase_order_id == SKIP
  @seller_tracking_id = seller_tracking_id unless seller_tracking_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#purchase_order_idString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 19

def purchase_order_id
  @purchase_order_id
end

#seller_order_idString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 15

def seller_order_id
  @seller_order_id
end

#seller_tracking_idString

TODO: Write general description for this method

Returns:

  • (String)


23
24
25
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 23

def seller_tracking_id
  @seller_tracking_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  seller_order_id =
    hash.key?('sellerOrderId') ? hash['sellerOrderId'] : SKIP
  purchase_order_id =
    hash.key?('purchaseOrderId') ? hash['purchaseOrderId'] : SKIP
  seller_tracking_id =
    hash.key?('sellerTrackingId') ? hash['sellerTrackingId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MarketplaceShipmentDetails.new(seller_order_id: seller_order_id,
                                 purchase_order_id: purchase_order_id,
                                 seller_tracking_id: seller_tracking_id,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['seller_order_id'] = 'sellerOrderId'
  @_hash['purchase_order_id'] = 'purchaseOrderId'
  @_hash['seller_tracking_id'] = 'sellerTrackingId'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 35

def self.optionals
  %w[
    seller_order_id
    purchase_order_id
    seller_tracking_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} seller_order_id: #{@seller_order_id.inspect}, purchase_order_id:"\
  " #{@purchase_order_id.inspect}, seller_tracking_id: #{@seller_tracking_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
91
# File 'lib/walmart_ap_is/models/marketplace_shipment_details.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} seller_order_id: #{@seller_order_id}, purchase_order_id:"\
  " #{@purchase_order_id}, seller_tracking_id: #{@seller_tracking_id}, additional_properties:"\
  " #{@additional_properties}>"
end