Class: WalmartApIs::MoneyType
- Defined in:
- lib/walmart_ap_is/models/money_type.rb
Overview
Currency type and monetary value.
Instance Attribute Summary collapse
-
#amount ⇒ Float
The monetary value.
-
#currency_code ⇒ String
The currency code in ISO 4217 format.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency_code: 'USD', amount: SKIP, additional_properties: nil) ⇒ MoneyType
constructor
A new instance of MoneyType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency_code: 'USD', amount: SKIP, additional_properties: nil) ⇒ MoneyType
Returns a new instance of MoneyType.
41 42 43 44 45 46 47 48 49 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 41 def initialize(currency_code: 'USD', amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency_code = currency_code unless currency_code == SKIP @amount = amount unless amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
The monetary value.
18 19 20 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 18 def amount @amount end |
#currency_code ⇒ String
The currency code in ISO 4217 format.
14 15 16 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 14 def currency_code @currency_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency_code = hash['CurrencyCode'] ||= 'USD' amount = hash.key?('Amount') ? hash['Amount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MoneyType.new(currency_code: currency_code, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['currency_code'] = 'CurrencyCode' @_hash['amount'] = 'Amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 29 def self.optionals %w[ currency_code amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency_code: #{@currency_code.inspect}, amount: #{@amount.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/walmart_ap_is/models/money_type.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency_code: #{@currency_code}, amount: #{@amount},"\ " additional_properties: #{@additional_properties}>" end |