Class: WalmartApIs::OfferCountType

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/offer_count_type.rb

Overview

The total number of offers for the specified condition and fulfillment channel.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(condition: SKIP, fulfillment_channel: SKIP, offer_count: SKIP, additional_properties: nil) ⇒ OfferCountType

Returns a new instance of OfferCountType.



51
52
53
54
55
56
57
58
59
60
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 51

def initialize(condition: SKIP, fulfillment_channel: SKIP,
               offer_count: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @condition = condition unless condition == SKIP
  @fulfillment_channel = fulfillment_channel unless fulfillment_channel == SKIP
  @offer_count = offer_count unless offer_count == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#conditionString

Indicates the condition of the item. For example: New, Used, Collectible, Refurbished, or Club.

Returns:

  • (String)


16
17
18
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 16

def condition
  @condition
end

#fulfillment_channelFulfillmentChannelType

Indicates whether the item is fulfilled by the seller or by Walmart Fulfillment Services.



21
22
23
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 21

def fulfillment_channel
  @fulfillment_channel
end

#offer_countInteger

The number of offers in a fulfillment channel that meet a specific condition.

Returns:

  • (Integer)


26
27
28
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 26

def offer_count
  @offer_count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  condition = hash.key?('condition') ? hash['condition'] : SKIP
  fulfillment_channel =
    hash.key?('fulfillmentChannel') ? hash['fulfillmentChannel'] : SKIP
  offer_count = hash.key?('OfferCount') ? hash['OfferCount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OfferCountType.new(condition: condition,
                     fulfillment_channel: fulfillment_channel,
                     offer_count: offer_count,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['condition'] = 'condition'
  @_hash['fulfillment_channel'] = 'fulfillmentChannel'
  @_hash['offer_count'] = 'OfferCount'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
41
42
43
44
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 38

def self.optionals
  %w[
    condition
    fulfillment_channel
    offer_count
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} condition: #{@condition.inspect}, fulfillment_channel:"\
  " #{@fulfillment_channel.inspect}, offer_count: #{@offer_count.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/walmart_ap_is/models/offer_count_type.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} condition: #{@condition}, fulfillment_channel: #{@fulfillment_channel},"\
  " offer_count: #{@offer_count}, additional_properties: #{@additional_properties}>"
end