Class: WalmartApIs::OperationProblem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/operation_problem.rb

Overview

A problem with additional properties persisted to an operation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code:, message:, severity:, details: SKIP, additional_properties: nil) ⇒ OperationProblem

Returns a new instance of OperationProblem.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 50

def initialize(code:, message:, severity:, details: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code
  @details = details unless details == SKIP
  @message = message
  @severity = severity
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

An error code that identifies the type of error that occurred.

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 14

def code
  @code
end

#detailsString

Additional details that can help the caller understand or fix the issue.

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 18

def details
  @details
end

#messageString

A message that describes the error condition.

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 22

def message
  @message
end

#severityString

The severity of the problem. Possible values: WARNING, ERROR.

Returns:

  • (String)


26
27
28
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 26

def severity
  @severity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : nil
  message = hash.key?('message') ? hash['message'] : nil
  severity = hash.key?('severity') ? hash['severity'] : nil
  details = hash.key?('details') ? hash['details'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OperationProblem.new(code: code,
                       message: message,
                       severity: severity,
                       details: details,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['details'] = 'details'
  @_hash['message'] = 'message'
  @_hash['severity'] = 'severity'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 39

def self.optionals
  %w[
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, details: #{@details.inspect}, message:"\
  " #{@message.inspect}, severity: #{@severity.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/walmart_ap_is/models/operation_problem.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, details: #{@details}, message: #{@message}, severity:"\
  " #{@severity}, additional_properties: #{@additional_properties}>"
end