Class: WalmartApIs::PackageDimensions
- Defined in:
- lib/walmart_ap_is/models/package_dimensions.rb
Overview
PackageDimensions Model.
Instance Attribute Summary collapse
-
#height ⇒ Float
TODO: Write general description for this method.
-
#length ⇒ Float
TODO: Write general description for this method.
-
#unit ⇒ Unit1
TODO: Write general description for this method.
-
#width ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(length:, width:, height:, unit:, additional_properties: nil) ⇒ PackageDimensions
constructor
A new instance of PackageDimensions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(length:, width:, height:, unit:, additional_properties: nil) ⇒ PackageDimensions
Returns a new instance of PackageDimensions.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 48 def initialize(length:, width:, height:, unit:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @length = length @width = width @height = height @unit = unit @additional_properties = additional_properties end |
Instance Attribute Details
#height ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 22 def height @height end |
#length ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 14 def length @length end |
#unit ⇒ Unit1
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 26 def unit @unit end |
#width ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 18 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. length = hash.key?('length') ? hash['length'] : nil width = hash.key?('width') ? hash['width'] : nil height = hash.key?('height') ? hash['height'] : nil unit = hash.key?('unit') ? hash['unit'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PackageDimensions.new(length: length, width: width, height: height, unit: unit, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['length'] = 'length' @_hash['width'] = 'width' @_hash['height'] = 'height' @_hash['unit'] = 'unit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} length: #{@length.inspect}, width: #{@width.inspect}, height:"\ " #{@height.inspect}, unit: #{@unit.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/walmart_ap_is/models/package_dimensions.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} length: #{@length}, width: #{@width}, height: #{@height}, unit: #{@unit},"\ " additional_properties: #{@additional_properties}>" end |