Class: WalmartApIs::PageContext

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/page_context.rb

Overview

PageContext Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(page_no:, current_page_count:, total_count:, total_pages:, additional_properties: nil) ⇒ PageContext

Returns a new instance of PageContext.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/walmart_ap_is/models/page_context.rb', line 48

def initialize(page_no:, current_page_count:, total_count:, total_pages:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @page_no = page_no
  @current_page_count = current_page_count
  @total_count = total_count
  @total_pages = total_pages
  @additional_properties = additional_properties
end

Instance Attribute Details

#current_page_countInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/walmart_ap_is/models/page_context.rb', line 18

def current_page_count
  @current_page_count
end

#page_noInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/walmart_ap_is/models/page_context.rb', line 14

def page_no
  @page_no
end

#total_countInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/walmart_ap_is/models/page_context.rb', line 22

def total_count
  @total_count
end

#total_pagesInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/walmart_ap_is/models/page_context.rb', line 26

def total_pages
  @total_pages
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/walmart_ap_is/models/page_context.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  page_no = hash.key?('pageNo') ? hash['pageNo'] : nil
  current_page_count =
    hash.key?('currentPageCount') ? hash['currentPageCount'] : nil
  total_count = hash.key?('totalCount') ? hash['totalCount'] : nil
  total_pages = hash.key?('totalPages') ? hash['totalPages'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PageContext.new(page_no: page_no,
                  current_page_count: current_page_count,
                  total_count: total_count,
                  total_pages: total_pages,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/page_context.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['page_no'] = 'pageNo'
  @_hash['current_page_count'] = 'currentPageCount'
  @_hash['total_count'] = 'totalCount'
  @_hash['total_pages'] = 'totalPages'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/walmart_ap_is/models/page_context.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/walmart_ap_is/models/page_context.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/walmart_ap_is/models/page_context.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} page_no: #{@page_no.inspect}, current_page_count:"\
  " #{@current_page_count.inspect}, total_count: #{@total_count.inspect}, total_pages:"\
  " #{@total_pages.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
# File 'lib/walmart_ap_is/models/page_context.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} page_no: #{@page_no}, current_page_count: #{@current_page_count},"\
  " total_count: #{@total_count}, total_pages: #{@total_pages}, additional_properties:"\
  " #{@additional_properties}>"
end