Class: WalmartApIs::Pagination

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/pagination.rb

Overview

Pagination Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(next_token: SKIP, previous_token: SKIP, additional_properties: nil) ⇒ Pagination

Returns a new instance of Pagination.



41
42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/pagination.rb', line 41

def initialize(next_token: SKIP, previous_token: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @next_token = next_token unless next_token == SKIP
  @previous_token = previous_token unless previous_token == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#next_tokenString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/pagination.rb', line 14

def next_token
  @next_token
end

#previous_tokenString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/pagination.rb', line 18

def previous_token
  @previous_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/walmart_ap_is/models/pagination.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  next_token = hash.key?('nextToken') ? hash['nextToken'] : SKIP
  previous_token = hash.key?('previousToken') ? hash['previousToken'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Pagination.new(next_token: next_token,
                 previous_token: previous_token,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/pagination.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['next_token'] = 'nextToken'
  @_hash['previous_token'] = 'previousToken'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/pagination.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/pagination.rb', line 29

def self.optionals
  %w[
    next_token
    previous_token
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/walmart_ap_is/models/pagination.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} next_token: #{@next_token.inspect}, previous_token:"\
  " #{@previous_token.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/walmart_ap_is/models/pagination.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} next_token: #{@next_token}, previous_token: #{@previous_token},"\
  " additional_properties: #{@additional_properties}>"
end