Class: WalmartApIs::PalletInput

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/pallet_input.rb

Overview

Contains input information about a pallet to be used in the inbound plan.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(quantity:, dimensions: SKIP, stackability: SKIP, weight: SKIP, additional_properties: nil) ⇒ PalletInput

Returns a new instance of PalletInput.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 54

def initialize(quantity:, dimensions: SKIP, stackability: SKIP,
               weight: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @dimensions = dimensions unless dimensions == SKIP
  @quantity = quantity
  @stackability = stackability unless stackability == SKIP
  @weight = weight unless weight == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dimensionsDimensions

Measurement of a package's dimensions.

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 14

def dimensions
  @dimensions
end

#quantityInteger

The number of containers where all other properties like weight or dimensions are identical.

Returns:

  • (Integer)


19
20
21
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 19

def quantity
  @quantity
end

#stackabilityStackability

Indicates whether pallets will be stacked when carrier arrives for pick-up.

Returns:



24
25
26
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 24

def stackability
  @stackability
end

#weightWeight

The weight of a package.

Returns:



28
29
30
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 28

def weight
  @weight
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  quantity = hash.key?('quantity') ? hash['quantity'] : nil
  dimensions = Dimensions.from_hash(hash['dimensions']) if hash['dimensions']
  stackability = hash.key?('stackability') ? hash['stackability'] : SKIP
  weight = Weight.from_hash(hash['weight']) if hash['weight']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PalletInput.new(quantity: quantity,
                  dimensions: dimensions,
                  stackability: stackability,
                  weight: weight,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
37
38
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['dimensions'] = 'dimensions'
  @_hash['quantity'] = 'quantity'
  @_hash['stackability'] = 'stackability'
  @_hash['weight'] = 'weight'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



41
42
43
44
45
46
47
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 41

def self.optionals
  %w[
    dimensions
    stackability
    weight
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} dimensions: #{@dimensions.inspect}, quantity: #{@quantity.inspect},"\
  " stackability: #{@stackability.inspect}, weight: #{@weight.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/walmart_ap_is/models/pallet_input.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} dimensions: #{@dimensions}, quantity: #{@quantity}, stackability:"\
  " #{@stackability}, weight: #{@weight}, additional_properties: #{@additional_properties}>"
end