Class: WalmartApIs::Participation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/participation.rb

Overview

Participation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_participating: SKIP, has_suspended_listings: SKIP, seller_status: SKIP, additional_properties: nil) ⇒ Participation

Returns a new instance of Participation.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/participation.rb', line 47

def initialize(is_participating: SKIP, has_suspended_listings: SKIP,
               seller_status: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_participating = is_participating unless is_participating == SKIP
  @has_suspended_listings = has_suspended_listings unless has_suspended_listings == SKIP
  @seller_status = seller_status unless seller_status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#has_suspended_listingsTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/walmart_ap_is/models/participation.rb', line 18

def has_suspended_listings
  @has_suspended_listings
end

#is_participatingTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/walmart_ap_is/models/participation.rb', line 14

def is_participating
  @is_participating
end

#seller_statusSellerStatus

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/participation.rb', line 22

def seller_status
  @seller_status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/walmart_ap_is/models/participation.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_participating =
    hash.key?('isParticipating') ? hash['isParticipating'] : SKIP
  has_suspended_listings =
    hash.key?('hasSuspendedListings') ? hash['hasSuspendedListings'] : SKIP
  seller_status = hash.key?('sellerStatus') ? hash['sellerStatus'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Participation.new(is_participating: is_participating,
                    has_suspended_listings: has_suspended_listings,
                    seller_status: seller_status,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/participation.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_participating'] = 'isParticipating'
  @_hash['has_suspended_listings'] = 'hasSuspendedListings'
  @_hash['seller_status'] = 'sellerStatus'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/participation.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/participation.rb', line 34

def self.optionals
  %w[
    is_participating
    has_suspended_listings
    seller_status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/walmart_ap_is/models/participation.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_participating: #{@is_participating.inspect}, has_suspended_listings:"\
  " #{@has_suspended_listings.inspect}, seller_status: #{@seller_status.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/walmart_ap_is/models/participation.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_participating: #{@is_participating}, has_suspended_listings:"\
  " #{@has_suspended_listings}, seller_status: #{@seller_status}, additional_properties:"\
  " #{@additional_properties}>"
end