Class: WalmartApIs::PatchOperation
- Defined in:
- lib/walmart_ap_is/models/patch_operation.rb
Overview
PatchOperation Model.
Instance Attribute Summary collapse
-
#op ⇒ Op
Patch operation type (JSON Patch).
-
#path ⇒ String
JSON Pointer path to the attribute (RFC 6901).
-
#value ⇒ Array[Object]
Value to set (absent for delete operations).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(op:, path:, value: SKIP, additional_properties: nil) ⇒ PatchOperation
constructor
A new instance of PatchOperation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(op:, path:, value: SKIP, additional_properties: nil) ⇒ PatchOperation
Returns a new instance of PatchOperation.
45 46 47 48 49 50 51 52 53 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 45 def initialize(op:, path:, value: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @op = op @path = path @value = value unless value == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#op ⇒ Op
Patch operation type (JSON Patch)
14 15 16 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 14 def op @op end |
#path ⇒ String
JSON Pointer path to the attribute (RFC 6901)
18 19 20 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 18 def path @path end |
#value ⇒ Array[Object]
Value to set (absent for delete operations)
22 23 24 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 22 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. op = hash.key?('op') ? hash['op'] : nil path = hash.key?('path') ? hash['path'] : nil value = hash.key?('value') ? hash['value'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PatchOperation.new(op: op, path: path, value: value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['op'] = 'op' @_hash['path'] = 'path' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 34 def self.optionals %w[ value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} op: #{@op.inspect}, path: #{@path.inspect}, value: #{@value.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/patch_operation.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} op: #{@op}, path: #{@path}, value: #{@value}, additional_properties:"\ " #{@additional_properties}>" end |