Class: WalmartApIs::Payload11

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/payload11.rb

Overview

Payload11 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(purchase_order_id: SKIP, order_items: SKIP, additional_properties: nil) ⇒ Payload11

Returns a new instance of Payload11.



41
42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/payload11.rb', line 41

def initialize(purchase_order_id: SKIP, order_items: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @purchase_order_id = purchase_order_id unless purchase_order_id == SKIP
  @order_items = order_items unless order_items == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#order_itemsArray[OrderLine]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/payload11.rb', line 18

def order_items
  @order_items
end

#purchase_order_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/payload11.rb', line 14

def purchase_order_id
  @purchase_order_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/walmart_ap_is/models/payload11.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  purchase_order_id =
    hash.key?('purchaseOrderId') ? hash['purchaseOrderId'] : SKIP
  # Parameter is an array, so we need to iterate through it
  order_items = nil
  unless hash['orderItems'].nil?
    order_items = []
    hash['orderItems'].each do |structure|
      order_items << (OrderLine.from_hash(structure) if structure)
    end
  end

  order_items = SKIP unless hash.key?('orderItems')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Payload11.new(purchase_order_id: purchase_order_id,
                order_items: order_items,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/payload11.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['purchase_order_id'] = 'purchaseOrderId'
  @_hash['order_items'] = 'orderItems'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/payload11.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/payload11.rb', line 29

def self.optionals
  %w[
    purchase_order_id
    order_items
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/walmart_ap_is/models/payload11.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} purchase_order_id: #{@purchase_order_id.inspect}, order_items:"\
  " #{@order_items.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/walmart_ap_is/models/payload11.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} purchase_order_id: #{@purchase_order_id}, order_items: #{@order_items},"\
  " additional_properties: #{@additional_properties}>"
end