Class: WalmartApIs::Payload4

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/payload4.rb

Overview

Payload4 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(shipment_id: SKIP, package_document_details: SKIP, additional_properties: nil) ⇒ Payload4

Returns a new instance of Payload4.



41
42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/payload4.rb', line 41

def initialize(shipment_id: SKIP, package_document_details: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @shipment_id = shipment_id unless shipment_id == SKIP
  @package_document_details = package_document_details unless package_document_details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#package_document_detailsArray[PackageDocumentDetail]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/payload4.rb', line 18

def package_document_details
  @package_document_details
end

#shipment_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/payload4.rb', line 14

def shipment_id
  @shipment_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/payload4.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  shipment_id = hash.key?('shipmentId') ? hash['shipmentId'] : SKIP
  # Parameter is an array, so we need to iterate through it
  package_document_details = nil
  unless hash['packageDocumentDetails'].nil?
    package_document_details = []
    hash['packageDocumentDetails'].each do |structure|
      package_document_details << (PackageDocumentDetail.from_hash(structure) if structure)
    end
  end

  package_document_details = SKIP unless hash.key?('packageDocumentDetails')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Payload4.new(shipment_id: shipment_id,
               package_document_details: package_document_details,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/payload4.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['shipment_id'] = 'shipmentId'
  @_hash['package_document_details'] = 'packageDocumentDetails'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/payload4.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/payload4.rb', line 29

def self.optionals
  %w[
    shipment_id
    package_document_details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/walmart_ap_is/models/payload4.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} shipment_id: #{@shipment_id.inspect}, package_document_details:"\
  " #{@package_document_details.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/walmart_ap_is/models/payload4.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} shipment_id: #{@shipment_id}, package_document_details:"\
  " #{@package_document_details}, additional_properties: #{@additional_properties}>"
end