Class: WalmartApIs::Payload5
- Defined in:
- lib/walmart_ap_is/models/payload5.rb
Overview
Payload5 Model.
Instance Attribute Summary collapse
-
#cancellation_status ⇒ CancellationStatus
Whether the cancellation was accepted by the carrier.
-
#cancelled ⇒ TrueClass | FalseClass
Whether the cancellation was accepted by the carrier.
-
#message ⇒ String
Whether the cancellation was accepted by the carrier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cancelled: SKIP, cancellation_status: SKIP, message: SKIP, additional_properties: nil) ⇒ Payload5
constructor
A new instance of Payload5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cancelled: SKIP, cancellation_status: SKIP, message: SKIP, additional_properties: nil) ⇒ Payload5
Returns a new instance of Payload5.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 47 def initialize(cancelled: SKIP, cancellation_status: SKIP, message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @cancelled = cancelled unless cancelled == SKIP @cancellation_status = cancellation_status unless cancellation_status == SKIP @message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#cancellation_status ⇒ CancellationStatus
Whether the cancellation was accepted by the carrier.
18 19 20 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 18 def cancellation_status @cancellation_status end |
#cancelled ⇒ TrueClass | FalseClass
Whether the cancellation was accepted by the carrier.
14 15 16 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 14 def cancelled @cancelled end |
#message ⇒ String
Whether the cancellation was accepted by the carrier.
22 23 24 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 22 def @message end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cancelled = hash.key?('cancelled') ? hash['cancelled'] : SKIP cancellation_status = hash.key?('cancellationStatus') ? hash['cancellationStatus'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Payload5.new(cancelled: cancelled, cancellation_status: cancellation_status, message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['cancelled'] = 'cancelled' @_hash['cancellation_status'] = 'cancellationStatus' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 34 def self.optionals %w[ cancelled cancellation_status message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} cancelled: #{@cancelled.inspect}, cancellation_status:"\ " #{@cancellation_status.inspect}, message: #{@message.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/walmart_ap_is/models/payload5.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} cancelled: #{@cancelled}, cancellation_status: #{@cancellation_status},"\ " message: #{@message}, additional_properties: #{@additional_properties}>" end |