Class: WalmartApIs::Payload6
- Defined in:
- lib/walmart_ap_is/models/payload6.rb
Overview
Payload6 Model.
Instance Attribute Summary collapse
-
#access_points ⇒ Array[AccessPoint]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_points: SKIP, additional_properties: nil) ⇒ Payload6
constructor
A new instance of Payload6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_points: SKIP, additional_properties: nil) ⇒ Payload6
Returns a new instance of Payload6.
35 36 37 38 39 40 41 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 35 def initialize(access_points: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @access_points = access_points unless access_points == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_points ⇒ Array[AccessPoint]
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 14 def access_points @access_points end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it access_points = nil unless hash['accessPoints'].nil? access_points = [] hash['accessPoints'].each do |structure| access_points << (AccessPoint.from_hash(structure) if structure) end end access_points = SKIP unless hash.key?('accessPoints') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Payload6.new(access_points: access_points, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['access_points'] = 'accessPoints' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 24 def self.optionals %w[ access_points ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} access_points: #{@access_points.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/walmart_ap_is/models/payload6.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} access_points: #{@access_points}, additional_properties:"\ " #{@additional_properties}>" end |