Class: WalmartApIs::PrepInstruction

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/prep_instruction.rb

Overview

Information pertaining to the preparation of inbound goods.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(fee: SKIP, prep_owner: SKIP, prep_type: SKIP, additional_properties: nil) ⇒ PrepInstruction

Returns a new instance of PrepInstruction.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 47

def initialize(fee: SKIP, prep_owner: SKIP, prep_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @fee = fee unless fee == SKIP
  @prep_owner = prep_owner unless prep_owner == SKIP
  @prep_type = prep_type unless prep_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#feeCurrency

The type and amount of currency.

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 14

def fee
  @fee
end

#prep_ownerString

Owner of the preparations. Options include SELLER or NONE.

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 18

def prep_owner
  @prep_owner
end

#prep_typeString

Type of preparation that should be done.

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 22

def prep_type
  @prep_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  fee = Currency.from_hash(hash['fee']) if hash['fee']
  prep_owner = hash.key?('prepOwner') ? hash['prepOwner'] : SKIP
  prep_type = hash.key?('prepType') ? hash['prepType'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PrepInstruction.new(fee: fee,
                      prep_owner: prep_owner,
                      prep_type: prep_type,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['fee'] = 'fee'
  @_hash['prep_owner'] = 'prepOwner'
  @_hash['prep_type'] = 'prepType'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 34

def self.optionals
  %w[
    fee
    prep_owner
    prep_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} fee: #{@fee.inspect}, prep_owner: #{@prep_owner.inspect}, prep_type:"\
  " #{@prep_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/walmart_ap_is/models/prep_instruction.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} fee: #{@fee}, prep_owner: #{@prep_owner}, prep_type: #{@prep_type},"\
  " additional_properties: #{@additional_properties}>"
end