Class: WalmartApIs::PriceToEstimateFees

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/price_to_estimate_fees.rb

Overview

Price information used to estimate fees.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(listing_price:, shipping: SKIP, points: SKIP, additional_properties: nil) ⇒ PriceToEstimateFees

Returns a new instance of PriceToEstimateFees.



46
47
48
49
50
51
52
53
54
55
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 46

def initialize(listing_price:, shipping: SKIP, points: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @listing_price = listing_price
  @shipping = shipping unless shipping == SKIP
  @points = points unless points == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#listing_priceMoneyType1

Currency amount.

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 14

def listing_price
  @listing_price
end

#pointsPoints1

Walmart Rewards points.

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 22

def points
  @points
end

#shippingMoneyType1

Currency amount.

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 18

def shipping
  @shipping
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  listing_price = MoneyType1.from_hash(hash['ListingPrice']) if hash['ListingPrice']
  shipping = MoneyType1.from_hash(hash['Shipping']) if hash['Shipping']
  points = Points1.from_hash(hash['Points']) if hash['Points']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PriceToEstimateFees.new(listing_price: listing_price,
                          shipping: shipping,
                          points: points,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['listing_price'] = 'ListingPrice'
  @_hash['shipping'] = 'Shipping'
  @_hash['points'] = 'Points'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 34

def self.optionals
  %w[
    shipping
    points
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} listing_price: #{@listing_price.inspect}, shipping: #{@shipping.inspect},"\
  " points: #{@points.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/walmart_ap_is/models/price_to_estimate_fees.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} listing_price: #{@listing_price}, shipping: #{@shipping}, points:"\
  " #{@points}, additional_properties: #{@additional_properties}>"
end