Class: WalmartApIs::Pricing
- Defined in:
- lib/walmart_ap_is/models/pricing.rb
Overview
Pricing Model.
Instance Attribute Summary collapse
-
#current_price ⇒ CurrentPrice
TODO: Write general description for this method.
-
#current_price_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(current_price_type:, current_price:, additional_properties: nil) ⇒ Pricing
constructor
A new instance of Pricing.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(current_price_type:, current_price:, additional_properties: nil) ⇒ Pricing
Returns a new instance of Pricing.
38 39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 38 def initialize(current_price_type:, current_price:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @current_price_type = current_price_type @current_price = current_price @additional_properties = additional_properties end |
Instance Attribute Details
#current_price ⇒ CurrentPrice
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 18 def current_price @current_price end |
#current_price_type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 14 def current_price_type @current_price_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. current_price_type = hash.key?('currentPriceType') ? hash['currentPriceType'] : nil current_price = CurrentPrice.from_hash(hash['currentPrice']) if hash['currentPrice'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Pricing.new(current_price_type: current_price_type, current_price: current_price, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['current_price_type'] = 'currentPriceType' @_hash['current_price'] = 'currentPrice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} current_price_type: #{@current_price_type.inspect}, current_price:"\ " #{@current_price.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/pricing.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} current_price_type: #{@current_price_type}, current_price:"\ " #{@current_price}, additional_properties: #{@additional_properties}>" end |