Class: WalmartApIs::ProductTypeDefinition
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ProductTypeDefinition
- Defined in:
- lib/walmart_ap_is/models/product_type_definition.rb
Overview
ProductTypeDefinition Model.
Instance Attribute Summary collapse
-
#meta_schema ⇒ String
TODO: Write general description for this method.
-
#property_groups ⇒ Object
JSON Schema for this product type's attributes.
-
#requirements ⇒ Object
JSON Schema for this product type's attributes.
-
#schema ⇒ Object
JSON Schema for this product type's attributes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(meta_schema: SKIP, schema: SKIP, requirements: SKIP, property_groups: SKIP, additional_properties: nil) ⇒ ProductTypeDefinition
constructor
A new instance of ProductTypeDefinition.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(meta_schema: SKIP, schema: SKIP, requirements: SKIP, property_groups: SKIP, additional_properties: nil) ⇒ ProductTypeDefinition
Returns a new instance of ProductTypeDefinition.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 53 def initialize(meta_schema: SKIP, schema: SKIP, requirements: SKIP, property_groups: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @meta_schema = unless == SKIP @schema = schema unless schema == SKIP @requirements = requirements unless requirements == SKIP @property_groups = property_groups unless property_groups == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#meta_schema ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 14 def @meta_schema end |
#property_groups ⇒ Object
JSON Schema for this product type's attributes
26 27 28 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 26 def property_groups @property_groups end |
#requirements ⇒ Object
JSON Schema for this product type's attributes
22 23 24 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 22 def requirements @requirements end |
#schema ⇒ Object
JSON Schema for this product type's attributes
18 19 20 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 18 def schema @schema end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('metaSchema') ? hash['metaSchema'] : SKIP schema = hash.key?('schema') ? hash['schema'] : SKIP requirements = hash.key?('requirements') ? hash['requirements'] : SKIP property_groups = hash.key?('propertyGroups') ? hash['propertyGroups'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProductTypeDefinition.new(meta_schema: , schema: schema, requirements: requirements, property_groups: property_groups, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['meta_schema'] = 'metaSchema' @_hash['schema'] = 'schema' @_hash['requirements'] = 'requirements' @_hash['property_groups'] = 'propertyGroups' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 39 def self.optionals %w[ meta_schema schema requirements property_groups ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} meta_schema: #{@meta_schema.inspect}, schema: #{@schema.inspect},"\ " requirements: #{@requirements.inspect}, property_groups: #{@property_groups.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 97 |
# File 'lib/walmart_ap_is/models/product_type_definition.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} meta_schema: #{@meta_schema}, schema: #{@schema}, requirements:"\ " #{@requirements}, property_groups: #{@property_groups}, additional_properties:"\ " #{@additional_properties}>" end |