Class: WalmartApIs::ProductTypeSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ProductTypeSummary
- Defined in:
- lib/walmart_ap_is/models/product_type_summary.rb
Overview
ProductTypeSummary Model.
Instance Attribute Summary collapse
-
#display_name ⇒ String
TODO: Write general description for this method.
-
#marketplace_ids ⇒ Array[MarketplaceId]
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, display_name: SKIP, marketplace_ids: SKIP, additional_properties: nil) ⇒ ProductTypeSummary
constructor
A new instance of ProductTypeSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, display_name: SKIP, marketplace_ids: SKIP, additional_properties: nil) ⇒ ProductTypeSummary
Returns a new instance of ProductTypeSummary.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 47 def initialize(name: SKIP, display_name: SKIP, marketplace_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @display_name = display_name unless display_name == SKIP @marketplace_ids = marketplace_ids unless marketplace_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#display_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 18 def display_name @display_name end |
#marketplace_ids ⇒ Array[MarketplaceId]
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 22 def marketplace_ids @marketplace_ids end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 14 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP display_name = hash.key?('displayName') ? hash['displayName'] : SKIP marketplace_ids = hash.key?('marketplaceIds') ? hash['marketplaceIds'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProductTypeSummary.new(name: name, display_name: display_name, marketplace_ids: marketplace_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['display_name'] = 'displayName' @_hash['marketplace_ids'] = 'marketplaceIds' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 34 def self.optionals %w[ name display_name marketplace_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, display_name: #{@display_name.inspect},"\ " marketplace_ids: #{@marketplace_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/walmart_ap_is/models/product_type_summary.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, display_name: #{@display_name}, marketplace_ids:"\ " #{@marketplace_ids}, additional_properties: #{@additional_properties}>" end |