Class: WalmartApIs::ProgramAction
- Defined in:
- lib/walmart_ap_is/models/program_action.rb
Overview
ProgramAction Model.
Instance Attribute Summary collapse
-
#item_identifiers ⇒ ItemIdentifiers
TODO: Write general description for this method.
-
#programs ⇒ Programs
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_identifiers:, programs:, additional_properties: nil) ⇒ ProgramAction
constructor
A new instance of ProgramAction.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_identifiers:, programs:, additional_properties: nil) ⇒ ProgramAction
Returns a new instance of ProgramAction.
38 39 40 41 42 43 44 45 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 38 def initialize(item_identifiers:, programs:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item_identifiers = item_identifiers @programs = programs @additional_properties = additional_properties end |
Instance Attribute Details
#item_identifiers ⇒ ItemIdentifiers
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 14 def item_identifiers @item_identifiers end |
#programs ⇒ Programs
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 18 def programs @programs end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_identifiers = ItemIdentifiers.from_hash(hash['ItemIdentifiers']) if hash['ItemIdentifiers'] programs = Programs.from_hash(hash['Programs']) if hash['Programs'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProgramAction.new(item_identifiers: item_identifiers, programs: programs, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['item_identifiers'] = 'ItemIdentifiers' @_hash['programs'] = 'Programs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} item_identifiers: #{@item_identifiers.inspect}, programs:"\ " #{@programs.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/walmart_ap_is/models/program_action.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} item_identifiers: #{@item_identifiers}, programs: #{@programs},"\ " additional_properties: #{@additional_properties}>" end |