Class: WalmartApIs::PromoDiscount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/promo_discount.rb

Overview

PromoDiscount Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sku:, price:, msrp:, additional_properties: nil) ⇒ PromoDiscount

Returns a new instance of PromoDiscount.



43
44
45
46
47
48
49
50
51
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 43

def initialize(sku:, price:, msrp:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sku = sku
  @price = price
  @msrp = msrp
  @additional_properties = additional_properties
end

Instance Attribute Details

#msrpInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 22

def msrp
  @msrp
end

#priceInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 18

def price
  @price
end

#skuString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 14

def sku
  @sku
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sku = hash.key?('sku') ? hash['sku'] : nil
  price = hash.key?('price') ? hash['price'] : nil
  msrp = hash.key?('msrp') ? hash['msrp'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PromoDiscount.new(sku: sku,
                    price: price,
                    msrp: msrp,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sku'] = 'sku'
  @_hash['price'] = 'price'
  @_hash['msrp'] = 'msrp'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sku: #{@sku.inspect}, price: #{@price.inspect}, msrp: #{@msrp.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/walmart_ap_is/models/promo_discount.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sku: #{@sku}, price: #{@price}, msrp: #{@msrp}, additional_properties:"\
  " #{@additional_properties}>"
end