Class: WalmartApIs::ProofOfDelivery

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/proof_of_delivery.rb

Overview

ProofOfDelivery Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(delivered_time: SKIP, recipient_name: SKIP, signature_image: SKIP, additional_properties: nil) ⇒ ProofOfDelivery

Returns a new instance of ProofOfDelivery.



48
49
50
51
52
53
54
55
56
57
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 48

def initialize(delivered_time: SKIP, recipient_name: SKIP,
               signature_image: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @delivered_time = delivered_time unless delivered_time == SKIP
  @recipient_name = recipient_name unless recipient_name == SKIP
  @signature_image = signature_image unless signature_image == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#delivered_timeDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


15
16
17
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 15

def delivered_time
  @delivered_time
end

#recipient_nameString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 19

def recipient_name
  @recipient_name
end

#signature_imageString

Base64-encoded signature image bytes.

Returns:

  • (String)


23
24
25
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 23

def signature_image
  @signature_image
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  delivered_time = if hash.key?('deliveredTime')
                     (DateTimeHelper.from_rfc3339(hash['deliveredTime']) if hash['deliveredTime'])
                   else
                     SKIP
                   end
  recipient_name = hash.key?('recipientName') ? hash['recipientName'] : SKIP
  signature_image =
    hash.key?('signatureImage') ? hash['signatureImage'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProofOfDelivery.new(delivered_time: delivered_time,
                      recipient_name: recipient_name,
                      signature_image: signature_image,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['delivered_time'] = 'deliveredTime'
  @_hash['recipient_name'] = 'recipientName'
  @_hash['signature_image'] = 'signatureImage'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 35

def self.optionals
  %w[
    delivered_time
    recipient_name
    signature_image
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} delivered_time: #{@delivered_time.inspect}, recipient_name:"\
  " #{@recipient_name.inspect}, signature_image: #{@signature_image.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_delivered_timeObject



87
88
89
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 87

def to_custom_delivered_time
  DateTimeHelper.to_rfc3339(delivered_time)
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/walmart_ap_is/models/proof_of_delivery.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} delivered_time: #{@delivered_time}, recipient_name: #{@recipient_name},"\
  " signature_image: #{@signature_image}, additional_properties: #{@additional_properties}>"
end