Class: WalmartApIs::Quantity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/quantity.rb

Overview

Quantity Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount: SKIP, unit: Unit::EA, additional_properties: nil) ⇒ Quantity

Returns a new instance of Quantity.



41
42
43
44
45
46
47
48
# File 'lib/walmart_ap_is/models/quantity.rb', line 41

def initialize(amount: SKIP, unit: Unit::EA, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount unless amount == SKIP
  @unit = unit unless unit == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/walmart_ap_is/models/quantity.rb', line 14

def amount
  @amount
end

#unitUnit

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/quantity.rb', line 18

def unit
  @unit
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/walmart_ap_is/models/quantity.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? hash['amount'] : SKIP
  unit = hash['unit'] ||= Unit::EA

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Quantity.new(amount: amount,
               unit: unit,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/quantity.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['unit'] = 'unit'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/walmart_ap_is/models/quantity.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/walmart_ap_is/models/quantity.rb', line 29

def self.optionals
  %w[
    amount
    unit
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/walmart_ap_is/models/quantity.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, unit: #{@unit.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/walmart_ap_is/models/quantity.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, unit: #{@unit}, additional_properties:"\
  " #{@additional_properties}>"
end