Class: WalmartApIs::QuantityDiscountPriceType
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::QuantityDiscountPriceType
- Defined in:
- lib/walmart_ap_is/models/quantity_discount_price_type.rb
Overview
Contains pricing information for bulk purchase discounts.
Instance Attribute Summary collapse
-
#listing_price ⇒ MoneyType
Currency type and monetary value.
-
#quantity_discount_type ⇒ String
readonly
Indicates the type of quantity discount this price applies to.
-
#quantity_tier ⇒ Integer
Indicates at what quantity this price becomes active.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(quantity_tier:, listing_price:, additional_properties: nil) ⇒ QuantityDiscountPriceType
constructor
A new instance of QuantityDiscountPriceType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(quantity_tier:, listing_price:, additional_properties: nil) ⇒ QuantityDiscountPriceType
Returns a new instance of QuantityDiscountPriceType.
43 44 45 46 47 48 49 50 51 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 43 def initialize(quantity_tier:, listing_price:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @quantity_tier = quantity_tier @quantity_discount_type = 'QUANTITY_DISCOUNT' @listing_price = listing_price @additional_properties = additional_properties end |
Instance Attribute Details
#listing_price ⇒ MoneyType
Currency type and monetary value.
22 23 24 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 22 def listing_price @listing_price end |
#quantity_discount_type ⇒ String (readonly)
Indicates the type of quantity discount this price applies to.
18 19 20 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 18 def quantity_discount_type @quantity_discount_type end |
#quantity_tier ⇒ Integer
Indicates at what quantity this price becomes active.
14 15 16 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 14 def quantity_tier @quantity_tier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. quantity_tier = hash.key?('quantityTier') ? hash['quantityTier'] : nil listing_price = MoneyType.from_hash(hash['listingPrice']) if hash['listingPrice'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. QuantityDiscountPriceType.new(quantity_tier: quantity_tier, listing_price: listing_price, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['quantity_tier'] = 'quantityTier' @_hash['quantity_discount_type'] = 'quantityDiscountType' @_hash['listing_price'] = 'listingPrice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} quantity_tier: #{@quantity_tier.inspect}, quantity_discount_type:"\ " #{@quantity_discount_type.inspect}, listing_price: #{@listing_price.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/quantity_discount_price_type.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} quantity_tier: #{@quantity_tier}, quantity_discount_type:"\ " #{@quantity_discount_type}, listing_price: #{@listing_price}, additional_properties:"\ " #{@additional_properties}>" end |