Class: WalmartApIs::Reason
- Defined in:
- lib/walmart_ap_is/models/reason.rb
Overview
Reason Model.
Instance Attribute Summary collapse
-
#links ⇒ Array[Link]
Localized human-readable message explaining the restriction.
-
#message ⇒ String
Localized human-readable message explaining the restriction.
-
#reason_code ⇒ ReasonCode
Localized human-readable message explaining the restriction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(message:, reason_code:, links: SKIP, additional_properties: nil) ⇒ Reason
constructor
A new instance of Reason.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(message:, reason_code:, links: SKIP, additional_properties: nil) ⇒ Reason
Returns a new instance of Reason.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/walmart_ap_is/models/reason.rb', line 45 def initialize(message:, reason_code:, links: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @message = @reason_code = reason_code @links = links unless links == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#links ⇒ Array[Link]
Localized human-readable message explaining the restriction
22 23 24 |
# File 'lib/walmart_ap_is/models/reason.rb', line 22 def links @links end |
#message ⇒ String
Localized human-readable message explaining the restriction
14 15 16 |
# File 'lib/walmart_ap_is/models/reason.rb', line 14 def @message end |
#reason_code ⇒ ReasonCode
Localized human-readable message explaining the restriction
18 19 20 |
# File 'lib/walmart_ap_is/models/reason.rb', line 18 def reason_code @reason_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/reason.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('message') ? hash['message'] : nil reason_code = hash.key?('reasonCode') ? hash['reasonCode'] : nil # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (Link.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Reason.new(message: , reason_code: reason_code, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/reason.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['message'] = 'message' @_hash['reason_code'] = 'reasonCode' @_hash['links'] = 'links' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/walmart_ap_is/models/reason.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/walmart_ap_is/models/reason.rb', line 34 def self.optionals %w[ links ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/walmart_ap_is/models/reason.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} message: #{@message.inspect}, reason_code: #{@reason_code.inspect}, links:"\ " #{@links.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/reason.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} message: #{@message}, reason_code: #{@reason_code}, links: #{@links},"\ " additional_properties: #{@additional_properties}>" end |