Class: WalmartApIs::RejectedShippingService
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::RejectedShippingService
- Defined in:
- lib/walmart_ap_is/models/rejected_shipping_service.rb
Overview
RejectedShippingService Model.
Instance Attribute Summary collapse
-
#carrier_name ⇒ String
TODO: Write general description for this method.
-
#rejection_reason_code ⇒ String
TODO: Write general description for this method.
-
#rejection_reason_message ⇒ String
TODO: Write general description for this method.
-
#shipping_service_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(carrier_name: SKIP, shipping_service_id: SKIP, rejection_reason_code: SKIP, rejection_reason_message: SKIP, additional_properties: nil) ⇒ RejectedShippingService
constructor
A new instance of RejectedShippingService.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(carrier_name: SKIP, shipping_service_id: SKIP, rejection_reason_code: SKIP, rejection_reason_message: SKIP, additional_properties: nil) ⇒ RejectedShippingService
Returns a new instance of RejectedShippingService.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 53 def initialize(carrier_name: SKIP, shipping_service_id: SKIP, rejection_reason_code: SKIP, rejection_reason_message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @carrier_name = carrier_name unless carrier_name == SKIP @shipping_service_id = shipping_service_id unless shipping_service_id == SKIP @rejection_reason_code = rejection_reason_code unless rejection_reason_code == SKIP @rejection_reason_message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#carrier_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 14 def carrier_name @carrier_name end |
#rejection_reason_code ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 22 def rejection_reason_code @rejection_reason_code end |
#rejection_reason_message ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 26 def @rejection_reason_message end |
#shipping_service_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 18 def shipping_service_id @shipping_service_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. carrier_name = hash.key?('carrierName') ? hash['carrierName'] : SKIP shipping_service_id = hash.key?('shippingServiceId') ? hash['shippingServiceId'] : SKIP rejection_reason_code = hash.key?('rejectionReasonCode') ? hash['rejectionReasonCode'] : SKIP = hash.key?('rejectionReasonMessage') ? hash['rejectionReasonMessage'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RejectedShippingService.new(carrier_name: carrier_name, shipping_service_id: shipping_service_id, rejection_reason_code: rejection_reason_code, rejection_reason_message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['carrier_name'] = 'carrierName' @_hash['shipping_service_id'] = 'shippingServiceId' @_hash['rejection_reason_code'] = 'rejectionReasonCode' @_hash['rejection_reason_message'] = 'rejectionReasonMessage' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 39 def self.optionals %w[ carrier_name shipping_service_id rejection_reason_code rejection_reason_message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 110 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} carrier_name: #{@carrier_name.inspect}, shipping_service_id:"\ " #{@shipping_service_id.inspect}, rejection_reason_code: #{@rejection_reason_code.inspect},"\ " rejection_reason_message: #{@rejection_reason_message.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 101 |
# File 'lib/walmart_ap_is/models/rejected_shipping_service.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} carrier_name: #{@carrier_name}, shipping_service_id:"\ " #{@shipping_service_id}, rejection_reason_code: #{@rejection_reason_code},"\ " rejection_reason_message: #{@rejection_reason_message}, additional_properties:"\ " #{@additional_properties}>" end |