Class: WalmartApIs::RepricerFeedsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/walmart_ap_is/apis/repricer_feeds_api.rb

Overview

RepricerFeedsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from WalmartApIs::BaseApi

Instance Method Details

#assign_unassign_items_to_from_repricer_strategy(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ ApiResponse

Adds or removes one or more items from a repricer strategy. Use this API to assign or unassign repricer strategies for items listed in Walmart Marketplace. In one feed you can update up to 10,000 items in bulk. To ensure optimal feed processing time, we recommend sending no more than 1000 items in one feed and keeping the feed sizes below 10 MB.

For more information and usage examples, refer to the <a

href=“developer.walmart.com/us-marketplace/docs/assign-unassign-it ems-to-repricer”>Pricing API Guide</a>. obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called. parameter: TODO: type description here

Parameters:

  • wm_sec_access_token (String)

    Required parameter: Access token

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: A unique ID that

  • wm_svc_name (String)

    Required parameter: Specifies the name of the

  • accept (String)

    Required parameter: TODO: type description here

  • body (AssignUnassignItemsToFromRepricerStrategyRequest)

    Required

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/walmart_ap_is/apis/repricer_feeds_api.rb', line 33

def assign_unassign_items_to_from_repricer_strategy(wm_sec_access_token,
                                                    wm_consumer_channel_type,
                                                    wm_qos_correlation_id,
                                                    wm_svc_name,
                                                    accept,
                                                    body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/repricerFeeds',
                                 Server::SERVER_1)
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')
                              .is_required(true))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')
                              .is_required(true))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')
                              .is_required(true))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(accept, key: 'Accept')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation8.method(:from_hash))
                .is_api_response(true))
    .execute
end