Class: WalmartApIs::RequestedUpdates
- Defined in:
- lib/walmart_ap_is/models/requested_updates.rb
Overview
Objects that were included in the update request.
Instance Attribute Summary collapse
-
#boxes ⇒ Array[BoxUpdateInput]
A list of boxes that will be present in the shipment after the update.
-
#items ⇒ Array[ItemInput]
A list of all items that will be present in the shipment after the update.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(boxes: SKIP, items: SKIP, additional_properties: nil) ⇒ RequestedUpdates
constructor
A new instance of RequestedUpdates.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(boxes: SKIP, items: SKIP, additional_properties: nil) ⇒ RequestedUpdates
Returns a new instance of RequestedUpdates.
41 42 43 44 45 46 47 48 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 41 def initialize(boxes: SKIP, items: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @boxes = boxes unless boxes == SKIP @items = items unless items == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#boxes ⇒ Array[BoxUpdateInput]
A list of boxes that will be present in the shipment after the update.
14 15 16 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 14 def boxes @boxes end |
#items ⇒ Array[ItemInput]
A list of all items that will be present in the shipment after the update.
18 19 20 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 18 def items @items end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it boxes = nil unless hash['boxes'].nil? boxes = [] hash['boxes'].each do |structure| boxes << (BoxUpdateInput.from_hash(structure) if structure) end end boxes = SKIP unless hash.key?('boxes') # Parameter is an array, so we need to iterate through it items = nil unless hash['items'].nil? items = [] hash['items'].each do |structure| items << (ItemInput.from_hash(structure) if structure) end end items = SKIP unless hash.key?('items') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RequestedUpdates.new(boxes: boxes, items: items, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['boxes'] = 'boxes' @_hash['items'] = 'items' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 29 def self.optionals %w[ boxes items ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} boxes: #{@boxes.inspect}, items: #{@items.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/walmart_ap_is/models/requested_updates.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} boxes: #{@boxes}, items: #{@items}, additional_properties:"\ " #{@additional_properties}>" end |