Class: WalmartApIs::RequestedValueAddedService

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/requested_value_added_service.rb

Overview

RequestedValueAddedService Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, details: SKIP, additional_properties: nil) ⇒ RequestedValueAddedService

Returns a new instance of RequestedValueAddedService.



42
43
44
45
46
47
48
49
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 42

def initialize(id:, details: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @details = details unless details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailsObject

Service-specific input payload. Validated against the schema published in availableValueAddedServices on the corresponding Rate. Compressed shape; see TODO.

Returns:

  • (Object)


20
21
22
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 20

def details
  @details
end

#idString

Identifier of the value-added service being requested.

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 14

def id
  @id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  details = hash.key?('details') ? hash['details'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RequestedValueAddedService.new(id: id,
                                 details: details,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['details'] = 'details'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 31

def self.optionals
  %w[
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, details: #{@details.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/walmart_ap_is/models/requested_value_added_service.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, details: #{@details}, additional_properties:"\
  " #{@additional_properties}>"
end