Class: WalmartApIs::Restriction

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/restriction.rb

Overview

Restriction Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(marketplace_id:, condition_type:, reasons: SKIP, additional_properties: nil) ⇒ Restriction

Returns a new instance of Restriction.



45
46
47
48
49
50
51
52
53
54
# File 'lib/walmart_ap_is/models/restriction.rb', line 45

def initialize(marketplace_id:, condition_type:, reasons: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @marketplace_id = marketplace_id
  @condition_type = condition_type
  @reasons = reasons unless reasons == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#condition_typeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/restriction.rb', line 18

def condition_type
  @condition_type
end

#marketplace_idMarketplaceId

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/restriction.rb', line 14

def marketplace_id
  @marketplace_id
end

#reasonsArray[Reason]

Empty array means listing is not restricted

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/restriction.rb', line 22

def reasons
  @reasons
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/walmart_ap_is/models/restriction.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : nil
  condition_type = hash.key?('conditionType') ? hash['conditionType'] : nil
  # Parameter is an array, so we need to iterate through it
  reasons = nil
  unless hash['reasons'].nil?
    reasons = []
    hash['reasons'].each do |structure|
      reasons << (Reason.from_hash(structure) if structure)
    end
  end

  reasons = SKIP unless hash.key?('reasons')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Restriction.new(marketplace_id: marketplace_id,
                  condition_type: condition_type,
                  reasons: reasons,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/restriction.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['marketplace_id'] = 'marketplaceId'
  @_hash['condition_type'] = 'conditionType'
  @_hash['reasons'] = 'reasons'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/walmart_ap_is/models/restriction.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/walmart_ap_is/models/restriction.rb', line 34

def self.optionals
  %w[
    reasons
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/walmart_ap_is/models/restriction.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, condition_type:"\
  " #{@condition_type.inspect}, reasons: #{@reasons.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/walmart_ap_is/models/restriction.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} marketplace_id: #{@marketplace_id}, condition_type: #{@condition_type},"\
  " reasons: #{@reasons}, additional_properties: #{@additional_properties}>"
end