Class: WalmartApIs::SalesRank
- Defined in:
- lib/walmart_ap_is/models/sales_rank.rb
Overview
SalesRank Model.
Instance Attribute Summary collapse
-
#category_id ⇒ String
TODO: Write general description for this method.
-
#category_name ⇒ String
TODO: Write general description for this method.
-
#link ⇒ String
TODO: Write general description for this method.
-
#rank ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(category_id: SKIP, rank: SKIP, category_name: SKIP, link: SKIP, additional_properties: nil) ⇒ SalesRank
constructor
A new instance of SalesRank.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category_id: SKIP, rank: SKIP, category_name: SKIP, link: SKIP, additional_properties: nil) ⇒ SalesRank
Returns a new instance of SalesRank.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 53 def initialize(category_id: SKIP, rank: SKIP, category_name: SKIP, link: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @category_id = category_id unless category_id == SKIP @rank = rank unless rank == SKIP @category_name = category_name unless category_name == SKIP @link = link unless link == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#category_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 14 def category_id @category_id end |
#category_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 22 def category_name @category_name end |
#link ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 26 def link @link end |
#rank ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 18 def rank @rank end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category_id = hash.key?('categoryId') ? hash['categoryId'] : SKIP rank = hash.key?('rank') ? hash['rank'] : SKIP category_name = hash.key?('categoryName') ? hash['categoryName'] : SKIP link = hash.key?('link') ? hash['link'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SalesRank.new(category_id: category_id, rank: rank, category_name: category_name, link: link, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['category_id'] = 'categoryId' @_hash['rank'] = 'rank' @_hash['category_name'] = 'categoryName' @_hash['link'] = 'link' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 39 def self.optionals %w[ category_id rank category_name link ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} category_id: #{@category_id.inspect}, rank: #{@rank.inspect},"\ " category_name: #{@category_name.inspect}, link: #{@link.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/sales_rank.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} category_id: #{@category_id}, rank: #{@rank}, category_name:"\ " #{@category_name}, link: #{@link}, additional_properties: #{@additional_properties}>" end |