Class: WalmartApIs::SalesRankType

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/sales_rank_type.rb

Overview

Sales rank information for the item, by category.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(product_category_id:, rank:, additional_properties: nil) ⇒ SalesRankType

Returns a new instance of SalesRankType.



38
39
40
41
42
43
44
45
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 38

def initialize(product_category_id:, rank:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @product_category_id = product_category_id
  @rank = rank
  @additional_properties = additional_properties
end

Instance Attribute Details

#product_category_idString

Identifies the item category from which the sales rank is taken.

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 14

def product_category_id
  @product_category_id
end

#rankInteger

The sales rank of the item within the item category.

Returns:

  • (Integer)


18
19
20
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 18

def rank
  @rank
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  product_category_id =
    hash.key?('ProductCategoryId') ? hash['ProductCategoryId'] : nil
  rank = hash.key?('Rank') ? hash['Rank'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SalesRankType.new(product_category_id: product_category_id,
                    rank: rank,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['product_category_id'] = 'ProductCategoryId'
  @_hash['rank'] = 'Rank'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} product_category_id: #{@product_category_id.inspect}, rank:"\
  " #{@rank.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/walmart_ap_is/models/sales_rank_type.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} product_category_id: #{@product_category_id}, rank: #{@rank},"\
  " additional_properties: #{@additional_properties}>"
end