Class: WalmartApIs::SelfShipAppointmentDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/self_ship_appointment_details.rb

Overview

Appointment details for carrier pickup or Ship Node appointments.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(appointment_id: SKIP, appointment_slot_time: SKIP, appointment_status: SKIP, additional_properties: nil) ⇒ SelfShipAppointmentDetails

Returns a new instance of SelfShipAppointmentDetails.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 47

def initialize(appointment_id: SKIP, appointment_slot_time: SKIP,
               appointment_status: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @appointment_id = appointment_id unless appointment_id == SKIP
  @appointment_slot_time = appointment_slot_time unless appointment_slot_time == SKIP
  @appointment_status = appointment_status unless appointment_status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#appointment_idFloat

Identifier for appointment.

Returns:

  • (Float)


14
15
16
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 14

def appointment_id
  @appointment_id
end

#appointment_slot_timeAppointmentSlotTime

An appointment slot time with start and end.

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 18

def appointment_slot_time
  @appointment_slot_time
end

#appointment_statusString

Status of the appointment.

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 22

def appointment_status
  @appointment_status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  appointment_id = hash.key?('appointmentId') ? hash['appointmentId'] : SKIP
  appointment_slot_time = AppointmentSlotTime.from_hash(hash['appointmentSlotTime']) if
    hash['appointmentSlotTime']
  appointment_status =
    hash.key?('appointmentStatus') ? hash['appointmentStatus'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SelfShipAppointmentDetails.new(appointment_id: appointment_id,
                                 appointment_slot_time: appointment_slot_time,
                                 appointment_status: appointment_status,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['appointment_id'] = 'appointmentId'
  @_hash['appointment_slot_time'] = 'appointmentSlotTime'
  @_hash['appointment_status'] = 'appointmentStatus'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 34

def self.optionals
  %w[
    appointment_id
    appointment_slot_time
    appointment_status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} appointment_id: #{@appointment_id.inspect}, appointment_slot_time:"\
  " #{@appointment_slot_time.inspect}, appointment_status: #{@appointment_status.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/walmart_ap_is/models/self_ship_appointment_details.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} appointment_id: #{@appointment_id}, appointment_slot_time:"\
  " #{@appointment_slot_time}, appointment_status: #{@appointment_status},"\
  " additional_properties: #{@additional_properties}>"
end