Class: WalmartApIs::SellerSkuIdentifier
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::SellerSkuIdentifier
- Defined in:
- lib/walmart_ap_is/models/seller_sku_identifier.rb
Overview
Schema to identify an item by MarketPlaceId, SellerId, and SellerSKU.
Instance Attribute Summary collapse
-
#marketplace_id ⇒ String
A marketplace identifier.
-
#seller_id ⇒ String
The seller identifier submitted for the operation.
-
#seller_sku ⇒ String
The seller stock keeping unit (SKU) of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id:, seller_id:, seller_sku:, additional_properties: nil) ⇒ SellerSkuIdentifier
constructor
A new instance of SellerSkuIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id:, seller_id:, seller_sku:, additional_properties: nil) ⇒ SellerSkuIdentifier
Returns a new instance of SellerSkuIdentifier.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 43 def initialize(marketplace_id:, seller_id:, seller_sku:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id @seller_id = seller_id @seller_sku = seller_sku @additional_properties = additional_properties end |
Instance Attribute Details
#marketplace_id ⇒ String
A marketplace identifier.
14 15 16 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 14 def marketplace_id @marketplace_id end |
#seller_id ⇒ String
The seller identifier submitted for the operation.
18 19 20 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 18 def seller_id @seller_id end |
#seller_sku ⇒ String
The seller stock keeping unit (SKU) of the item.
22 23 24 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 22 def seller_sku @seller_sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('MarketplaceId') ? hash['MarketplaceId'] : nil seller_id = hash.key?('SellerId') ? hash['SellerId'] : nil seller_sku = hash.key?('SellerSKU') ? hash['SellerSKU'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SellerSkuIdentifier.new(marketplace_id: marketplace_id, seller_id: seller_id, seller_sku: seller_sku, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'MarketplaceId' @_hash['seller_id'] = 'SellerId' @_hash['seller_sku'] = 'SellerSKU' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, seller_id:"\ " #{@seller_id.inspect}, seller_sku: #{@seller_sku.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/seller_sku_identifier.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, seller_id: #{@seller_id}, seller_sku:"\ " #{@seller_sku}, additional_properties: #{@additional_properties}>" end |