Class: WalmartApIs::ServiceSelection
- Defined in:
- lib/walmart_ap_is/models/service_selection.rb
Overview
Optional seller-supplied filter to restrict the rate quote to a specific carrier(s) and/or service(s).
Instance Attribute Summary collapse
-
#carrier_ids ⇒ Array[String]
TODO: Write general description for this method.
-
#service_ids ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(service_ids: SKIP, carrier_ids: SKIP, additional_properties: nil) ⇒ ServiceSelection
constructor
A new instance of ServiceSelection.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(service_ids: SKIP, carrier_ids: SKIP, additional_properties: nil) ⇒ ServiceSelection
Returns a new instance of ServiceSelection.
42 43 44 45 46 47 48 49 50 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 42 def initialize(service_ids: SKIP, carrier_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @service_ids = service_ids unless service_ids == SKIP @carrier_ids = carrier_ids unless carrier_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#carrier_ids ⇒ Array[String]
TODO: Write general description for this method
19 20 21 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 19 def carrier_ids @carrier_ids end |
#service_ids ⇒ Array[String]
TODO: Write general description for this method
15 16 17 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 15 def service_ids @service_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. service_ids = hash.key?('serviceIds') ? hash['serviceIds'] : SKIP carrier_ids = hash.key?('carrierIds') ? hash['carrierIds'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ServiceSelection.new(service_ids: service_ids, carrier_ids: carrier_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['service_ids'] = 'serviceIds' @_hash['carrier_ids'] = 'carrierIds' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 30 def self.optionals %w[ service_ids carrier_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} service_ids: #{@service_ids.inspect}, carrier_ids: #{@carrier_ids.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/walmart_ap_is/models/service_selection.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} service_ids: #{@service_ids}, carrier_ids: #{@carrier_ids},"\ " additional_properties: #{@additional_properties}>" end |