Class: WalmartApIs::SetPackingInformationRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::SetPackingInformationRequest
- Defined in:
- lib/walmart_ap_is/models/set_packing_information_request.rb
Overview
The setPackingInformation request.
Instance Attribute Summary collapse
-
#package_groupings ⇒ Array[PackageGroupingInput]
List of packing information for the inbound plan.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(package_groupings:, additional_properties: nil) ⇒ SetPackingInformationRequest
constructor
A new instance of SetPackingInformationRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_groupings:, additional_properties: nil) ⇒ SetPackingInformationRequest
Returns a new instance of SetPackingInformationRequest.
33 34 35 36 37 38 39 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 33 def initialize(package_groupings:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @package_groupings = package_groupings @additional_properties = additional_properties end |
Instance Attribute Details
#package_groupings ⇒ Array[PackageGroupingInput]
List of packing information for the inbound plan.
14 15 16 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 14 def package_groupings @package_groupings end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it package_groupings = nil unless hash['packageGroupings'].nil? package_groupings = [] hash['packageGroupings'].each do |structure| package_groupings << (PackageGroupingInput.from_hash(structure) if structure) end end package_groupings = nil unless hash.key?('packageGroupings') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SetPackingInformationRequest.new(package_groupings: package_groupings, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['package_groupings'] = 'packageGroupings' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_groupings: #{@package_groupings.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/walmart_ap_is/models/set_packing_information_request.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_groupings: #{@package_groupings}, additional_properties:"\ " #{@additional_properties}>" end |