Class: WalmartApIs::ShipOrderLine

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/ship_order_line.rb

Overview

ShipOrderLine Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(line_number:, tracking_info:, ship_quantity: SKIP, additional_properties: nil) ⇒ ShipOrderLine

Returns a new instance of ShipOrderLine.



45
46
47
48
49
50
51
52
53
54
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 45

def initialize(line_number:, tracking_info:, ship_quantity: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @line_number = line_number
  @ship_quantity = ship_quantity unless ship_quantity == SKIP
  @tracking_info = tracking_info
  @additional_properties = additional_properties
end

Instance Attribute Details

#line_numberString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 14

def line_number
  @line_number
end

#ship_quantityQuantityWithUnit

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 18

def ship_quantity
  @ship_quantity
end

#tracking_infoTrackingInfo

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 22

def tracking_info
  @tracking_info
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  line_number = hash.key?('lineNumber') ? hash['lineNumber'] : nil
  tracking_info = TrackingInfo.from_hash(hash['trackingInfo']) if hash['trackingInfo']
  ship_quantity = QuantityWithUnit.from_hash(hash['shipQuantity']) if hash['shipQuantity']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ShipOrderLine.new(line_number: line_number,
                    tracking_info: tracking_info,
                    ship_quantity: ship_quantity,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['line_number'] = 'lineNumber'
  @_hash['ship_quantity'] = 'shipQuantity'
  @_hash['tracking_info'] = 'trackingInfo'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 34

def self.optionals
  %w[
    ship_quantity
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
92
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} line_number: #{@line_number.inspect}, ship_quantity:"\
  " #{@ship_quantity.inspect}, tracking_info: #{@tracking_info.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/walmart_ap_is/models/ship_order_line.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} line_number: #{@line_number}, ship_quantity: #{@ship_quantity},"\
  " tracking_info: #{@tracking_info}, additional_properties: #{@additional_properties}>"
end