Class: WalmartApIs::ShipPackageLine

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/ship_package_line.rb

Overview

ShipPackageLine Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(line_number:, ship_quantity: SKIP, additional_properties: nil) ⇒ ShipPackageLine

Returns a new instance of ShipPackageLine.



40
41
42
43
44
45
46
47
48
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 40

def initialize(line_number:, ship_quantity: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @line_number = line_number
  @ship_quantity = ship_quantity unless ship_quantity == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#line_numberString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 14

def line_number
  @line_number
end

#ship_quantityQuantityWithUnit

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 18

def ship_quantity
  @ship_quantity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  line_number = hash.key?('lineNumber') ? hash['lineNumber'] : nil
  ship_quantity = QuantityWithUnit.from_hash(hash['shipQuantity']) if hash['shipQuantity']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ShipPackageLine.new(line_number: line_number,
                      ship_quantity: ship_quantity,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['line_number'] = 'lineNumber'
  @_hash['ship_quantity'] = 'shipQuantity'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 29

def self.optionals
  %w[
    ship_quantity
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} line_number: #{@line_number.inspect}, ship_quantity:"\
  " #{@ship_quantity.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/walmart_ap_is/models/ship_package_line.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} line_number: #{@line_number}, ship_quantity: #{@ship_quantity},"\
  " additional_properties: #{@additional_properties}>"
end