Class: WalmartApIs::ShipmentSource

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/shipment_source.rb

Overview

Specifies the 'ship from' address for the shipment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(source_type:, address: SKIP, additional_properties: nil) ⇒ ShipmentSource

Returns a new instance of ShipmentSource.



40
41
42
43
44
45
46
47
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 40

def initialize(source_type:, address: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address = address unless address == SKIP
  @source_type = source_type
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressAddress

Specific details to identify a place.

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 14

def address
  @address
end

#source_typeString

The type of source for this shipment. Possible values: SELLER_FACILITY.

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 18

def source_type
  @source_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  source_type = hash.key?('sourceType') ? hash['sourceType'] : nil
  address = Address.from_hash(hash['address']) if hash['address']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ShipmentSource.new(source_type: source_type,
                     address: address,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['source_type'] = 'sourceType'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 29

def self.optionals
  %w[
    address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, source_type: #{@source_type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/walmart_ap_is/models/shipment_source.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, source_type: #{@source_type}, additional_properties:"\
  " #{@additional_properties}>"
end