Class: WalmartApIs::ShipmentSummary
- Defined in:
- lib/walmart_ap_is/models/shipment_summary.rb
Overview
Summary information about a shipment.
Instance Attribute Summary collapse
-
#shipment_id ⇒ String
Identifier of a shipment.
-
#status ⇒ String
The status of a shipment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shipment_id:, status:, additional_properties: nil) ⇒ ShipmentSummary
constructor
A new instance of ShipmentSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shipment_id:, status:, additional_properties: nil) ⇒ ShipmentSummary
Returns a new instance of ShipmentSummary.
41 42 43 44 45 46 47 48 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 41 def initialize(shipment_id:, status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @shipment_id = shipment_id @status = status @additional_properties = additional_properties end |
Instance Attribute Details
#shipment_id ⇒ String
Identifier of a shipment. A shipment contains the boxes and units being inbounded.
15 16 17 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 15 def shipment_id @shipment_id end |
#status ⇒ String
The status of a shipment. Possible values: ABANDONED, CANCELLED,
CHECKED_IN, CLOSED, DELETED, DELIVERED, IN_TRANSIT, MIXED,
READY_TO_SHIP, RECEIVING, SHIPPED, UNCONFIRMED, WORKING.
21 22 23 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 21 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. shipment_id = hash.key?('shipmentId') ? hash['shipmentId'] : nil status = hash.key?('status') ? hash['status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ShipmentSummary.new(shipment_id: shipment_id, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['shipment_id'] = 'shipmentId' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} shipment_id: #{@shipment_id.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/walmart_ap_is/models/shipment_summary.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} shipment_id: #{@shipment_id}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |