Class: WalmartApIs::ShippingRequirements
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ShippingRequirements
- Defined in:
- lib/walmart_ap_is/models/shipping_requirements.rb
Overview
The possible shipping modes for the packing option for a given shipping solution.
Instance Attribute Summary collapse
-
#modes ⇒ Array[String]
Available shipment modes for this shipping program.
-
#solution ⇒ String
Shipping program for the option.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(modes:, solution:, additional_properties: nil) ⇒ ShippingRequirements
constructor
A new instance of ShippingRequirements.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(modes:, solution:, additional_properties: nil) ⇒ ShippingRequirements
Returns a new instance of ShippingRequirements.
40 41 42 43 44 45 46 47 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 40 def initialize(modes:, solution:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @modes = modes @solution = solution @additional_properties = additional_properties end |
Instance Attribute Details
#modes ⇒ Array[String]
Available shipment modes for this shipping program.
15 16 17 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 15 def modes @modes end |
#solution ⇒ String
Shipping program for the option. Can be: WALMART_PARTNERED_CARRIER,
USE_YOUR_OWN_CARRIER.
20 21 22 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 20 def solution @solution end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. modes = hash.key?('modes') ? hash['modes'] : nil solution = hash.key?('solution') ? hash['solution'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ShippingRequirements.new(modes: modes, solution: solution, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['modes'] = 'modes' @_hash['solution'] = 'solution' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} modes: #{@modes.inspect}, solution: #{@solution.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/shipping_requirements.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} modes: #{@modes}, solution: #{@solution}, additional_properties:"\ " #{@additional_properties}>" end |