Class: WalmartApIs::ShipsFromType
- Defined in:
- lib/walmart_ap_is/models/ships_from_type.rb
Overview
The state and country from where the item is shipped.
Instance Attribute Summary collapse
-
#country ⇒ String
The country from where the item is shipped.
-
#state ⇒ String
The state from where the item is shipped.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(state: SKIP, country: SKIP, additional_properties: nil) ⇒ ShipsFromType
constructor
A new instance of ShipsFromType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(state: SKIP, country: SKIP, additional_properties: nil) ⇒ ShipsFromType
Returns a new instance of ShipsFromType.
41 42 43 44 45 46 47 48 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 41 def initialize(state: SKIP, country: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @state = state unless state == SKIP @country = country unless country == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ String
The country from where the item is shipped.
18 19 20 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 18 def country @country end |
#state ⇒ String
The state from where the item is shipped.
14 15 16 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 14 def state @state end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. state = hash.key?('State') ? hash['State'] : SKIP country = hash.key?('Country') ? hash['Country'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ShipsFromType.new(state: state, country: country, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['state'] = 'State' @_hash['country'] = 'Country' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 29 def self.optionals %w[ state country ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} state: #{@state.inspect}, country: #{@country.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/walmart_ap_is/models/ships_from_type.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} state: #{@state}, country: #{@country}, additional_properties:"\ " #{@additional_properties}>" end |