Class: WalmartApIs::Size
- Defined in:
- lib/walmart_ap_is/models/size.rb
Overview
Size Model.
Instance Attribute Summary collapse
-
#length ⇒ Float
TODO: Write general description for this method.
-
#unit ⇒ Unit1
TODO: Write general description for this method.
-
#width ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(width: SKIP, length: SKIP, unit: SKIP, additional_properties: nil) ⇒ Size
constructor
A new instance of Size.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(width: SKIP, length: SKIP, unit: SKIP, additional_properties: nil) ⇒ Size
Returns a new instance of Size.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/size.rb', line 47 def initialize(width: SKIP, length: SKIP, unit: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @width = width unless width == SKIP @length = length unless length == SKIP @unit = unit unless unit == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#length ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/size.rb', line 18 def length @length end |
#unit ⇒ Unit1
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/size.rb', line 22 def unit @unit end |
#width ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/size.rb', line 14 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/size.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. width = hash.key?('width') ? hash['width'] : SKIP length = hash.key?('length') ? hash['length'] : SKIP unit = hash.key?('unit') ? hash['unit'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Size.new(width: width, length: length, unit: unit, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/size.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['width'] = 'width' @_hash['length'] = 'length' @_hash['unit'] = 'unit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/size.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/size.rb', line 34 def self.optionals %w[ width length unit ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/size.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} width: #{@width.inspect}, length: #{@length.inspect}, unit:"\ " #{@unit.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/size.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} width: #{@width}, length: #{@length}, unit: #{@unit},"\ " additional_properties: #{@additional_properties}>" end |