Class: WalmartApIs::Sort
- Defined in:
- lib/walmart_ap_is/models/sort.rb
Overview
Sort Model.
Instance Attribute Summary collapse
-
#sort_field ⇒ String
TODO: Write general description for this method.
-
#sort_order ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(sort_field:, sort_order:, additional_properties: nil) ⇒ Sort
constructor
A new instance of Sort.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(sort_field:, sort_order:, additional_properties: nil) ⇒ Sort
Returns a new instance of Sort.
38 39 40 41 42 43 44 45 |
# File 'lib/walmart_ap_is/models/sort.rb', line 38 def initialize(sort_field:, sort_order:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @sort_field = sort_field @sort_order = sort_order @additional_properties = additional_properties end |
Instance Attribute Details
#sort_field ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/sort.rb', line 14 def sort_field @sort_field end |
#sort_order ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/sort.rb', line 18 def sort_order @sort_order end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/walmart_ap_is/models/sort.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. sort_field = hash.key?('sortField') ? hash['sortField'] : nil sort_order = hash.key?('sortOrder') ? hash['sortOrder'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Sort.new(sort_field: sort_field, sort_order: sort_order, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/sort.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['sort_field'] = 'sortField' @_hash['sort_order'] = 'sortOrder' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/walmart_ap_is/models/sort.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/walmart_ap_is/models/sort.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/sort.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} sort_field: #{@sort_field.inspect}, sort_order: #{@sort_order.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/walmart_ap_is/models/sort.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} sort_field: #{@sort_field}, sort_order: #{@sort_order},"\ " additional_properties: #{@additional_properties}>" end |