Class: WalmartApIs::StrategyApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/walmart_ap_is/apis/strategy_api.rb

Overview

StrategyApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from WalmartApIs::BaseApi

Instance Method Details

#create_repricer_strategy(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ ApiResponse

Creates a new repricing strategy on Walmart Marketplace. A repricer strategy defines how item prices should be automatically adjusted based on competitor pricing, buy box position, or other rules. Use this API when onboarding new pricing logic or launching a dynamic pricing strategy that responds to market conditions automatically. For more information and usage examples, refer to the <a href=“developer.walmart.com/us-marketplace/docs/create-new-reprice r-strategy”>Pricing API Guide</a>. obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called. description here

Parameters:

  • wm_sec_access_token (String)

    Required parameter: Access token

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: A unique ID that

  • wm_svc_name (String)

    Required parameter: Specifies the name of the

  • accept (String)

    Required parameter: TODO: type description here

  • body (CreateRepricerStrategyRequest)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/walmart_ap_is/apis/strategy_api.rb', line 32

def create_repricer_strategy(wm_sec_access_token,
                             wm_consumer_channel_type,
                             wm_qos_correlation_id,
                             wm_svc_name,
                             accept,
                             body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/repricer/strategy',
                                 Server::SERVER_1)
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')
                              .is_required(true))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')
                              .is_required(true))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')
                              .is_required(true))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(accept, key: 'Accept')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation.method(:from_hash))
                .is_api_response(true))
    .execute
end