Class: WalmartApIs::TaxRate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/tax_rate.rb

Overview

Contains the type and rate of tax.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(cess_rate: SKIP, gst_rate: SKIP, tax_type: SKIP, additional_properties: nil) ⇒ TaxRate

Returns a new instance of TaxRate.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 47

def initialize(cess_rate: SKIP, gst_rate: SKIP, tax_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cess_rate = cess_rate unless cess_rate == SKIP
  @gst_rate = gst_rate unless gst_rate == SKIP
  @tax_type = tax_type unless tax_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cess_rateFloat

Rate of cess tax.

Returns:

  • (Float)


14
15
16
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 14

def cess_rate
  @cess_rate
end

#gst_rateFloat

Rate of gst tax.

Returns:

  • (Float)


18
19
20
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 18

def gst_rate
  @gst_rate
end

#tax_typeString

Type of tax. Possible values: CGST, SGST, IGST, TOTAL_TAX.

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 22

def tax_type
  @tax_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  cess_rate = hash.key?('cessRate') ? hash['cessRate'] : SKIP
  gst_rate = hash.key?('gstRate') ? hash['gstRate'] : SKIP
  tax_type = hash.key?('taxType') ? hash['taxType'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TaxRate.new(cess_rate: cess_rate,
              gst_rate: gst_rate,
              tax_type: tax_type,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cess_rate'] = 'cessRate'
  @_hash['gst_rate'] = 'gstRate'
  @_hash['tax_type'] = 'taxType'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 34

def self.optionals
  %w[
    cess_rate
    gst_rate
    tax_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cess_rate: #{@cess_rate.inspect}, gst_rate: #{@gst_rate.inspect}, tax_type:"\
  " #{@tax_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/walmart_ap_is/models/tax_rate.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cess_rate: #{@cess_rate}, gst_rate: #{@gst_rate}, tax_type: #{@tax_type},"\
  " additional_properties: #{@additional_properties}>"
end