Class: WalmartApIs::TokenApiAuthorizationCode
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::TokenApiAuthorizationCode
- Defined in:
- lib/walmart_ap_is/models/token_api_authorization_code.rb
Overview
TokenApiAuthorizationCode Model.
Instance Attribute Summary collapse
-
#access_token ⇒ String
TODO: Write general description for this method.
-
#client_credentials_res ⇒ ClientCredentialsRes
TODO: Write general description for this method.
-
#expires_in ⇒ Integer
TODO: Write general description for this method.
-
#refresh_token_res ⇒ RefreshTokenRes
TODO: Write general description for this method.
-
#token_api_res ⇒ TokenApiRes
TODO: Write general description for this method.
-
#token_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_credentials_res:, token_api_res:, refresh_token_res:, access_token:, token_type:, expires_in:, additional_properties: nil) ⇒ TokenApiAuthorizationCode
constructor
A new instance of TokenApiAuthorizationCode.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_credentials_res:, token_api_res:, refresh_token_res:, access_token:, token_type:, expires_in:, additional_properties: nil) ⇒ TokenApiAuthorizationCode
Returns a new instance of TokenApiAuthorizationCode.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 58 def initialize(client_credentials_res:, token_api_res:, refresh_token_res:, access_token:, token_type:, expires_in:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_credentials_res = client_credentials_res @token_api_res = token_api_res @refresh_token_res = refresh_token_res @access_token = access_token @token_type = token_type @expires_in = expires_in @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 26 def access_token @access_token end |
#client_credentials_res ⇒ ClientCredentialsRes
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 14 def client_credentials_res @client_credentials_res end |
#expires_in ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 34 def expires_in @expires_in end |
#refresh_token_res ⇒ RefreshTokenRes
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 22 def refresh_token_res @refresh_token_res end |
#token_api_res ⇒ TokenApiRes
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 18 def token_api_res @token_api_res end |
#token_type ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 30 def token_type @token_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_credentials_res = ClientCredentialsRes.from_hash(hash['clientCredentialsRes']) if hash['clientCredentialsRes'] token_api_res = TokenApiRes.from_hash(hash['tokenAPIRes']) if hash['tokenAPIRes'] refresh_token_res = RefreshTokenRes.from_hash(hash['refreshTokenRes']) if hash['refreshTokenRes'] access_token = hash.key?('access_token') ? hash['access_token'] : nil token_type = hash.key?('token_type') ? hash['token_type'] : nil expires_in = hash.key?('expires_in') ? hash['expires_in'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TokenApiAuthorizationCode.new(client_credentials_res: client_credentials_res, token_api_res: token_api_res, refresh_token_res: refresh_token_res, access_token: access_token, token_type: token_type, expires_in: expires_in, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_credentials_res'] = 'clientCredentialsRes' @_hash['token_api_res'] = 'tokenAPIRes' @_hash['refresh_token_res'] = 'refreshTokenRes' @_hash['access_token'] = 'access_token' @_hash['token_type'] = 'token_type' @_hash['expires_in'] = 'expires_in' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 120 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_credentials_res: #{@client_credentials_res.inspect}, token_api_res:"\ " #{@token_api_res.inspect}, refresh_token_res: #{@refresh_token_res.inspect}, access_token:"\ " #{@access_token.inspect}, token_type: #{@token_type.inspect}, expires_in:"\ " #{@expires_in.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 110 111 |
# File 'lib/walmart_ap_is/models/token_api_authorization_code.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_credentials_res: #{@client_credentials_res}, token_api_res:"\ " #{@token_api_res}, refresh_token_res: #{@refresh_token_res}, access_token:"\ " #{@access_token}, token_type: #{@token_type}, expires_in: #{@expires_in},"\ " additional_properties: #{@additional_properties}>" end |