Class: WalmartApIs::TokenApiRes

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/token_api_res.rb

Overview

TokenApiRes Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(summary:, value:, additional_properties: nil) ⇒ TokenApiRes

Returns a new instance of TokenApiRes.



38
39
40
41
42
43
44
45
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 38

def initialize(summary:, value:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @summary = summary
  @value = value
  @additional_properties = additional_properties
end

Instance Attribute Details

#summaryString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 14

def summary
  @summary
end

#valueValue1

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 18

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  summary = hash.key?('summary') ? hash['summary'] : nil
  value = Value1.from_hash(hash['value']) if hash['value']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenApiRes.new(summary: summary,
                  value: value,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['summary'] = 'summary'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} summary: #{@summary.inspect}, value: #{@value.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/walmart_ap_is/models/token_api_res.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} summary: #{@summary}, value: #{@value}, additional_properties:"\
  " #{@additional_properties}>"
end