Class: WalmartApIs::TransactionSearchResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/transaction_search_response.rb

Overview

TransactionSearchResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(next_token: SKIP, total_records: SKIP, transactions: SKIP, additional_properties: nil) ⇒ TransactionSearchResponse

Returns a new instance of TransactionSearchResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 47

def initialize(next_token: SKIP, total_records: SKIP, transactions: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @next_token = next_token unless next_token == SKIP
  @total_records = total_records unless total_records == SKIP
  @transactions = transactions unless transactions == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#next_tokenString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 14

def next_token
  @next_token
end

#total_recordsInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 18

def total_records
  @total_records
end

#transactionsArray[SettlementTransaction]

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 22

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  next_token = hash.key?('nextToken') ? hash['nextToken'] : SKIP
  total_records = hash.key?('totalRecords') ? hash['totalRecords'] : SKIP
  # Parameter is an array, so we need to iterate through it
  transactions = nil
  unless hash['transactions'].nil?
    transactions = []
    hash['transactions'].each do |structure|
      transactions << (SettlementTransaction.from_hash(structure) if structure)
    end
  end

  transactions = SKIP unless hash.key?('transactions')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionSearchResponse.new(next_token: next_token,
                                total_records: total_records,
                                transactions: transactions,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['next_token'] = 'nextToken'
  @_hash['total_records'] = 'totalRecords'
  @_hash['transactions'] = 'transactions'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 34

def self.optionals
  %w[
    next_token
    total_records
    transactions
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} next_token: #{@next_token.inspect}, total_records:"\
  " #{@total_records.inspect}, transactions: #{@transactions.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/walmart_ap_is/models/transaction_search_response.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} next_token: #{@next_token}, total_records: #{@total_records}, transactions:"\
  " #{@transactions}, additional_properties: #{@additional_properties}>"
end