Class: WalmartApIs::UpdateFulfillmentOrderResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/update_fulfillment_order_response.rb

Overview

UpdateFulfillmentOrderResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(seller_fulfillment_order_id: SKIP, additional_properties: nil) ⇒ UpdateFulfillmentOrderResponse

Returns a new instance of UpdateFulfillmentOrderResponse.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 35

def initialize(seller_fulfillment_order_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless seller_fulfillment_order_id == SKIP
    @seller_fulfillment_order_id =
      seller_fulfillment_order_id
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#seller_fulfillment_order_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 14

def seller_fulfillment_order_id
  @seller_fulfillment_order_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  seller_fulfillment_order_id =
    hash.key?('sellerFulfillmentOrderId') ? hash['sellerFulfillmentOrderId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateFulfillmentOrderResponse.new(seller_fulfillment_order_id: seller_fulfillment_order_id,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['seller_fulfillment_order_id'] = 'sellerFulfillmentOrderId'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 24

def self.optionals
  %w[
    seller_fulfillment_order_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} seller_fulfillment_order_id: #{@seller_fulfillment_order_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



68
69
70
71
72
# File 'lib/walmart_ap_is/models/update_fulfillment_order_response.rb', line 68

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} seller_fulfillment_order_id: #{@seller_fulfillment_order_id},"\
  " additional_properties: #{@additional_properties}>"
end