Class: WalmartApIs::UpdateInventoryRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/update_inventory_request.rb

Overview

UpdateInventoryRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(quantity:, ship_node: SKIP, fulfillment_lag: SKIP, additional_properties: nil) ⇒ UpdateInventoryRequest

Returns a new instance of UpdateInventoryRequest.



46
47
48
49
50
51
52
53
54
55
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 46

def initialize(quantity:, ship_node: SKIP, fulfillment_lag: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @quantity = quantity
  @ship_node = ship_node unless ship_node == SKIP
  @fulfillment_lag = fulfillment_lag unless fulfillment_lag == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fulfillment_lagInteger

Lead time in days to ship (0-4 for standard)

Returns:

  • (Integer)


22
23
24
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 22

def fulfillment_lag
  @fulfillment_lag
end

#quantityQuantity

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 14

def quantity
  @quantity
end

#ship_nodeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 18

def ship_node
  @ship_node
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  quantity = Quantity.from_hash(hash['quantity']) if hash['quantity']
  ship_node = hash.key?('shipNode') ? hash['shipNode'] : SKIP
  fulfillment_lag =
    hash.key?('fulfillmentLag') ? hash['fulfillmentLag'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateInventoryRequest.new(quantity: quantity,
                             ship_node: ship_node,
                             fulfillment_lag: fulfillment_lag,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['quantity'] = 'quantity'
  @_hash['ship_node'] = 'shipNode'
  @_hash['fulfillment_lag'] = 'fulfillmentLag'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 34

def self.optionals
  %w[
    ship_node
    fulfillment_lag
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
94
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} quantity: #{@quantity.inspect}, ship_node: #{@ship_node.inspect},"\
  " fulfillment_lag: #{@fulfillment_lag.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/walmart_ap_is/models/update_inventory_request.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} quantity: #{@quantity}, ship_node: #{@ship_node}, fulfillment_lag:"\
  " #{@fulfillment_lag}, additional_properties: #{@additional_properties}>"
end