Class: WalmartApIs::UpdateShipmentStatusResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::UpdateShipmentStatusResponse
- Defined in:
- lib/walmart_ap_is/models/update_shipment_status_response.rb
Overview
UpdateShipmentStatusResponse Model.
Instance Attribute Summary collapse
-
#purchase_order_id ⇒ String
TODO: Write general description for this method.
-
#shipment_status ⇒ ShipmentStatus11
TODO: Write general description for this method.
-
#updated_at ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(purchase_order_id: SKIP, shipment_status: SKIP, updated_at: SKIP, additional_properties: nil) ⇒ UpdateShipmentStatusResponse
constructor
A new instance of UpdateShipmentStatusResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(purchase_order_id: SKIP, shipment_status: SKIP, updated_at: SKIP, additional_properties: nil) ⇒ UpdateShipmentStatusResponse
Returns a new instance of UpdateShipmentStatusResponse.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 48 def initialize(purchase_order_id: SKIP, shipment_status: SKIP, updated_at: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @purchase_order_id = purchase_order_id unless purchase_order_id == SKIP @shipment_status = shipment_status unless shipment_status == SKIP @updated_at = updated_at unless updated_at == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#purchase_order_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 15 def purchase_order_id @purchase_order_id end |
#shipment_status ⇒ ShipmentStatus11
TODO: Write general description for this method
19 20 21 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 19 def shipment_status @shipment_status end |
#updated_at ⇒ DateTime
TODO: Write general description for this method
23 24 25 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 23 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. purchase_order_id = hash.key?('purchaseOrderId') ? hash['purchaseOrderId'] : SKIP shipment_status = hash.key?('shipmentStatus') ? hash['shipmentStatus'] : SKIP updated_at = if hash.key?('updatedAt') (DateTimeHelper.from_rfc3339(hash['updatedAt']) if hash['updatedAt']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateShipmentStatusResponse.new(purchase_order_id: purchase_order_id, shipment_status: shipment_status, updated_at: updated_at, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['purchase_order_id'] = 'purchaseOrderId' @_hash['shipment_status'] = 'shipmentStatus' @_hash['updated_at'] = 'updatedAt' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 35 def self.optionals %w[ purchase_order_id shipment_status updated_at ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} purchase_order_id: #{@purchase_order_id.inspect}, shipment_status:"\ " #{@shipment_status.inspect}, updated_at: #{@updated_at.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_updated_at ⇒ Object
88 89 90 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 88 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/walmart_ap_is/models/update_shipment_status_response.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} purchase_order_id: #{@purchase_order_id}, shipment_status:"\ " #{@shipment_status}, updated_at: #{@updated_at}, additional_properties:"\ " #{@additional_properties}>" end |