Class: WalmartApIs::UpdateVerificationStatusResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/update_verification_status_response.rb

Overview

UpdateVerificationStatusResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(purchase_order_id: SKIP, verification_status: SKIP, updated_at: SKIP, additional_properties: nil) ⇒ UpdateVerificationStatusResponse

Returns a new instance of UpdateVerificationStatusResponse.



48
49
50
51
52
53
54
55
56
57
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 48

def initialize(purchase_order_id: SKIP, verification_status: SKIP,
               updated_at: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @purchase_order_id = purchase_order_id unless purchase_order_id == SKIP
  @verification_status = verification_status unless verification_status == SKIP
  @updated_at = updated_at unless updated_at == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#purchase_order_idString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 15

def purchase_order_id
  @purchase_order_id
end

#updated_atDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


23
24
25
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 23

def updated_at
  @updated_at
end

#verification_statusVerificationStatus1

TODO: Write general description for this method

Returns:



19
20
21
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 19

def verification_status
  @verification_status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  purchase_order_id =
    hash.key?('purchaseOrderId') ? hash['purchaseOrderId'] : SKIP
  verification_status =
    hash.key?('verificationStatus') ? hash['verificationStatus'] : SKIP
  updated_at = if hash.key?('updatedAt')
                 (DateTimeHelper.from_rfc3339(hash['updatedAt']) if hash['updatedAt'])
               else
                 SKIP
               end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateVerificationStatusResponse.new(purchase_order_id: purchase_order_id,
                                       verification_status: verification_status,
                                       updated_at: updated_at,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['purchase_order_id'] = 'purchaseOrderId'
  @_hash['verification_status'] = 'verificationStatus'
  @_hash['updated_at'] = 'updatedAt'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 35

def self.optionals
  %w[
    purchase_order_id
    verification_status
    updated_at
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
106
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} purchase_order_id: #{@purchase_order_id.inspect}, verification_status:"\
  " #{@verification_status.inspect}, updated_at: #{@updated_at.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_updated_atObject



88
89
90
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 88

def to_custom_updated_at
  DateTimeHelper.to_rfc3339(updated_at)
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
98
# File 'lib/walmart_ap_is/models/update_verification_status_response.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} purchase_order_id: #{@purchase_order_id}, verification_status:"\
  " #{@verification_status}, updated_at: #{@updated_at}, additional_properties:"\
  " #{@additional_properties}>"
end