Class: WalmartApIs::Value

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/value.rb

Overview

Value Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, token_type:, expires_in:, additional_properties: nil) ⇒ Value

Returns a new instance of Value.



43
44
45
46
47
48
49
50
51
52
# File 'lib/walmart_ap_is/models/value.rb', line 43

def initialize(access_token:, token_type:, expires_in:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token
  @token_type = token_type
  @expires_in = expires_in
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/value.rb', line 14

def access_token
  @access_token
end

#expires_inInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/walmart_ap_is/models/value.rb', line 22

def expires_in
  @expires_in
end

#token_typeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/value.rb', line 18

def token_type
  @token_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/walmart_ap_is/models/value.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  token_type = hash.key?('token_type') ? hash['token_type'] : nil
  expires_in = hash.key?('expires_in') ? hash['expires_in'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Value.new(access_token: access_token,
            token_type: token_type,
            expires_in: expires_in,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/walmart_ap_is/models/value.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'access_token'
  @_hash['token_type'] = 'token_type'
  @_hash['expires_in'] = 'expires_in'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/walmart_ap_is/models/value.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/walmart_ap_is/models/value.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/walmart_ap_is/models/value.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, token_type: #{@token_type.inspect},"\
  " expires_in: #{@expires_in.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/walmart_ap_is/models/value.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, token_type: #{@token_type}, expires_in:"\
  " #{@expires_in}, additional_properties: #{@additional_properties}>"
end