Class: WalmartApIs::Value1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/value1.rb

Overview

Value1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, refresh_token:, token_type:, expires_in:, additional_properties: nil) ⇒ Value1

Returns a new instance of Value1.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/walmart_ap_is/models/value1.rb', line 48

def initialize(access_token:, refresh_token:, token_type:, expires_in:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token
  @refresh_token = refresh_token
  @token_type = token_type
  @expires_in = expires_in
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/value1.rb', line 14

def access_token
  @access_token
end

#expires_inInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/walmart_ap_is/models/value1.rb', line 26

def expires_in
  @expires_in
end

#refresh_tokenString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/value1.rb', line 18

def refresh_token
  @refresh_token
end

#token_typeString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/walmart_ap_is/models/value1.rb', line 22

def token_type
  @token_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/walmart_ap_is/models/value1.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  refresh_token = hash.key?('refresh_token') ? hash['refresh_token'] : nil
  token_type = hash.key?('token_type') ? hash['token_type'] : nil
  expires_in = hash.key?('expires_in') ? hash['expires_in'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Value1.new(access_token: access_token,
             refresh_token: refresh_token,
             token_type: token_type,
             expires_in: expires_in,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/walmart_ap_is/models/value1.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'access_token'
  @_hash['refresh_token'] = 'refresh_token'
  @_hash['token_type'] = 'token_type'
  @_hash['expires_in'] = 'expires_in'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/walmart_ap_is/models/value1.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/walmart_ap_is/models/value1.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/walmart_ap_is/models/value1.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, refresh_token:"\
  " #{@refresh_token.inspect}, token_type: #{@token_type.inspect}, expires_in:"\
  " #{@expires_in.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
91
# File 'lib/walmart_ap_is/models/value1.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, refresh_token: #{@refresh_token},"\
  " token_type: #{@token_type}, expires_in: #{@expires_in}, additional_properties:"\
  " #{@additional_properties}>"
end