Class: WalmartApIs::ValueAddedService

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/walmart_ap_is/models/value_added_service.rb

Overview

ValueAddedService Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code:, description: SKIP, additional_properties: nil) ⇒ ValueAddedService

Returns a new instance of ValueAddedService.



40
41
42
43
44
45
46
47
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 40

def initialize(code:, description: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code
  @description = description unless description == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

Short service code (e.g. ADULT_SIGNATURE).

Returns:

  • (String)


14
15
16
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 14

def code
  @code
end

#descriptionString

Human-readable description of the service.

Returns:

  • (String)


18
19
20
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 18

def description
  @description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : nil
  description = hash.key?('description') ? hash['description'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ValueAddedService.new(code: code,
                        description: description,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['description'] = 'description'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 29

def self.optionals
  %w[
    description
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, description: #{@description.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/walmart_ap_is/models/value_added_service.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, description: #{@description}, additional_properties:"\
  " #{@additional_properties}>"
end