Class: WalmartApIs::WeightRange
- Defined in:
- lib/walmart_ap_is/models/weight_range.rb
Overview
The range of weights that are allowed for a package.
Instance Attribute Summary collapse
-
#maximum ⇒ Float
Maximum allowed weight.
-
#minimum ⇒ Float
Minimum allowed weight.
-
#unit ⇒ UnitOfWeight
Unit of the weight being measured.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(maximum:, minimum:, unit:, additional_properties: nil) ⇒ WeightRange
constructor
A new instance of WeightRange.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(maximum:, minimum:, unit:, additional_properties: nil) ⇒ WeightRange
Returns a new instance of WeightRange.
43 44 45 46 47 48 49 50 51 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 43 def initialize(maximum:, minimum:, unit:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @maximum = maximum @minimum = minimum @unit = unit @additional_properties = additional_properties end |
Instance Attribute Details
#maximum ⇒ Float
Maximum allowed weight.
14 15 16 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 14 def maximum @maximum end |
#minimum ⇒ Float
Minimum allowed weight.
18 19 20 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 18 def minimum @minimum end |
#unit ⇒ UnitOfWeight
Unit of the weight being measured.
22 23 24 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 22 def unit @unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. maximum = hash.key?('maximum') ? hash['maximum'] : nil minimum = hash.key?('minimum') ? hash['minimum'] : nil unit = hash.key?('unit') ? hash['unit'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WeightRange.new(maximum: maximum, minimum: minimum, unit: unit, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['maximum'] = 'maximum' @_hash['minimum'] = 'minimum' @_hash['unit'] = 'unit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} maximum: #{@maximum.inspect}, minimum: #{@minimum.inspect}, unit:"\ " #{@unit.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/walmart_ap_is/models/weight_range.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} maximum: #{@maximum}, minimum: #{@minimum}, unit: #{@unit},"\ " additional_properties: #{@additional_properties}>" end |