Class: WalmartApIs::WindowInput
- Defined in:
- lib/walmart_ap_is/models/window_input.rb
Overview
Contains only a starting DateTime.
Instance Attribute Summary collapse
-
#start ⇒ DateTime
The start date of the window.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start:, additional_properties: nil) ⇒ WindowInput
constructor
A new instance of WindowInput.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_start ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start:, additional_properties: nil) ⇒ WindowInput
Returns a new instance of WindowInput.
35 36 37 38 39 40 41 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 35 def initialize(start:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start = start @additional_properties = additional_properties end |
Instance Attribute Details
#start ⇒ DateTime
The start date of the window. In ISO 8601 datetime format with minute precision.
16 17 18 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 16 def start @start end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start = if hash.key?('start') (DateTimeHelper.from_rfc3339(hash['start']) if hash['start']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WindowInput.new(start: start, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['start'] = 'start' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} start: #{@start.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_start ⇒ Object
64 65 66 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 64 def to_custom_start DateTimeHelper.to_rfc3339(start) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/walmart_ap_is/models/window_input.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} start: #{@start}, additional_properties: #{@additional_properties}>" end |