Class: WalmartApIs::BatchOffersRequestParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::BatchOffersRequestParams
- Defined in:
- lib/walmart_ap_is/models/batch_offers_request_params.rb
Overview
Common request parameters for ItemOffersRequest and ListingOffersRequest.
Instance Attribute Summary collapse
-
#customer_type ⇒ CustomerType
Indicates whether to request Consumer or Business offers.
-
#item_condition ⇒ ConditionType2
Indicates the condition of the item.
-
#marketplace_id ⇒ String
A marketplace identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id:, item_condition:, customer_type: SKIP, additional_properties: nil) ⇒ BatchOffersRequestParams
constructor
A new instance of BatchOffersRequestParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id:, item_condition:, customer_type: SKIP, additional_properties: nil) ⇒ BatchOffersRequestParams
Returns a new instance of BatchOffersRequestParams.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 47 def initialize(marketplace_id:, item_condition:, customer_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id @item_condition = item_condition @customer_type = customer_type unless customer_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#customer_type ⇒ CustomerType
Indicates whether to request Consumer or Business offers. Default is Consumer.
24 25 26 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 24 def customer_type @customer_type end |
#item_condition ⇒ ConditionType2
Indicates the condition of the item. Possible values: New, Used, Collectible, Refurbished, Club.
19 20 21 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 19 def item_condition @item_condition end |
#marketplace_id ⇒ String
A marketplace identifier.
14 15 16 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 14 def marketplace_id @marketplace_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('MarketplaceId') ? hash['MarketplaceId'] : nil item_condition = hash.key?('ItemCondition') ? hash['ItemCondition'] : nil customer_type = hash.key?('CustomerType') ? hash['CustomerType'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BatchOffersRequestParams.new(marketplace_id: marketplace_id, item_condition: item_condition, customer_type: customer_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'MarketplaceId' @_hash['item_condition'] = 'ItemCondition' @_hash['customer_type'] = 'CustomerType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 36 def self.optionals %w[ customer_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, item_condition:"\ " #{@item_condition.inspect}, customer_type: #{@customer_type.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/batch_offers_request_params.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, item_condition: #{@item_condition},"\ " customer_type: #{@customer_type}, additional_properties: #{@additional_properties}>" end |