Class: WalmartApIs::ClassificationRefinement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ClassificationRefinement
- Defined in:
- lib/walmart_ap_is/models/classification_refinement.rb
Overview
ClassificationRefinement Model.
Instance Attribute Summary collapse
-
#category_id ⇒ String
TODO: Write general description for this method.
-
#display_name ⇒ String
TODO: Write general description for this method.
-
#number_of_results ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(category_id: SKIP, display_name: SKIP, number_of_results: SKIP, additional_properties: nil) ⇒ ClassificationRefinement
constructor
A new instance of ClassificationRefinement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category_id: SKIP, display_name: SKIP, number_of_results: SKIP, additional_properties: nil) ⇒ ClassificationRefinement
Returns a new instance of ClassificationRefinement.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 47 def initialize(category_id: SKIP, display_name: SKIP, number_of_results: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @category_id = category_id unless category_id == SKIP @display_name = display_name unless display_name == SKIP @number_of_results = number_of_results unless number_of_results == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#category_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 14 def category_id @category_id end |
#display_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 18 def display_name @display_name end |
#number_of_results ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 22 def number_of_results @number_of_results end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category_id = hash.key?('categoryId') ? hash['categoryId'] : SKIP display_name = hash.key?('displayName') ? hash['displayName'] : SKIP number_of_results = hash.key?('numberOfResults') ? hash['numberOfResults'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ClassificationRefinement.new(category_id: category_id, display_name: display_name, number_of_results: number_of_results, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['category_id'] = 'categoryId' @_hash['display_name'] = 'displayName' @_hash['number_of_results'] = 'numberOfResults' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 34 def self.optionals %w[ category_id display_name number_of_results ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 96 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} category_id: #{@category_id.inspect}, display_name:"\ " #{@display_name.inspect}, number_of_results: #{@number_of_results.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/classification_refinement.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} category_id: #{@category_id}, display_name: #{@display_name},"\ " number_of_results: #{@number_of_results}, additional_properties:"\ " #{@additional_properties}>" end |