Class: WalmartApIs::FeedsFeedTypeIncentiveEnrollmentApi
- Defined in:
- lib/walmart_ap_is/apis/feeds_feed_type_incentive_enrollment_api.rb
Overview
FeedsFeedTypeIncentiveEnrollmentApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#update_reduced_referral_fee_incentives_enrollment(feed_type, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ ApiResponse
You can use this API endpoint to enroll any eligible item to Reduced Referral Fee incentive.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from WalmartApIs::BaseApi
Instance Method Details
#update_reduced_referral_fee_incentives_enrollment(feed_type, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ ApiResponse
You can use this API endpoint to enroll any eligible item to Reduced Referral Fee incentive. You can also use this endpoint to unenroll any items from active Reduced Referral Fee incentives. For more information and usage examples, refer to the <a href=“developer.walmart.com/us-marketplace/docs/enroll-in-reduced- referral-fee-incentives”>Pricing API Guide</a>. here obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called. parameter: TODO: type description here
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/walmart_ap_is/apis/feeds_feed_type_incentive_enrollment_api.rb', line 32 def update_reduced_referral_fee_incentives_enrollment(feed_type, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/feeds', Server::SERVER_1) .query_param(new_parameter(feed_type, key: 'feedType') .is_required(true)) .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN') .is_required(true)) .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE') .is_required(true)) .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID') .is_required(true)) .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME') .is_required(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .header_param(new_parameter(accept, key: 'Accept') .is_required(true)) .body_param(new_parameter(body) .is_required(true)) .body_serializer(proc do |param| param.to_json unless param.nil? end)) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(SuccessfulOperation11.method(:from_hash)) .is_api_response(true)) .execute end |