Class: WalmartApIs::FeesEstimateError
- Defined in:
- lib/walmart_ap_is/models/fees_estimate_error.rb
Overview
Error detail when a fee estimate could not be computed.
Instance Attribute Summary collapse
-
#code ⇒ String
TODO: Write general description for this method.
-
#detail ⇒ Array[String]
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type:, code:, message:, detail:, additional_properties: nil) ⇒ FeesEstimateError
constructor
A new instance of FeesEstimateError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type:, code:, message:, detail:, additional_properties: nil) ⇒ FeesEstimateError
Returns a new instance of FeesEstimateError.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 48 def initialize(type:, code:, message:, detail:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type @code = code @message = @detail = detail @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 18 def code @code end |
#detail ⇒ Array[String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 26 def detail @detail end |
#message ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 22 def @message end |
#type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 14 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('Type') ? hash['Type'] : nil code = hash.key?('Code') ? hash['Code'] : nil = hash.key?('Message') ? hash['Message'] : nil detail = hash.key?('Detail') ? hash['Detail'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FeesEstimateError.new(type: type, code: code, message: , detail: detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'Type' @_hash['code'] = 'Code' @_hash['message'] = 'Message' @_hash['detail'] = 'Detail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, code: #{@code.inspect}, message:"\ " #{@message.inspect}, detail: #{@detail.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/walmart_ap_is/models/fees_estimate_error.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, code: #{@code}, message: #{@message}, detail: #{@detail},"\ " additional_properties: #{@additional_properties}>" end |