Class: WalmartApIs::FileContents
- Defined in:
- lib/walmart_ap_is/models/file_contents.rb
Overview
FileContents Model.
Instance Attribute Summary collapse
-
#checksum ⇒ String
Base64-encoded label file.
-
#contents ⇒ String
Base64-encoded label file.
-
#file_type ⇒ FileType
Base64-encoded label file.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contents: SKIP, file_type: SKIP, checksum: SKIP, additional_properties: nil) ⇒ FileContents
constructor
A new instance of FileContents.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contents: SKIP, file_type: SKIP, checksum: SKIP, additional_properties: nil) ⇒ FileContents
Returns a new instance of FileContents.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 47 def initialize(contents: SKIP, file_type: SKIP, checksum: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @contents = contents unless contents == SKIP @file_type = file_type unless file_type == SKIP @checksum = checksum unless checksum == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#checksum ⇒ String
Base64-encoded label file
22 23 24 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 22 def checksum @checksum end |
#contents ⇒ String
Base64-encoded label file
14 15 16 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 14 def contents @contents end |
#file_type ⇒ FileType
Base64-encoded label file
18 19 20 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 18 def file_type @file_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. contents = hash.key?('contents') ? hash['contents'] : SKIP file_type = hash.key?('fileType') ? hash['fileType'] : SKIP checksum = hash.key?('checksum') ? hash['checksum'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FileContents.new(contents: contents, file_type: file_type, checksum: checksum, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['contents'] = 'contents' @_hash['file_type'] = 'fileType' @_hash['checksum'] = 'checksum' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 34 def self.optionals %w[ contents file_type checksum ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} contents: #{@contents.inspect}, file_type: #{@file_type.inspect}, checksum:"\ " #{@checksum.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/file_contents.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} contents: #{@contents}, file_type: #{@file_type}, checksum: #{@checksum},"\ " additional_properties: #{@additional_properties}>" end |