Class: WalmartApIs::GetEligibleShippingServicesResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::GetEligibleShippingServicesResponse
- Defined in:
- lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb
Overview
GetEligibleShippingServicesResponse Model.
Instance Attribute Summary collapse
-
#rejected_shipping_service_list ⇒ Array[RejectedShippingService]
TODO: Write general description for this method.
-
#shipping_service_list ⇒ Array[ShippingService]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shipping_service_list: SKIP, rejected_shipping_service_list: SKIP, additional_properties: nil) ⇒ GetEligibleShippingServicesResponse
constructor
A new instance of GetEligibleShippingServicesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shipping_service_list: SKIP, rejected_shipping_service_list: SKIP, additional_properties: nil) ⇒ GetEligibleShippingServicesResponse
Returns a new instance of GetEligibleShippingServicesResponse.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 41 def initialize(shipping_service_list: SKIP, rejected_shipping_service_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @shipping_service_list = shipping_service_list unless shipping_service_list == SKIP unless rejected_shipping_service_list == SKIP @rejected_shipping_service_list = rejected_shipping_service_list end @additional_properties = additional_properties end |
Instance Attribute Details
#rejected_shipping_service_list ⇒ Array[RejectedShippingService]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 18 def rejected_shipping_service_list @rejected_shipping_service_list end |
#shipping_service_list ⇒ Array[ShippingService]
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 14 def shipping_service_list @shipping_service_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it shipping_service_list = nil unless hash['shippingServiceList'].nil? shipping_service_list = [] hash['shippingServiceList'].each do |structure| shipping_service_list << (ShippingService.from_hash(structure) if structure) end end shipping_service_list = SKIP unless hash.key?('shippingServiceList') # Parameter is an array, so we need to iterate through it rejected_shipping_service_list = nil unless hash['rejectedShippingServiceList'].nil? rejected_shipping_service_list = [] hash['rejectedShippingServiceList'].each do |structure| rejected_shipping_service_list << (RejectedShippingService.from_hash(structure) if structure) end end rejected_shipping_service_list = SKIP unless hash.key?('rejectedShippingServiceList') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetEligibleShippingServicesResponse.new(shipping_service_list: shipping_service_list, rejected_shipping_service_list: rejected_shipping_service_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['shipping_service_list'] = 'shippingServiceList' @_hash['rejected_shipping_service_list'] = 'rejectedShippingServiceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 29 def self.optionals %w[ shipping_service_list rejected_shipping_service_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} shipping_service_list: #{@shipping_service_list.inspect},"\ " rejected_shipping_service_list: #{@rejected_shipping_service_list.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/walmart_ap_is/models/get_eligible_shipping_services_response.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} shipping_service_list: #{@shipping_service_list},"\ " rejected_shipping_service_list: #{@rejected_shipping_service_list}, additional_properties:"\ " #{@additional_properties}>" end |