Class: WalmartApIs::IdentifierType1
- Defined in:
- lib/walmart_ap_is/models/identifier_type1.rb
Overview
Specifies the identifiers used to uniquely identify an item.
Instance Attribute Summary collapse
-
#marketplace_item ⇒ WalmartItemIdentifier
Schema to identify an item by MarketPlaceId and Walmart Item ID (see ADR-029).
-
#sku_identifier ⇒ SellerSkuIdentifier
Schema to identify an item by MarketPlaceId, SellerId, and SellerSKU.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_item:, sku_identifier: SKIP, additional_properties: nil) ⇒ IdentifierType1
constructor
A new instance of IdentifierType1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_item:, sku_identifier: SKIP, additional_properties: nil) ⇒ IdentifierType1
Returns a new instance of IdentifierType1.
41 42 43 44 45 46 47 48 49 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 41 def initialize(marketplace_item:, sku_identifier: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_item = marketplace_item @sku_identifier = sku_identifier unless sku_identifier == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#marketplace_item ⇒ WalmartItemIdentifier
Schema to identify an item by MarketPlaceId and Walmart Item ID (see ADR-029).
15 16 17 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 15 def marketplace_item @marketplace_item end |
#sku_identifier ⇒ SellerSkuIdentifier
Schema to identify an item by MarketPlaceId, SellerId, and SellerSKU.
19 20 21 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 19 def sku_identifier @sku_identifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_item = WalmartItemIdentifier.from_hash(hash['MarketplaceItem']) if hash['MarketplaceItem'] sku_identifier = SellerSkuIdentifier.from_hash(hash['SKUIdentifier']) if hash['SKUIdentifier'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IdentifierType1.new(marketplace_item: marketplace_item, sku_identifier: sku_identifier, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_item'] = 'MarketplaceItem' @_hash['sku_identifier'] = 'SKUIdentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 30 def self.optionals %w[ sku_identifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_item: #{@marketplace_item.inspect}, sku_identifier:"\ " #{@sku_identifier.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/identifier_type1.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_item: #{@marketplace_item}, sku_identifier: #{@sku_identifier},"\ " additional_properties: #{@additional_properties}>" end |