Class: WalmartApIs::Incentive
- Defined in:
- lib/walmart_ap_is/models/incentive.rb
Overview
Contains details about cost related modifications to the placement cost.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the incentive.
-
#target ⇒ String
Target of the incentive.
-
#type ⇒ String
Type of incentive.
-
#value ⇒ Currency
The type and amount of currency.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(description:, target:, type:, value:, additional_properties: nil) ⇒ Incentive
constructor
A new instance of Incentive.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(description:, target:, type:, value:, additional_properties: nil) ⇒ Incentive
Returns a new instance of Incentive.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 49 def initialize(description:, target:, type:, value:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @description = description @target = target @type = type @value = value @additional_properties = additional_properties end |
Instance Attribute Details
#description ⇒ String
Description of the incentive.
14 15 16 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 14 def description @description end |
#target ⇒ String
Target of the incentive. Possible values: 'Placement Services', 'Fulfillment Fee Discount'.
19 20 21 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 19 def target @target end |
#type ⇒ String
Type of incentive. Possible values: FEE, DISCOUNT.
23 24 25 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 23 def type @type end |
#value ⇒ Currency
The type and amount of currency.
27 28 29 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 27 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. description = hash.key?('description') ? hash['description'] : nil target = hash.key?('target') ? hash['target'] : nil type = hash.key?('type') ? hash['type'] : nil value = Currency.from_hash(hash['value']) if hash['value'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Incentive.new(description: description, target: target, type: type, value: value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['description'] = 'description' @_hash['target'] = 'target' @_hash['type'] = 'type' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} description: #{@description.inspect}, target: #{@target.inspect}, type:"\ " #{@type.inspect}, value: #{@value.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/walmart_ap_is/models/incentive.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} description: #{@description}, target: #{@target}, type: #{@type}, value:"\ " #{@value}, additional_properties: #{@additional_properties}>" end |