Class: WalmartApIs::ItemFeedHeader
- Defined in:
- lib/walmart_ap_is/models/item_feed_header.rb
Overview
ItemFeedHeader Model.
Instance Attribute Summary collapse
-
#locale ⇒ String
TODO: Write general description for this method.
-
#mart ⇒ String
TODO: Write general description for this method.
-
#process_mode ⇒ String
TODO: Write general description for this method.
-
#selling_channel ⇒ String
TODO: Write general description for this method.
-
#subset ⇒ String
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(process_mode:, subset:, mart:, selling_channel:, version:, locale:, additional_properties: nil) ⇒ ItemFeedHeader
constructor
A new instance of ItemFeedHeader.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(process_mode:, subset:, mart:, selling_channel:, version:, locale:, additional_properties: nil) ⇒ ItemFeedHeader
Returns a new instance of ItemFeedHeader.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 58 def initialize(process_mode:, subset:, mart:, selling_channel:, version:, locale:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @process_mode = process_mode @subset = subset @mart = mart @selling_channel = selling_channel @version = version @locale = locale @additional_properties = additional_properties end |
Instance Attribute Details
#locale ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 34 def locale @locale end |
#mart ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 22 def mart @mart end |
#process_mode ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 14 def process_mode @process_mode end |
#selling_channel ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 26 def selling_channel @selling_channel end |
#subset ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 18 def subset @subset end |
#version ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 30 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. process_mode = hash.key?('processMode') ? hash['processMode'] : nil subset = hash.key?('subset') ? hash['subset'] : nil mart = hash.key?('mart') ? hash['mart'] : nil selling_channel = hash.key?('sellingChannel') ? hash['sellingChannel'] : nil version = hash.key?('version') ? hash['version'] : nil locale = hash.key?('locale') ? hash['locale'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemFeedHeader.new(process_mode: process_mode, subset: subset, mart: mart, selling_channel: selling_channel, version: version, locale: locale, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['process_mode'] = 'processMode' @_hash['subset'] = 'subset' @_hash['mart'] = 'mart' @_hash['selling_channel'] = 'sellingChannel' @_hash['version'] = 'version' @_hash['locale'] = 'locale' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 117 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} process_mode: #{@process_mode.inspect}, subset: #{@subset.inspect}, mart:"\ " #{@mart.inspect}, selling_channel: #{@selling_channel.inspect}, version:"\ " #{@version.inspect}, locale: #{@locale.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/walmart_ap_is/models/item_feed_header.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} process_mode: #{@process_mode}, subset: #{@subset}, mart: #{@mart},"\ " selling_channel: #{@selling_channel}, version: #{@version}, locale: #{@locale},"\ " additional_properties: #{@additional_properties}>" end |