Class: WalmartApIs::ItemIdentifier1
- Defined in:
- lib/walmart_ap_is/models/item_identifier1.rb
Overview
Information that identifies an item.
Instance Attribute Summary collapse
-
#item_condition ⇒ ConditionType2
Indicates the condition of the item.
-
#marketplace_id ⇒ String
A marketplace identifier.
-
#seller_sku ⇒ String
The seller stock keeping unit (SKU) of the item.
-
#walmart_item_id ⇒ String
The Walmart Item ID of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id:, item_condition:, walmart_item_id: SKIP, seller_sku: SKIP, additional_properties: nil) ⇒ ItemIdentifier1
constructor
A new instance of ItemIdentifier1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id:, item_condition:, walmart_item_id: SKIP, seller_sku: SKIP, additional_properties: nil) ⇒ ItemIdentifier1
Returns a new instance of ItemIdentifier1.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 52 def initialize(marketplace_id:, item_condition:, walmart_item_id: SKIP, seller_sku: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id @walmart_item_id = walmart_item_id unless walmart_item_id == SKIP @seller_sku = seller_sku unless seller_sku == SKIP @item_condition = item_condition @additional_properties = additional_properties end |
Instance Attribute Details
#item_condition ⇒ ConditionType2
Indicates the condition of the item. Possible values: New, Used, Collectible, Refurbished, Club.
27 28 29 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 27 def item_condition @item_condition end |
#marketplace_id ⇒ String
A marketplace identifier.
14 15 16 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 14 def marketplace_id @marketplace_id end |
#seller_sku ⇒ String
The seller stock keeping unit (SKU) of the item.
22 23 24 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 22 def seller_sku @seller_sku end |
#walmart_item_id ⇒ String
The Walmart Item ID of the item.
18 19 20 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 18 def walmart_item_id @walmart_item_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('MarketplaceId') ? hash['MarketplaceId'] : nil item_condition = hash.key?('ItemCondition') ? hash['ItemCondition'] : nil walmart_item_id = hash.key?('walmartItemId') ? hash['walmartItemId'] : SKIP seller_sku = hash.key?('SellerSKU') ? hash['SellerSKU'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemIdentifier1.new(marketplace_id: marketplace_id, item_condition: item_condition, walmart_item_id: walmart_item_id, seller_sku: seller_sku, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'MarketplaceId' @_hash['walmart_item_id'] = 'walmartItemId' @_hash['seller_sku'] = 'SellerSKU' @_hash['item_condition'] = 'ItemCondition' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 40 def self.optionals %w[ walmart_item_id seller_sku ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, walmart_item_id:"\ " #{@walmart_item_id.inspect}, seller_sku: #{@seller_sku.inspect}, item_condition:"\ " #{@item_condition.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 96 |
# File 'lib/walmart_ap_is/models/item_identifier1.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, walmart_item_id: #{@walmart_item_id},"\ " seller_sku: #{@seller_sku}, item_condition: #{@item_condition}, additional_properties:"\ " #{@additional_properties}>" end |