Class: WalmartApIs::ItemOfferByMarketplace
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ItemOfferByMarketplace
- Defined in:
- lib/walmart_ap_is/models/item_offer_by_marketplace.rb
Overview
ItemOfferByMarketplace Model.
Instance Attribute Summary collapse
-
#marketplace_id ⇒ String
TODO: Write general description for this method.
-
#offer_type ⇒ OfferType
TODO: Write general description for this method.
-
#points ⇒ Points
TODO: Write general description for this method.
-
#price ⇒ Money
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id: SKIP, offer_type: SKIP, price: SKIP, points: SKIP, additional_properties: nil) ⇒ ItemOfferByMarketplace
constructor
A new instance of ItemOfferByMarketplace.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id: SKIP, offer_type: SKIP, price: SKIP, points: SKIP, additional_properties: nil) ⇒ ItemOfferByMarketplace
Returns a new instance of ItemOfferByMarketplace.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 53 def initialize(marketplace_id: SKIP, offer_type: SKIP, price: SKIP, points: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id unless marketplace_id == SKIP @offer_type = offer_type unless offer_type == SKIP @price = price unless price == SKIP @points = points unless points == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#marketplace_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 14 def marketplace_id @marketplace_id end |
#offer_type ⇒ OfferType
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 18 def offer_type @offer_type end |
#points ⇒ Points
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 26 def points @points end |
#price ⇒ Money
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 22 def price @price end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : SKIP offer_type = hash.key?('offerType') ? hash['offerType'] : SKIP price = Money.from_hash(hash['price']) if hash['price'] points = Points.from_hash(hash['points']) if hash['points'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemOfferByMarketplace.new(marketplace_id: marketplace_id, offer_type: offer_type, price: price, points: points, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'marketplaceId' @_hash['offer_type'] = 'offerType' @_hash['price'] = 'price' @_hash['points'] = 'points' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 39 def self.optionals %w[ marketplace_id offer_type price points ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, offer_type:"\ " #{@offer_type.inspect}, price: #{@price.inspect}, points: #{@points.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/item_offer_by_marketplace.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, offer_type: #{@offer_type}, price:"\ " #{@price}, points: #{@points}, additional_properties: #{@additional_properties}>" end |