Class: WalmartApIs::ListDeliveryWindowOptionsResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::ListDeliveryWindowOptionsResponse
- Defined in:
- lib/walmart_ap_is/models/list_delivery_window_options_response.rb
Overview
The listDeliveryWindowOptions response.
Instance Attribute Summary collapse
-
#delivery_window_options ⇒ Array[DeliveryWindowOption]
Delivery window options generated for the shipment.
-
#pagination ⇒ Pagination4
Contains tokens to fetch from a certain page.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(delivery_window_options:, pagination: SKIP, additional_properties: nil) ⇒ ListDeliveryWindowOptionsResponse
constructor
A new instance of ListDeliveryWindowOptionsResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(delivery_window_options:, pagination: SKIP, additional_properties: nil) ⇒ ListDeliveryWindowOptionsResponse
Returns a new instance of ListDeliveryWindowOptionsResponse.
40 41 42 43 44 45 46 47 48 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 40 def initialize(delivery_window_options:, pagination: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @delivery_window_options = @pagination = pagination unless pagination == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#delivery_window_options ⇒ Array[DeliveryWindowOption]
Delivery window options generated for the shipment.
14 15 16 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 14 def @delivery_window_options end |
#pagination ⇒ Pagination4
Contains tokens to fetch from a certain page.
18 19 20 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 18 def pagination @pagination end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it = nil unless hash['deliveryWindowOptions'].nil? = [] hash['deliveryWindowOptions'].each do |structure| << (DeliveryWindowOption.from_hash(structure) if structure) end end = nil unless hash.key?('deliveryWindowOptions') pagination = Pagination4.from_hash(hash['pagination']) if hash['pagination'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ListDeliveryWindowOptionsResponse.new(delivery_window_options: , pagination: pagination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['delivery_window_options'] = 'deliveryWindowOptions' @_hash['pagination'] = 'pagination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 29 def self.optionals %w[ pagination ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} delivery_window_options: #{@delivery_window_options.inspect}, pagination:"\ " #{@pagination.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/walmart_ap_is/models/list_delivery_window_options_response.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} delivery_window_options: #{@delivery_window_options}, pagination:"\ " #{@pagination}, additional_properties: #{@additional_properties}>" end |