Class: WalmartApIs::ListingsRestrictionsApi
- Defined in:
- lib/walmart_ap_is/apis/listings_restrictions_api.rb
Overview
ListingsRestrictionsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_listings_restrictions(asin, condition_type, seller_id, marketplace_ids, reason_locale: 'en_US') ⇒ ApiResponse
Returns restrictions on listing an item for a given ASIN and seller.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from WalmartApIs::BaseApi
Instance Method Details
#get_listings_restrictions(asin, condition_type, seller_id, marketplace_ids, reason_locale: 'en_US') ⇒ ApiResponse
Returns restrictions on listing an item for a given ASIN and seller. A successful response does not guarantee the seller can list — check the restrictions array. Walmart Seller API) here type description here restriction reason messages
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/walmart_ap_is/apis/listings_restrictions_api.rb', line 22 def get_listings_restrictions(asin, condition_type, seller_id, marketplace_ids, reason_locale: 'en_US') @api_call .request(new_request_builder(HttpMethodEnum::GET, '/listings/v4/restrictions', Server::DEFAULT1) .query_param(new_parameter(asin, key: 'asin') .is_required(true)) .query_param(new_parameter(condition_type, key: 'conditionType') .is_required(true)) .query_param(new_parameter(seller_id, key: 'sellerId') .is_required(true)) .query_param(new_parameter(marketplace_ids, key: 'marketplaceIds') .is_required(true)) .query_param(new_parameter(reason_locale, key: 'reasonLocale')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('walletAuth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RestrictionList.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', ErrorListErrorException) .local_error('403', 'Forbidden', ErrorListErrorException) .local_error('429', 'Rate limit exceeded', ErrorListErrorException) .local_error('500', 'Internal Server Error', ErrorListErrorException)) .execute end |