Class: WalmartApIs::Location
- Defined in:
- lib/walmart_ap_is/models/location.rb
Overview
Location Model.
Instance Attribute Summary collapse
-
#city ⇒ String
TODO: Write general description for this method.
-
#country_code ⇒ String
TODO: Write general description for this method.
-
#postal_code ⇒ String
TODO: Write general description for this method.
-
#state_or_region ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(city: SKIP, state_or_region: SKIP, country_code: SKIP, postal_code: SKIP, additional_properties: nil) ⇒ Location
constructor
A new instance of Location.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(city: SKIP, state_or_region: SKIP, country_code: SKIP, postal_code: SKIP, additional_properties: nil) ⇒ Location
Returns a new instance of Location.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/walmart_ap_is/models/location.rb', line 53 def initialize(city: SKIP, state_or_region: SKIP, country_code: SKIP, postal_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @city = city unless city == SKIP @state_or_region = state_or_region unless state_or_region == SKIP @country_code = country_code unless country_code == SKIP @postal_code = postal_code unless postal_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/location.rb', line 14 def city @city end |
#country_code ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/location.rb', line 22 def country_code @country_code end |
#postal_code ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/location.rb', line 26 def postal_code @postal_code end |
#state_or_region ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/location.rb', line 18 def state_or_region @state_or_region end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/walmart_ap_is/models/location.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. city = hash.key?('city') ? hash['city'] : SKIP state_or_region = hash.key?('stateOrRegion') ? hash['stateOrRegion'] : SKIP country_code = hash.key?('countryCode') ? hash['countryCode'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Location.new(city: city, state_or_region: state_or_region, country_code: country_code, postal_code: postal_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/location.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['city'] = 'city' @_hash['state_or_region'] = 'stateOrRegion' @_hash['country_code'] = 'countryCode' @_hash['postal_code'] = 'postalCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/walmart_ap_is/models/location.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/location.rb', line 39 def self.optionals %w[ city state_or_region country_code postal_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/walmart_ap_is/models/location.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} city: #{@city.inspect}, state_or_region: #{@state_or_region.inspect},"\ " country_code: #{@country_code.inspect}, postal_code: #{@postal_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 97 |
# File 'lib/walmart_ap_is/models/location.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} city: #{@city}, state_or_region: #{@state_or_region}, country_code:"\ " #{@country_code}, postal_code: #{@postal_code}, additional_properties:"\ " #{@additional_properties}>" end |