Class: WalmartApIs::MpItemFeedHeader
- Defined in:
- lib/walmart_ap_is/models/mp_item_feed_header.rb
Overview
MpItemFeedHeader Model.
Instance Attribute Summary collapse
-
#business_unit ⇒ String
TODO: Write general description for this method.
-
#locale ⇒ String
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(business_unit:, version:, locale:, additional_properties: nil) ⇒ MpItemFeedHeader
constructor
A new instance of MpItemFeedHeader.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(business_unit:, version:, locale:, additional_properties: nil) ⇒ MpItemFeedHeader
Returns a new instance of MpItemFeedHeader.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 43 def initialize(business_unit:, version:, locale:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @business_unit = business_unit @version = version @locale = locale @additional_properties = additional_properties end |
Instance Attribute Details
#business_unit ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 14 def business_unit @business_unit end |
#locale ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 22 def locale @locale end |
#version ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 18 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. business_unit = hash.key?('businessUnit') ? hash['businessUnit'] : nil version = hash.key?('version') ? hash['version'] : nil locale = hash.key?('locale') ? hash['locale'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MpItemFeedHeader.new(business_unit: business_unit, version: version, locale: locale, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['business_unit'] = 'businessUnit' @_hash['version'] = 'version' @_hash['locale'] = 'locale' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} business_unit: #{@business_unit.inspect}, version: #{@version.inspect},"\ " locale: #{@locale.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/mp_item_feed_header.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} business_unit: #{@business_unit}, version: #{@version}, locale: #{@locale},"\ " additional_properties: #{@additional_properties}>" end |