Class: WalmartApIs::MultiPackageShipResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::MultiPackageShipResponse
- Defined in:
- lib/walmart_ap_is/models/multi_package_ship_response.rb
Overview
MultiPackageShipResponse Model.
Instance Attribute Summary collapse
-
#packages_accepted ⇒ Integer
Number of
packages[]entries successfully forwarded to FMS — echoed back so callers can sanity-check against what they sent. -
#purchase_order_id ⇒ String
TODO: Write general description for this method.
-
#shipped_at ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(purchase_order_id: SKIP, shipped_at: SKIP, packages_accepted: SKIP, additional_properties: nil) ⇒ MultiPackageShipResponse
constructor
A new instance of MultiPackageShipResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_shipped_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(purchase_order_id: SKIP, shipped_at: SKIP, packages_accepted: SKIP, additional_properties: nil) ⇒ MultiPackageShipResponse
Returns a new instance of MultiPackageShipResponse.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 50 def initialize(purchase_order_id: SKIP, shipped_at: SKIP, packages_accepted: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @purchase_order_id = purchase_order_id unless purchase_order_id == SKIP @shipped_at = shipped_at unless shipped_at == SKIP @packages_accepted = packages_accepted unless packages_accepted == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#packages_accepted ⇒ Integer
Number of packages[] entries successfully forwarded to FMS
— echoed back so callers can sanity-check against what they
sent.
25 26 27 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 25 def packages_accepted @packages_accepted end |
#purchase_order_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 15 def purchase_order_id @purchase_order_id end |
#shipped_at ⇒ DateTime
TODO: Write general description for this method
19 20 21 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 19 def shipped_at @shipped_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. purchase_order_id = hash.key?('purchaseOrderId') ? hash['purchaseOrderId'] : SKIP shipped_at = if hash.key?('shippedAt') (DateTimeHelper.from_rfc3339(hash['shippedAt']) if hash['shippedAt']) else SKIP end packages_accepted = hash.key?('packagesAccepted') ? hash['packagesAccepted'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MultiPackageShipResponse.new(purchase_order_id: purchase_order_id, shipped_at: shipped_at, packages_accepted: packages_accepted, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['purchase_order_id'] = 'purchaseOrderId' @_hash['shipped_at'] = 'shippedAt' @_hash['packages_accepted'] = 'packagesAccepted' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 37 def self.optionals %w[ purchase_order_id shipped_at packages_accepted ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} purchase_order_id: #{@purchase_order_id.inspect}, shipped_at:"\ " #{@shipped_at.inspect}, packages_accepted: #{@packages_accepted.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_shipped_at ⇒ Object
90 91 92 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 90 def to_custom_shipped_at DateTimeHelper.to_rfc3339(shipped_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/walmart_ap_is/models/multi_package_ship_response.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} purchase_order_id: #{@purchase_order_id}, shipped_at: #{@shipped_at},"\ " packages_accepted: #{@packages_accepted}, additional_properties:"\ " #{@additional_properties}>" end |