Class: WalmartApIs::OfferIdentifier
- Defined in:
- lib/walmart_ap_is/models/offer_identifier.rb
Overview
Identifies an offer.
Instance Attribute Summary collapse
-
#fulfillment_type ⇒ FulfillmentType1
The fulfillment type for the offer.
-
#marketplace_id ⇒ String
A marketplace identifier.
-
#seller_id ⇒ String
The seller identifier.
-
#sku ⇒ String
The seller stock keeping unit (SKU) of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id: SKIP, seller_id: SKIP, sku: SKIP, fulfillment_type: SKIP, additional_properties: nil) ⇒ OfferIdentifier
constructor
A new instance of OfferIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id: SKIP, seller_id: SKIP, sku: SKIP, fulfillment_type: SKIP, additional_properties: nil) ⇒ OfferIdentifier
Returns a new instance of OfferIdentifier.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 53 def initialize(marketplace_id: SKIP, seller_id: SKIP, sku: SKIP, fulfillment_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id unless marketplace_id == SKIP @seller_id = seller_id unless seller_id == SKIP @sku = sku unless sku == SKIP @fulfillment_type = fulfillment_type unless fulfillment_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fulfillment_type ⇒ FulfillmentType1
The fulfillment type for the offer. Possible values: WFS, SELLER.
26 27 28 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 26 def fulfillment_type @fulfillment_type end |
#marketplace_id ⇒ String
A marketplace identifier.
14 15 16 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 14 def marketplace_id @marketplace_id end |
#seller_id ⇒ String
The seller identifier.
18 19 20 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 18 def seller_id @seller_id end |
#sku ⇒ String
The seller stock keeping unit (SKU) of the item.
22 23 24 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 22 def sku @sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : SKIP seller_id = hash.key?('sellerId') ? hash['sellerId'] : SKIP sku = hash.key?('sku') ? hash['sku'] : SKIP fulfillment_type = hash.key?('fulfillmentType') ? hash['fulfillmentType'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OfferIdentifier.new(marketplace_id: marketplace_id, seller_id: seller_id, sku: sku, fulfillment_type: fulfillment_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'marketplaceId' @_hash['seller_id'] = 'sellerId' @_hash['sku'] = 'sku' @_hash['fulfillment_type'] = 'fulfillmentType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 39 def self.optionals %w[ marketplace_id seller_id sku fulfillment_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, seller_id:"\ " #{@seller_id.inspect}, sku: #{@sku.inspect}, fulfillment_type:"\ " #{@fulfillment_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/walmart_ap_is/models/offer_identifier.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, seller_id: #{@seller_id}, sku: #{@sku},"\ " fulfillment_type: #{@fulfillment_type}, additional_properties: #{@additional_properties}>" end |