Class: WalmartApIs::PackageDocument
- Defined in:
- lib/walmart_ap_is/models/package_document.rb
Overview
PackageDocument Model.
Instance Attribute Summary collapse
-
#contents ⇒ String
Base64-encoded document bytes.
-
#format ⇒ Format1
TODO: Write general description for this method.
-
#type ⇒ Type1
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type:, format:, contents:, additional_properties: nil) ⇒ PackageDocument
constructor
A new instance of PackageDocument.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type:, format:, contents:, additional_properties: nil) ⇒ PackageDocument
Returns a new instance of PackageDocument.
43 44 45 46 47 48 49 50 51 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 43 def initialize(type:, format:, contents:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type @format = format @contents = contents @additional_properties = additional_properties end |
Instance Attribute Details
#contents ⇒ String
Base64-encoded document bytes.
22 23 24 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 22 def contents @contents end |
#format ⇒ Format1
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 18 def format @format end |
#type ⇒ Type1
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 14 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : nil format = hash.key?('format') ? hash['format'] : nil contents = hash.key?('contents') ? hash['contents'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PackageDocument.new(type: type, format: format, contents: contents, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['format'] = 'format' @_hash['contents'] = 'contents' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, format: #{@format.inspect}, contents:"\ " #{@contents.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/walmart_ap_is/models/package_document.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, format: #{@format}, contents: #{@contents},"\ " additional_properties: #{@additional_properties}>" end |