Class: WalmartApIs::PackageDocumentDetail
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::PackageDocumentDetail
- Defined in:
- lib/walmart_ap_is/models/package_document_detail.rb
Overview
PackageDocumentDetail Model.
Instance Attribute Summary collapse
-
#package_client_reference_id ⇒ String
TODO: Write general description for this method.
-
#package_documents ⇒ Array[PackageDocument]
TODO: Write general description for this method.
-
#tracking_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(package_client_reference_id:, package_documents:, tracking_id: SKIP, additional_properties: nil) ⇒ PackageDocumentDetail
constructor
A new instance of PackageDocumentDetail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_client_reference_id:, package_documents:, tracking_id: SKIP, additional_properties: nil) ⇒ PackageDocumentDetail
Returns a new instance of PackageDocumentDetail.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 45 def initialize(package_client_reference_id:, package_documents:, tracking_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @package_client_reference_id = package_client_reference_id @package_documents = package_documents @tracking_id = tracking_id unless tracking_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#package_client_reference_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 14 def package_client_reference_id @package_client_reference_id end |
#package_documents ⇒ Array[PackageDocument]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 18 def package_documents @package_documents end |
#tracking_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 22 def tracking_id @tracking_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. package_client_reference_id = hash.key?('packageClientReferenceId') ? hash['packageClientReferenceId'] : nil # Parameter is an array, so we need to iterate through it package_documents = nil unless hash['packageDocuments'].nil? package_documents = [] hash['packageDocuments'].each do |structure| package_documents << (PackageDocument.from_hash(structure) if structure) end end package_documents = nil unless hash.key?('packageDocuments') tracking_id = hash.key?('trackingId') ? hash['trackingId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PackageDocumentDetail.new(package_client_reference_id: package_client_reference_id, package_documents: package_documents, tracking_id: tracking_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['package_client_reference_id'] = 'packageClientReferenceId' @_hash['package_documents'] = 'packageDocuments' @_hash['tracking_id'] = 'trackingId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 34 def self.optionals %w[ tracking_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_client_reference_id: #{@package_client_reference_id.inspect},"\ " package_documents: #{@package_documents.inspect}, tracking_id: #{@tracking_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/package_document_detail.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_client_reference_id: #{@package_client_reference_id},"\ " package_documents: #{@package_documents}, tracking_id: #{@tracking_id},"\ " additional_properties: #{@additional_properties}>" end |