Class: WalmartApIs::Payload12
- Defined in:
- lib/walmart_ap_is/models/payload12.rb
Overview
Payload12 Model.
Instance Attribute Summary collapse
-
#package_document_details ⇒ Array[PackageDocumentDetail]
TODO: Write general description for this method.
-
#promise ⇒ Promise
TODO: Write general description for this method.
-
#shipment_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shipment_id: SKIP, package_document_details: SKIP, promise: SKIP, additional_properties: nil) ⇒ Payload12
constructor
A new instance of Payload12.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shipment_id: SKIP, package_document_details: SKIP, promise: SKIP, additional_properties: nil) ⇒ Payload12
Returns a new instance of Payload12.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 47 def initialize(shipment_id: SKIP, package_document_details: SKIP, promise: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @shipment_id = shipment_id unless shipment_id == SKIP @package_document_details = package_document_details unless package_document_details == SKIP @promise = promise unless promise == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#package_document_details ⇒ Array[PackageDocumentDetail]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 18 def package_document_details @package_document_details end |
#promise ⇒ Promise
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 22 def promise @promise end |
#shipment_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 14 def shipment_id @shipment_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. shipment_id = hash.key?('shipmentId') ? hash['shipmentId'] : SKIP # Parameter is an array, so we need to iterate through it package_document_details = nil unless hash['packageDocumentDetails'].nil? package_document_details = [] hash['packageDocumentDetails'].each do |structure| package_document_details << (PackageDocumentDetail.from_hash(structure) if structure) end end package_document_details = SKIP unless hash.key?('packageDocumentDetails') promise = Promise.from_hash(hash['promise']) if hash['promise'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Payload12.new(shipment_id: shipment_id, package_document_details: package_document_details, promise: promise, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['shipment_id'] = 'shipmentId' @_hash['package_document_details'] = 'packageDocumentDetails' @_hash['promise'] = 'promise' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 34 def self.optionals %w[ shipment_id package_document_details promise ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} shipment_id: #{@shipment_id.inspect}, package_document_details:"\ " #{@package_document_details.inspect}, promise: #{@promise.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 96 |
# File 'lib/walmart_ap_is/models/payload12.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} shipment_id: #{@shipment_id}, package_document_details:"\ " #{@package_document_details}, promise: #{@promise}, additional_properties:"\ " #{@additional_properties}>" end |