Class: WalmartApIs::Price
- Defined in:
- lib/walmart_ap_is/models/price.rb
Overview
Schema for price info in getPricing response.
Instance Attribute Summary collapse
-
#product ⇒ Product
An item.
-
#seller_sku ⇒ String
The seller stock keeping unit (SKU) of the item.
-
#status ⇒ String
The status of the operation.
-
#walmart_item_id ⇒ String
The Walmart Item ID of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status:, seller_sku: SKIP, walmart_item_id: SKIP, product: SKIP, additional_properties: nil) ⇒ Price
constructor
A new instance of Price.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status:, seller_sku: SKIP, walmart_item_id: SKIP, product: SKIP, additional_properties: nil) ⇒ Price
Returns a new instance of Price.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/walmart_ap_is/models/price.rb', line 52 def initialize(status:, seller_sku: SKIP, walmart_item_id: SKIP, product: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status @seller_sku = seller_sku unless seller_sku == SKIP @walmart_item_id = walmart_item_id unless walmart_item_id == SKIP @product = product unless product == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#product ⇒ Product
An item.
26 27 28 |
# File 'lib/walmart_ap_is/models/price.rb', line 26 def product @product end |
#seller_sku ⇒ String
The seller stock keeping unit (SKU) of the item.
18 19 20 |
# File 'lib/walmart_ap_is/models/price.rb', line 18 def seller_sku @seller_sku end |
#status ⇒ String
The status of the operation.
14 15 16 |
# File 'lib/walmart_ap_is/models/price.rb', line 14 def status @status end |
#walmart_item_id ⇒ String
The Walmart Item ID of the item.
22 23 24 |
# File 'lib/walmart_ap_is/models/price.rb', line 22 def walmart_item_id @walmart_item_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/price.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil seller_sku = hash.key?('SellerSKU') ? hash['SellerSKU'] : SKIP walmart_item_id = hash.key?('walmartItemId') ? hash['walmartItemId'] : SKIP product = Product.from_hash(hash['Product']) if hash['Product'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Price.new(status: status, seller_sku: seller_sku, walmart_item_id: walmart_item_id, product: product, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/price.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['seller_sku'] = 'SellerSKU' @_hash['walmart_item_id'] = 'walmartItemId' @_hash['product'] = 'Product' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/walmart_ap_is/models/price.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 |
# File 'lib/walmart_ap_is/models/price.rb', line 39 def self.optionals %w[ seller_sku walmart_item_id product ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/walmart_ap_is/models/price.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, seller_sku: #{@seller_sku.inspect},"\ " walmart_item_id: #{@walmart_item_id.inspect}, product: #{@product.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 96 |
# File 'lib/walmart_ap_is/models/price.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, seller_sku: #{@seller_sku}, walmart_item_id:"\ " #{@walmart_item_id}, product: #{@product}, additional_properties:"\ " #{@additional_properties}>" end |