Class: WalmartApIs::Refinements
- Defined in:
- lib/walmart_ap_is/models/refinements.rb
Overview
Refinements Model.
Instance Attribute Summary collapse
-
#classification_refinements ⇒ Array[ClassificationRefinement]
TODO: Write general description for this method.
-
#departments ⇒ Array[Department]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(departments: SKIP, classification_refinements: SKIP, additional_properties: nil) ⇒ Refinements
constructor
A new instance of Refinements.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(departments: SKIP, classification_refinements: SKIP, additional_properties: nil) ⇒ Refinements
Returns a new instance of Refinements.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 41 def initialize(departments: SKIP, classification_refinements: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @departments = departments unless departments == SKIP unless classification_refinements == SKIP @classification_refinements = classification_refinements end @additional_properties = additional_properties end |
Instance Attribute Details
#classification_refinements ⇒ Array[ClassificationRefinement]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 18 def classification_refinements @classification_refinements end |
#departments ⇒ Array[Department]
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 14 def departments @departments end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it departments = nil unless hash['departments'].nil? departments = [] hash['departments'].each do |structure| departments << (Department.from_hash(structure) if structure) end end departments = SKIP unless hash.key?('departments') # Parameter is an array, so we need to iterate through it classification_refinements = nil unless hash['classificationRefinements'].nil? classification_refinements = [] hash['classificationRefinements'].each do |structure| classification_refinements << (ClassificationRefinement.from_hash(structure) if structure) end end classification_refinements = SKIP unless hash.key?('classificationRefinements') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Refinements.new(departments: departments, classification_refinements: classification_refinements, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['departments'] = 'departments' @_hash['classification_refinements'] = 'classificationRefinements' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 29 def self.optionals %w[ departments classification_refinements ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} departments: #{@departments.inspect}, classification_refinements:"\ " #{@classification_refinements.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/walmart_ap_is/models/refinements.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} departments: #{@departments}, classification_refinements:"\ " #{@classification_refinements}, additional_properties: #{@additional_properties}>" end |