Class: WalmartApIs::Region
- Defined in:
- lib/walmart_ap_is/models/region.rb
Overview
Representation of a location used within the inbounding experience.
Instance Attribute Summary collapse
-
#country_code ⇒ String
ISO 3166 standard alpha-2 country code.
-
#state ⇒ String
State.
-
#warehouse_id ⇒ String
An identifier for a Ship Node.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(country_code: SKIP, state: SKIP, warehouse_id: SKIP, additional_properties: nil) ⇒ Region
constructor
A new instance of Region.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country_code: SKIP, state: SKIP, warehouse_id: SKIP, additional_properties: nil) ⇒ Region
Returns a new instance of Region.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/region.rb', line 47 def initialize(country_code: SKIP, state: SKIP, warehouse_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @country_code = country_code unless country_code == SKIP @state = state unless state == SKIP @warehouse_id = warehouse_id unless warehouse_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#country_code ⇒ String
ISO 3166 standard alpha-2 country code.
14 15 16 |
# File 'lib/walmart_ap_is/models/region.rb', line 14 def country_code @country_code end |
#state ⇒ String
State.
18 19 20 |
# File 'lib/walmart_ap_is/models/region.rb', line 18 def state @state end |
#warehouse_id ⇒ String
An identifier for a Ship Node.
22 23 24 |
# File 'lib/walmart_ap_is/models/region.rb', line 22 def warehouse_id @warehouse_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/walmart_ap_is/models/region.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country_code = hash.key?('countryCode') ? hash['countryCode'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP warehouse_id = hash.key?('warehouseId') ? hash['warehouseId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Region.new(country_code: country_code, state: state, warehouse_id: warehouse_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/region.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['country_code'] = 'countryCode' @_hash['state'] = 'state' @_hash['warehouse_id'] = 'warehouseId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/region.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/region.rb', line 34 def self.optionals %w[ country_code state warehouse_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/region.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code.inspect}, state: #{@state.inspect},"\ " warehouse_id: #{@warehouse_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/walmart_ap_is/models/region.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code}, state: #{@state}, warehouse_id:"\ " #{@warehouse_id}, additional_properties: #{@additional_properties}>" end |