Class: WalmartApIs::SellersApi
- Defined in:
- lib/walmart_ap_is/apis/sellers_api.rb
Overview
SellersApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_marketplace_participations ⇒ ApiResponse
Returns the list of marketplaces the authenticated seller participates in (e.g. Walmart US, Walmart Canada, Walmart Mexico).
-
#get_seller_account ⇒ ApiResponse
Returns the authenticated seller's account information including business name, email, account status, and seller type.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from WalmartApIs::BaseApi
Instance Method Details
#get_marketplace_participations ⇒ ApiResponse
Returns the list of marketplaces the authenticated seller participates in (e.g. Walmart US, Walmart Canada, Walmart Mexico).
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/apis/sellers_api.rb', line 12 def get_marketplace_participations @api_call .request(new_request_builder(HttpMethodEnum::GET, '/sellers/v4/marketplaceParticipations', Server::DEFAULT1) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('walletAuth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(GetMarketplaceParticipationsResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', ErrorListErrorException) .local_error('403', 'Forbidden', ErrorListErrorException) .local_error('429', 'Rate limit exceeded', ErrorListErrorException) .local_error('500', 'Internal Server Error', ErrorListErrorException)) .execute end |
#get_seller_account ⇒ ApiResponse
Returns the authenticated seller's account information including business name, email, account status, and seller type.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/walmart_ap_is/apis/sellers_api.rb', line 41 def get_seller_account @api_call .request(new_request_builder(HttpMethodEnum::GET, '/sellers/v4/account', Server::DEFAULT1) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('walletAuth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(SellerAccount.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', ErrorListErrorException) .local_error('403', 'Forbidden', ErrorListErrorException) .local_error('429', 'Rate limit exceeded', ErrorListErrorException) .local_error('500', 'Internal Server Error', ErrorListErrorException)) .execute end |