Class: WalmartApIs::SettlementPeriod
- Defined in:
- lib/walmart_ap_is/models/settlement_period.rb
Overview
SettlementPeriod Model.
Instance Attribute Summary collapse
-
#end_date ⇒ DateTime
TODO: Write general description for this method.
-
#period_id ⇒ String
TODO: Write general description for this method.
-
#start_date ⇒ DateTime
TODO: Write general description for this method.
-
#status ⇒ Status2
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(period_id: SKIP, start_date: SKIP, end_date: SKIP, status: SKIP, additional_properties: nil) ⇒ SettlementPeriod
constructor
A new instance of SettlementPeriod.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_end_date ⇒ Object
- #to_custom_start_date ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(period_id: SKIP, start_date: SKIP, end_date: SKIP, status: SKIP, additional_properties: nil) ⇒ SettlementPeriod
Returns a new instance of SettlementPeriod.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 54 def initialize(period_id: SKIP, start_date: SKIP, end_date: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @period_id = period_id unless period_id == SKIP @start_date = start_date unless start_date == SKIP @end_date = end_date unless end_date == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ DateTime
TODO: Write general description for this method
23 24 25 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 23 def end_date @end_date end |
#period_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 15 def period_id @period_id end |
#start_date ⇒ DateTime
TODO: Write general description for this method
19 20 21 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 19 def start_date @start_date end |
#status ⇒ Status2
TODO: Write general description for this method
27 28 29 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 27 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. period_id = hash.key?('periodId') ? hash['periodId'] : SKIP start_date = if hash.key?('startDate') (DateTimeHelper.from_rfc3339(hash['startDate']) if hash['startDate']) else SKIP end end_date = if hash.key?('endDate') (DateTimeHelper.from_rfc3339(hash['endDate']) if hash['endDate']) else SKIP end status = hash.key?('status') ? hash['status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SettlementPeriod.new(period_id: period_id, start_date: start_date, end_date: end_date, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['period_id'] = 'periodId' @_hash['start_date'] = 'startDate' @_hash['end_date'] = 'endDate' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 46 47 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 40 def self.optionals %w[ period_id start_date end_date status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} period_id: #{@period_id.inspect}, start_date: #{@start_date.inspect},"\ " end_date: #{@end_date.inspect}, status: #{@status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_end_date ⇒ Object
103 104 105 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 103 def to_custom_end_date DateTimeHelper.to_rfc3339(end_date) end |
#to_custom_start_date ⇒ Object
99 100 101 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 99 def to_custom_start_date DateTimeHelper.to_rfc3339(start_date) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/walmart_ap_is/models/settlement_period.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} period_id: #{@period_id}, start_date: #{@start_date}, end_date:"\ " #{@end_date}, status: #{@status}, additional_properties: #{@additional_properties}>" end |