Class: WalmartApIs::Strategy
- Defined in:
- lib/walmart_ap_is/models/strategy.rb
Overview
Strategy Model.
Instance Attribute Summary collapse
-
#adjustment_type ⇒ String
TODO: Write general description for this method.
-
#adjustment_value ⇒ Float
TODO: Write general description for this method.
-
#strategy_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(strategy_type:, adjustment_type:, adjustment_value:, additional_properties: nil) ⇒ Strategy
constructor
A new instance of Strategy.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(strategy_type:, adjustment_type:, adjustment_value:, additional_properties: nil) ⇒ Strategy
Returns a new instance of Strategy.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 43 def initialize(strategy_type:, adjustment_type:, adjustment_value:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @strategy_type = strategy_type @adjustment_type = adjustment_type @adjustment_value = adjustment_value @additional_properties = additional_properties end |
Instance Attribute Details
#adjustment_type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 18 def adjustment_type @adjustment_type end |
#adjustment_value ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 22 def adjustment_value @adjustment_value end |
#strategy_type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 14 def strategy_type @strategy_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. strategy_type = hash.key?('strategyType') ? hash['strategyType'] : nil adjustment_type = hash.key?('adjustmentType') ? hash['adjustmentType'] : nil adjustment_value = hash.key?('adjustmentValue') ? hash['adjustmentValue'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Strategy.new(strategy_type: strategy_type, adjustment_type: adjustment_type, adjustment_value: adjustment_value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['strategy_type'] = 'strategyType' @_hash['adjustment_type'] = 'adjustmentType' @_hash['adjustment_value'] = 'adjustmentValue' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} strategy_type: #{@strategy_type.inspect}, adjustment_type:"\ " #{@adjustment_type.inspect}, adjustment_value: #{@adjustment_value.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/strategy.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} strategy_type: #{@strategy_type}, adjustment_type: #{@adjustment_type},"\ " adjustment_value: #{@adjustment_value}, additional_properties: #{@additional_properties}>" end |