Class: WalmartApIs::SuccessfulOperation2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::SuccessfulOperation2
- Defined in:
- lib/walmart_ap_is/models/successful_operation2.rb
Overview
SuccessfulOperation2 Model.
Instance Attribute Summary collapse
-
#expire_at ⇒ String
TODO: Write general description for this method.
-
#is_valid ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#issued_at ⇒ String
TODO: Write general description for this method.
-
#scopes ⇒ Scopes
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(expire_at:, issued_at:, is_valid:, scopes:, additional_properties: nil) ⇒ SuccessfulOperation2
constructor
A new instance of SuccessfulOperation2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(expire_at:, issued_at:, is_valid:, scopes:, additional_properties: nil) ⇒ SuccessfulOperation2
Returns a new instance of SuccessfulOperation2.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 48 def initialize(expire_at:, issued_at:, is_valid:, scopes:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @expire_at = expire_at @issued_at = issued_at @is_valid = is_valid @scopes = scopes @additional_properties = additional_properties end |
Instance Attribute Details
#expire_at ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 14 def expire_at @expire_at end |
#is_valid ⇒ TrueClass | FalseClass
TODO: Write general description for this method
22 23 24 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 22 def is_valid @is_valid end |
#issued_at ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 18 def issued_at @issued_at end |
#scopes ⇒ Scopes
TODO: Write general description for this method
26 27 28 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 26 def scopes @scopes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. expire_at = hash.key?('expire_at') ? hash['expire_at'] : nil issued_at = hash.key?('issued_at') ? hash['issued_at'] : nil is_valid = hash.key?('is_valid') ? hash['is_valid'] : nil scopes = Scopes.from_hash(hash['scopes']) if hash['scopes'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SuccessfulOperation2.new(expire_at: expire_at, issued_at: issued_at, is_valid: is_valid, scopes: scopes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['expire_at'] = 'expire_at' @_hash['issued_at'] = 'issued_at' @_hash['is_valid'] = 'is_valid' @_hash['scopes'] = 'scopes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} expire_at: #{@expire_at.inspect}, issued_at: #{@issued_at.inspect},"\ " is_valid: #{@is_valid.inspect}, scopes: #{@scopes.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/walmart_ap_is/models/successful_operation2.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} expire_at: #{@expire_at}, issued_at: #{@issued_at}, is_valid: #{@is_valid},"\ " scopes: #{@scopes}, additional_properties: #{@additional_properties}>" end |