Class: WalmartApIs::SuccessfulOperation6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::SuccessfulOperation6
- Defined in:
- lib/walmart_ap_is/models/successful_operation6.rb
Overview
SuccessfulOperation6 Model.
Instance Attribute Summary collapse
-
#page_context ⇒ PageContext
TODO: Write general description for this method.
-
#pricing_insights_response_list ⇒ Array[PricingInsightsResponseList]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(page_context:, pricing_insights_response_list:, additional_properties: nil) ⇒ SuccessfulOperation6
constructor
A new instance of SuccessfulOperation6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(page_context:, pricing_insights_response_list:, additional_properties: nil) ⇒ SuccessfulOperation6
Returns a new instance of SuccessfulOperation6.
38 39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 38 def initialize(page_context:, pricing_insights_response_list:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @page_context = page_context @pricing_insights_response_list = pricing_insights_response_list @additional_properties = additional_properties end |
Instance Attribute Details
#page_context ⇒ PageContext
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 14 def page_context @page_context end |
#pricing_insights_response_list ⇒ Array[PricingInsightsResponseList]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 18 def pricing_insights_response_list @pricing_insights_response_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. page_context = PageContext.from_hash(hash['pageContext']) if hash['pageContext'] # Parameter is an array, so we need to iterate through it pricing_insights_response_list = nil unless hash['pricingInsightsResponseList'].nil? pricing_insights_response_list = [] hash['pricingInsightsResponseList'].each do |structure| pricing_insights_response_list << (PricingInsightsResponseList.from_hash(structure) if structure) end end pricing_insights_response_list = nil unless hash.key?('pricingInsightsResponseList') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SuccessfulOperation6.new(page_context: page_context, pricing_insights_response_list: pricing_insights_response_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['page_context'] = 'pageContext' @_hash['pricing_insights_response_list'] = 'pricingInsightsResponseList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} page_context: #{@page_context.inspect}, pricing_insights_response_list:"\ " #{@pricing_insights_response_list.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/successful_operation6.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} page_context: #{@page_context}, pricing_insights_response_list:"\ " #{@pricing_insights_response_list}, additional_properties: #{@additional_properties}>" end |