Class: WalmartApIs::TaxDetails
- Defined in:
- lib/walmart_ap_is/models/tax_details.rb
Overview
Information used to determine the tax compliance.
Instance Attribute Summary collapse
-
#declared_value ⇒ Currency
The type and amount of currency.
-
#hsn_code ⇒ String
Harmonized System of Nomenclature code.
-
#tax_rates ⇒ Array[TaxRate]
List of tax rates.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(declared_value: SKIP, hsn_code: SKIP, tax_rates: SKIP, additional_properties: nil) ⇒ TaxDetails
constructor
A new instance of TaxDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(declared_value: SKIP, hsn_code: SKIP, tax_rates: SKIP, additional_properties: nil) ⇒ TaxDetails
Returns a new instance of TaxDetails.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 47 def initialize(declared_value: SKIP, hsn_code: SKIP, tax_rates: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @declared_value = declared_value unless declared_value == SKIP @hsn_code = hsn_code unless hsn_code == SKIP @tax_rates = tax_rates unless tax_rates == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#declared_value ⇒ Currency
The type and amount of currency.
14 15 16 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 14 def declared_value @declared_value end |
#hsn_code ⇒ String
Harmonized System of Nomenclature code.
18 19 20 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 18 def hsn_code @hsn_code end |
#tax_rates ⇒ Array[TaxRate]
List of tax rates.
22 23 24 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 22 def tax_rates @tax_rates end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. declared_value = Currency.from_hash(hash['declaredValue']) if hash['declaredValue'] hsn_code = hash.key?('hsnCode') ? hash['hsnCode'] : SKIP # Parameter is an array, so we need to iterate through it tax_rates = nil unless hash['taxRates'].nil? tax_rates = [] hash['taxRates'].each do |structure| tax_rates << (TaxRate.from_hash(structure) if structure) end end tax_rates = SKIP unless hash.key?('taxRates') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxDetails.new(declared_value: declared_value, hsn_code: hsn_code, tax_rates: tax_rates, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['declared_value'] = 'declaredValue' @_hash['hsn_code'] = 'hsnCode' @_hash['tax_rates'] = 'taxRates' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 34 def self.optionals %w[ declared_value hsn_code tax_rates ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} declared_value: #{@declared_value.inspect}, hsn_code: #{@hsn_code.inspect},"\ " tax_rates: #{@tax_rates.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/tax_details.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} declared_value: #{@declared_value}, hsn_code: #{@hsn_code}, tax_rates:"\ " #{@tax_rates}, additional_properties: #{@additional_properties}>" end |