Class: WalmartApIs::UpdateInventoryResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::UpdateInventoryResponse
- Defined in:
- lib/walmart_ap_is/models/update_inventory_response.rb
Overview
UpdateInventoryResponse Model.
Instance Attribute Summary collapse
-
#quantity ⇒ Quantity
TODO: Write general description for this method.
-
#seller_sku ⇒ String
TODO: Write general description for this method.
-
#updated_at ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(seller_sku: SKIP, quantity: SKIP, updated_at: SKIP, additional_properties: nil) ⇒ UpdateInventoryResponse
constructor
A new instance of UpdateInventoryResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(seller_sku: SKIP, quantity: SKIP, updated_at: SKIP, additional_properties: nil) ⇒ UpdateInventoryResponse
Returns a new instance of UpdateInventoryResponse.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 48 def initialize(seller_sku: SKIP, quantity: SKIP, updated_at: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @seller_sku = seller_sku unless seller_sku == SKIP @quantity = quantity unless quantity == SKIP @updated_at = updated_at unless updated_at == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#quantity ⇒ Quantity
TODO: Write general description for this method
19 20 21 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 19 def quantity @quantity end |
#seller_sku ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 15 def seller_sku @seller_sku end |
#updated_at ⇒ DateTime
TODO: Write general description for this method
23 24 25 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 23 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. seller_sku = hash.key?('sellerSku') ? hash['sellerSku'] : SKIP quantity = Quantity.from_hash(hash['quantity']) if hash['quantity'] updated_at = if hash.key?('updatedAt') (DateTimeHelper.from_rfc3339(hash['updatedAt']) if hash['updatedAt']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateInventoryResponse.new(seller_sku: seller_sku, quantity: quantity, updated_at: updated_at, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['seller_sku'] = 'sellerSku' @_hash['quantity'] = 'quantity' @_hash['updated_at'] = 'updatedAt' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 35 def self.optionals %w[ seller_sku quantity updated_at ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} seller_sku: #{@seller_sku.inspect}, quantity: #{@quantity.inspect},"\ " updated_at: #{@updated_at.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_updated_at ⇒ Object
86 87 88 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 86 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/walmart_ap_is/models/update_inventory_response.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} seller_sku: #{@seller_sku}, quantity: #{@quantity}, updated_at:"\ " #{@updated_at}, additional_properties: #{@additional_properties}>" end |