Class: WalmartApIs::UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest
- Defined in:
- lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb
Overview
UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest Model.
Instance Attribute Summary collapse
-
#program_action ⇒ Array[ProgramAction]
TODO: Write general description for this method.
-
#program_action_feed_header ⇒ ProgramActionFeedHeader
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(program_action_feed_header:, program_action:, additional_properties: nil) ⇒ UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest
constructor
A new instance of UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(program_action_feed_header:, program_action:, additional_properties: nil) ⇒ UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest
Returns a new instance of UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest.
38 39 40 41 42 43 44 45 46 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 38 def initialize(program_action_feed_header:, program_action:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @program_action_feed_header = program_action_feed_header @program_action = program_action @additional_properties = additional_properties end |
Instance Attribute Details
#program_action ⇒ Array[ProgramAction]
TODO: Write general description for this method
18 19 20 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 18 def program_action @program_action end |
#program_action_feed_header ⇒ ProgramActionFeedHeader
TODO: Write general description for this method
14 15 16 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 14 def program_action_feed_header @program_action_feed_header end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['ProgramActionFeedHeader'] program_action_feed_header = ProgramActionFeedHeader.from_hash(hash['ProgramActionFeedHeader']) end # Parameter is an array, so we need to iterate through it program_action = nil unless hash['ProgramAction'].nil? program_action = [] hash['ProgramAction'].each do |structure| program_action << (ProgramAction.from_hash(structure) if structure) end end program_action = nil unless hash.key?('ProgramAction') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateWalmartFundedIncentivesEnrollmentForSpecificItemsRequest.new(program_action_feed_header: program_action_feed_header, program_action: program_action, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['program_action_feed_header'] = 'ProgramActionFeedHeader' @_hash['program_action'] = 'ProgramAction' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} program_action_feed_header: #{@program_action_feed_header.inspect},"\ " program_action: #{@program_action.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/walmart_ap_is/models/update_walmart_funded_incentives_enrollment_for_specific_items_request.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} program_action_feed_header: #{@program_action_feed_header}, program_action:"\ " #{@program_action}, additional_properties: #{@additional_properties}>" end |