Class: WalmartApIs::WalmartItemIdentifier
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::WalmartItemIdentifier
- Defined in:
- lib/walmart_ap_is/models/walmart_item_identifier.rb
Overview
Schema to identify an item by MarketPlaceId and Walmart Item ID (see ADR-029).
Instance Attribute Summary collapse
-
#marketplace_id ⇒ String
A marketplace identifier.
-
#walmart_item_id ⇒ String
The Walmart Item ID of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(marketplace_id:, walmart_item_id:, additional_properties: nil) ⇒ WalmartItemIdentifier
constructor
A new instance of WalmartItemIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(marketplace_id:, walmart_item_id:, additional_properties: nil) ⇒ WalmartItemIdentifier
Returns a new instance of WalmartItemIdentifier.
39 40 41 42 43 44 45 46 47 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 39 def initialize(marketplace_id:, walmart_item_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @marketplace_id = marketplace_id @walmart_item_id = walmart_item_id @additional_properties = additional_properties end |
Instance Attribute Details
#marketplace_id ⇒ String
A marketplace identifier.
15 16 17 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 15 def marketplace_id @marketplace_id end |
#walmart_item_id ⇒ String
The Walmart Item ID of the item.
19 20 21 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 19 def walmart_item_id @walmart_item_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. marketplace_id = hash.key?('MarketplaceId') ? hash['MarketplaceId'] : nil walmart_item_id = hash.key?('walmartItemId') ? hash['walmartItemId'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalmartItemIdentifier.new(marketplace_id: marketplace_id, walmart_item_id: walmart_item_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['marketplace_id'] = 'MarketplaceId' @_hash['walmart_item_id'] = 'walmartItemId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id.inspect}, walmart_item_id:"\ " #{@walmart_item_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/walmart_ap_is/models/walmart_item_identifier.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} marketplace_id: #{@marketplace_id}, walmart_item_id: #{@walmart_item_id},"\ " additional_properties: #{@additional_properties}>" end |