Class: WalmartApIs::WfsPrimeDetailsType
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::WfsPrimeDetailsType
- Defined in:
- lib/walmart_ap_is/models/wfs_prime_details_type.rb
Overview
Walmart Fulfillment Services prime eligibility information.
Instance Attribute Summary collapse
-
#is_national_wfs_prime ⇒ TrueClass | FalseClass
Indicates whether the offer is eligible for WFS Prime throughout the entire marketplace.
-
#is_wfs_prime ⇒ TrueClass | FalseClass
Indicates whether the offer is eligible for WFS Prime.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(is_wfs_prime:, is_national_wfs_prime:, additional_properties: nil) ⇒ WfsPrimeDetailsType
constructor
A new instance of WfsPrimeDetailsType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_wfs_prime:, is_national_wfs_prime:, additional_properties: nil) ⇒ WfsPrimeDetailsType
Returns a new instance of WfsPrimeDetailsType.
39 40 41 42 43 44 45 46 47 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 39 def initialize(is_wfs_prime:, is_national_wfs_prime:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @is_wfs_prime = is_wfs_prime @is_national_wfs_prime = is_national_wfs_prime @additional_properties = additional_properties end |
Instance Attribute Details
#is_national_wfs_prime ⇒ TrueClass | FalseClass
Indicates whether the offer is eligible for WFS Prime throughout the entire marketplace.
19 20 21 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 19 def is_national_wfs_prime @is_national_wfs_prime end |
#is_wfs_prime ⇒ TrueClass | FalseClass
Indicates whether the offer is eligible for WFS Prime.
14 15 16 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 14 def is_wfs_prime @is_wfs_prime end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_wfs_prime = hash.key?('IsWFSPrime') ? hash['IsWFSPrime'] : nil is_national_wfs_prime = hash.key?('IsNationalWFSPrime') ? hash['IsNationalWFSPrime'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WfsPrimeDetailsType.new(is_wfs_prime: is_wfs_prime, is_national_wfs_prime: is_national_wfs_prime, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['is_wfs_prime'] = 'IsWFSPrime' @_hash['is_national_wfs_prime'] = 'IsNationalWFSPrime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_wfs_prime: #{@is_wfs_prime.inspect}, is_national_wfs_prime:"\ " #{@is_national_wfs_prime.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/walmart_ap_is/models/wfs_prime_details_type.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_wfs_prime: #{@is_wfs_prime}, is_national_wfs_prime:"\ " #{@is_national_wfs_prime}, additional_properties: #{@additional_properties}>" end |