Class: WalmartApIs::WfsUnavailableQuantity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- WalmartApIs::WfsUnavailableQuantity
- Defined in:
- lib/walmart_ap_is/models/wfs_unavailable_quantity.rb
Overview
WfsUnavailableQuantity Model.
Instance Attribute Summary collapse
-
#inventory_movement_units ⇒ Integer
Units held during fulfillment center movement.
-
#inventory_review_units ⇒ Integer
Units held pending inventory review.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(inventory_review_units: SKIP, inventory_movement_units: SKIP, additional_properties: nil) ⇒ WfsUnavailableQuantity
constructor
A new instance of WfsUnavailableQuantity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(inventory_review_units: SKIP, inventory_movement_units: SKIP, additional_properties: nil) ⇒ WfsUnavailableQuantity
Returns a new instance of WfsUnavailableQuantity.
41 42 43 44 45 46 47 48 49 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 41 def initialize(inventory_review_units: SKIP, inventory_movement_units: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @inventory_review_units = inventory_review_units unless inventory_review_units == SKIP @inventory_movement_units = inventory_movement_units unless inventory_movement_units == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#inventory_movement_units ⇒ Integer
Units held during fulfillment center movement
18 19 20 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 18 def inventory_movement_units @inventory_movement_units end |
#inventory_review_units ⇒ Integer
Units held pending inventory review
14 15 16 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 14 def inventory_review_units @inventory_review_units end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. inventory_review_units = hash.key?('inventoryReviewUnits') ? hash['inventoryReviewUnits'] : SKIP inventory_movement_units = hash.key?('inventoryMovementUnits') ? hash['inventoryMovementUnits'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WfsUnavailableQuantity.new(inventory_review_units: inventory_review_units, inventory_movement_units: inventory_movement_units, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['inventory_review_units'] = 'inventoryReviewUnits' @_hash['inventory_movement_units'] = 'inventoryMovementUnits' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 29 def self.optionals %w[ inventory_review_units inventory_movement_units ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} inventory_review_units: #{@inventory_review_units.inspect},"\ " inventory_movement_units: #{@inventory_movement_units.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 80 |
# File 'lib/walmart_ap_is/models/wfs_unavailable_quantity.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} inventory_review_units: #{@inventory_review_units},"\ " inventory_movement_units: #{@inventory_movement_units}, additional_properties:"\ " #{@additional_properties}>" end |